# /////////////////////////////////////////////////////////////// #
# Python Script initially created on 2022-12-15
# Compiled by Aly @ Grasselli Geomechanics Group, UofT, 2022
# Created using PyCharm
# /////////////////////////////////////////////////////////////// #

# Dictionary to hold Rock Category
_rocktype_dictionary = {
    "Diabase": ["Igneous", 'blue', 'ID'],
    "Intrusive Rock": ["Igneous", 'black', "IG"],
    "Flow Rock": ["Igneous", 'red', "IF"],
    "Granite": ["Igneous", 'black', "IG"],
    "Basalt": ["Igneous", 'red', "IF"],
    "Quartzite": ["Metamorphic", 'orange', "MQ"],
    "Gneiss": ["Metamorphic", 'yellow', "MG"],
    "Marble": ["Metamorphic", 'purple', "MM"],
    "Schist_Flat": ["Metamorphic", 'darkgreen', "MSpp"],
    "Schist": ["Metamorphic", 'darkgreen', "MS"],
    "Schist_Perp": ["Metamorphic", 'olive', "MSpl"],
    "Limestone": ["Sedimentary", 'cyan', "SL"],
    "Mudstone": ["Sedimentary", 'grey', "SSh"],
    "Sandstone": ["Sedimentary", 'brown', "SS"],
    "Shale": ["Sedimentary", 'dodgerblue', 'SSh'],
    "Chalk": ["Sedimentary", 'fuchsia', 'SC']
}

# Dictionary to hold common values of Poisson Ratio and Density
_poisson_density_range = [
    {'Rock Type': 'Andesite', 'Group': 'Igneous', 'Min_P': 0.2, 'Max_P': 0.35, 'Min_D': 2.172, 'Max_D': 3.052},
    {'Rock Type': 'Basalt', 'Group': 'Igneous', 'Min_P': 0.1, 'Max_P': 0.35, 'Min_D': 0.736, 'Max_D': 3.124},
    {'Rock Type': 'Claystone', 'Group': 'Sedimentary', 'Min_P': 0.25, 'Max_P': 0.4, 'Min_D': 1.8, 'Max_D': 2.2},
    {'Rock Type': 'Conglomerate', 'Group': 'Sedimentary', 'Min_P': 0.1, 'Max_P': 0.4, 'Min_D': 2.47, 'Max_D': 2.76},
    {'Rock Type': 'Diabase/Dolerite', 'Group': 'Igneous', 'Min_P': 0.1, 'Max_P': 0.35, 'Min_D': 2.296, 'Max_D': 3.19},
    {'Rock Type': 'Diorite', 'Group': 'Igneous', 'Min_P': 0.2, 'Max_P': 0.3, 'Min_D': 2.03, 'Max_D': 3.124},
    {'Rock Type': 'Dolomite', 'Group': 'Sedimentary', 'Min_P': 0.15, 'Max_P': 0.35, 'Min_D': 2.4, 'Max_D': 2.85},
    {'Rock Type': 'Gabbro', 'Group': 'Igneous', 'Min_P': 0.1, 'Max_P': 0.38, 'Min_D': 2.7, 'Max_D': 3.19},
    {'Rock Type': 'Gneiss', 'Group': 'Metamorphic', 'Min_P': 0.1, 'Max_P': 0.3, 'Min_D': 2.064, 'Max_D': 3.36},
    {'Rock Type': 'Granite', 'Group': 'Igneous', 'Min_P': 0.1, 'Max_P': 0.33, 'Min_D': 2.4, 'Max_D': 2.785},
    {'Rock Type': 'Granodiorite', 'Group': 'Igneous', 'Min_P': 0.15, 'Max_P': 0.25, 'Min_D': 2.63, 'Max_D': 2.74},
    {'Rock Type': 'Greywacke', 'Group': 'Sedimentary', 'Min_P': 0.08, 'Max_P': 0.23, 'Min_D': 2.41, 'Max_D': 2.77},
    {'Rock Type': 'Limestone', 'Group': 'Sedimentary', 'Min_P': 0.1, 'Max_P': 0.33, 'Min_D': 1.31, 'Max_D': 2.92},
    {'Rock Type': 'Marble', 'Group': 'Metamorphic', 'Min_P': 0.15, 'Max_P': 0.3, 'Min_D': 2.64, 'Max_D': 3.02},
    {'Rock Type': 'Marl', 'Group': 'Sedimentary', 'Min_P': 0.13, 'Max_P': 0.33, 'Min_D': 1.86, 'Max_D': 2.69},
    {'Rock Type': 'Norite', 'Group': 'Igneous', 'Min_P': 0.2, 'Max_P': 0.25, 'Min_D': 2.72, 'Max_D': 3.02},
    {'Rock Type': 'Quartzite', 'Group': 'Metamorphic', 'Min_P': 0.1, 'Max_P': 0.33, 'Min_D': 2.55, 'Max_D': 3.05},
    {'Rock Type': 'Rock Salt', 'Group': 'Sedimentary', 'Min_P': 0.05, 'Max_P': 0.3, 'Min_D': 2.1, 'Max_D': 2.9},
    {'Rock Type': 'Sandstone', 'Group': 'Sedimentary', 'Min_P': 0.05, 'Max_P': 0.4, 'Min_D': 1.44, 'Max_D': 2.8},
    {'Rock Type': 'Shale', 'Group': 'Sedimentary', 'Min_P': 0.05, 'Max_P': 0.32, 'Min_D': 1.6, 'Max_D': 2.92},
    {'Rock Type': 'Siltstone', 'Group': 'Sedimentary', 'Min_P': 0.13, 'Max_P': 0.35, 'Min_D': 1.11, 'Max_D': 2.87},
    {'Rock Type': 'Tuff', 'Group': 'Igneous', 'Min_P': 0.1, 'Max_P': 0.28, 'Min_D': 1.6, 'Max_D': 2.78}
]

# Dictionary to hold the SR cluster points
_rock_tatone_et_al_points = {
    'Limestone': [
        {2: 3.02949612882451, 3: 3.09595164266821, 4: 3.16386493534127, 5: 3.23326798491433, 6: 3.30419347093409,
         7: 3.37667478981108, 8: 3.45074607054483, 9: 3.52644219079411, 10: 3.60379879329957, 11: 3.68285230266681,
         12: 3.76363994251739, 13: 3.84619975301621, 14: 3.93057060878337, 15: 4.01679223719886, 16: 4.10490523710886,
         17: 4.19495109794236, 18: 4.28697221924716, 19: 4.38101193065431, 20: 4.47711451228065, 21: 4.57532521557874,
         22: 4.67569028464431, 23: 4.75015081432211, 24: 4.77825697799097, 25: 4.88307359080271, 26: 4.99018947767441,
         27: 5.07967385879178, 28: 5.09965507585128, 29: 5.21152192897806, 30: 5.32584271136914, 31: 5.34540858866538,
         32: 5.44267125281115, 33: 5.56206256390955, 34: 5.57997874507495, 35: 5.68407286199132, 36: 5.79494499878191,
         37: 5.80875959757571, 38: 5.93618148142582, 39: 5.99637580133825, 40: 6.06639851219348, 41: 6.18725454238726,
         42: 6.19947200467057, 43: 6.33546461866011, 44: 6.37056663375495, 45: 6.47444038848062, 46: 6.54738156684704,
         47: 6.61646475311774, 48: 6.71872707138227, 49: 6.76160458703718, 50: 6.88563877407678, 51: 6.90992823167371,
         52: 7.04894039473982, 53: 7.06150552761076, 54: 7.20928597328663, 55: 7.21640784746605, 56: 7.36719238646632,
         57: 7.37470812949848, 58: 7.52306418495968, 59: 7.53648091195235, 60: 7.67721221562886, 61: 7.70180236815484,
         62: 7.82986706693746, 63: 7.87075034238347, 64: 7.98118805303903, 65: 8.04340438652035, 66: 8.1312682101198,
         67: 8.21984579751048, 68: 8.28013560113526, 69: 8.40015765564165, 70: 8.42775110007144, 71: 8.57466530009831,
         72: 8.58442486366426, 73: 8.72232361258672, 74: 8.77273418676903, 75: 8.86888166855163, 76: 8.96517429344188,
         77: 9.01406361253148, 78: 9.15777276266049, 79: 9.16183579721485, 80: 9.30314345085109, 81: 9.36281129933302,
         82: 9.44667616500686, 83: 9.56819543235723, 84: 9.58774259310429, 85: 9.72937200615072, 86: 9.77808490472338,
         87: 9.86951993205606, 88: 9.99257854627917, 89: 10.0059404613759, 90: 10.1433522436361, 91: 10.2117773548197,
         92: 10.2774757656232, 93: 10.4085014736238, 94: 10.435784543644, 95: 10.5396897542826, 96: 10.6647055901545,
         97: 10.6647123177378, 98: 10.792755556455, 99: 10.898648285523, 100: 10.9140529629895, 101: 11.0377770999432,
         102: 11.1377227854456, 103: 11.1556378778827, 104: 11.2766482248546, 105: 11.3820416620116,
         106: 11.3915620323175, 107: 11.5114636137166, 108: 11.6246092447576, 109: 11.6317199567097,
         110: 11.7436710950024, 111: 11.856814018898, 112: 11.8868752345972, 113: 11.9732530868023,
         114: 12.0862457523619, 115: 12.1476276396573, 116: 12.1981314817329, 117: 12.3097824331177,
         118: 12.4138210146373, 119: 12.4140999513709, 120: 12.5218033864683, 121: 12.620768391037,
         122: 12.6864176425295, 123: 12.7137845093793, 124: 12.8035539957505, 125: 12.8822899495931,
         126: 12.9496885767004, 127: 12.9647089383158, 128: 13.0084367103433, 129: 13.0531069154767,
         130: 13.0805845488383, 131: 13.0884274252236, 132: 13.0733095587095, 133: 13.030893560202,
         134: 12.9647089383158, 135: 12.9560284217188, 136: 12.8449015406065, 137: 12.6865990452425,
         138: 12.6864176425295, 139: 12.4760949595775, 140: 12.4140999513709, 141: 12.2038171816563,
         142: 12.1476276396573, 143: 11.8868752345972, 144: 11.8662802902869, 145: 11.6317199567097,
         146: 11.4674689596416, 147: 11.3820416620116, 148: 11.1377227854456, 149: 11.0054274290996,
         150: 10.898648285523, 151: 10.6647055901545, 152: 10.435784543644, 153: 10.4108670879754,
         154: 10.2117773548197, 155: 9.99257854627917, 156: 9.77808490472338, 157: 9.56819543235723,
         158: 9.36281129933302, 159: 9.16183579721485, 160: 8.96517429344188, 161: 8.86878775869089,
         162: 8.77273418676903, 163: 8.58442486366426, 164: 8.40015765564165, 165: 8.32374600185215,
         166: 8.21984579751048, 167: 8.04340438652035, 168: 7.94628470540537, 169: 7.87075034238347,
         170: 7.70180236815483, 171: 7.64008694457892, 172: 7.53648091195235, 173: 7.37669769598773,
         174: 7.37470812949848, 175: 7.21640784746605, 176: 7.14355189166273, 177: 7.06150552761076,
         178: 6.93246783109811, 179: 6.90992823167371, 180: 6.76160458703718, 181: 6.73852014460225,
         182: 6.61646475311774, 183: 6.55841085603691, 184: 6.47444038848062, 185: 6.39037376886867,
         186: 6.33546461866011, 187: 6.23256258451956, 188: 6.19947200467056, 189: 6.08350668691807,
         190: 6.06639851219348, 191: 5.9420307165083, 192: 5.93618148142582, 193: 5.80875959757571,
         194: 5.80703347582486, 195: 5.68407286199132, 196: 5.67760691942655, 197: 5.56206256390955,
         198: 5.55370643597414, 199: 5.44267125281115, 200: 5.43484899424248, 201: 5.32584271136914,
         202: 5.32064936561574, 203: 5.21152192897806, 204: 5.21080395429432, 205: 5.10443852684981,
         206: 5.09965507585128, 207: 5.00171619209398, 208: 4.99018947767441, 209: 4.90260195188795,
         210: 4.88307359080271, 211: 4.80701971118092, 212: 4.77825697799097, 213: 4.71492635094291,
         214: 4.67569028464431, 215: 4.62630306628511, 216: 4.57532521557874, 217: 4.5411461101644,
         218: 4.47711451228065, 219: 4.4594569116581, 220: 4.38120699493468, 221: 4.38101193065431,
         222: 4.30428677244199, 223: 4.28697221924716, 224: 4.23072103673068, 225: 4.19495109794236,
         226: 4.16048874986649, 227: 4.10490523710886, 228: 4.09353592311065, 229: 4.0285408180347,
         230: 4.01679223719886, 231: 3.96556374597897, 232: 3.93057060878337, 233: 3.90561514514479,
         234: 3.84836997702013, 235: 3.84619975301621, 236: 3.79192364063585, 237: 3.76363994251739,
         238: 3.7382212018628, 239: 3.68684661365407, 240: 3.68285230266681, 241: 3.63642752539413,
         242: 3.60379879329957, 243: 3.5885462630493, 244: 3.54233612612818, 245: 3.52644219079411,
         246: 3.49795081452032, 247: 3.45590523585254, 248: 3.45074607054483, 249: 3.41555780975518,
         250: 3.37789864866233, 251: 3.37667478981108, 252: 3.34239488383442, 253: 3.30985991071581,
         254: 3.30419347093409, 255: 3.28022856007772, 256: 3.25395423572186, 257: 3.23326798491433,
         258: 3.2313316690602, 259: 3.21249264442607, 260: 3.19757396576617, 261: 3.18645056312096,
         262: 3.17861026124768, 263: 3.17310059208834, 264: 3.16868388160024, 265: 3.16413108764981,
         266: 3.16386493534127, 267: 3.15806053587182, 268: 3.15020867342918, 269: 3.1404688288586,
         270: 3.1289650605665, 271: 3.11592076673923, 272: 3.10155725363086, 273: 3.09595164266821,
         274: 3.0859653502689, 275: 3.06993969075879, 276: 3.05389937256336, 277: 3.03809648918114,
         278: 3.02949612882451, 279: 3.02335865721863, 280: 3.01101067525671, 281: 3.00172172028478,
         282: 2.99743055755065, 283: 3.00205526843864, 284: 3.02447317318916, 285: 3.02949612882451},
        {2: 30.2527872379455, 3: 29.7006904133435, 4: 29.5818952873534, 5: 29.629346455413, 6: 29.7459522822828,
         7: 29.8876385622294, 8: 30.030606640073, 9: 30.1601503417918, 10: 30.2667439213234, 11: 30.3450986449507,
         12: 30.3962250711976, 13: 30.421304592444, 14: 30.4289985649936, 15: 30.4307679031202, 16: 30.4388790726806,
         17: 30.4643268386997, 18: 30.5154527930226, 19: 30.5976132128256, 20: 30.7137236121756, 21: 30.8652374111788,
         22: 31.0531535252443, 23: 31.2175638316801, 24: 31.2787378822088, 25: 31.5404335101298, 26: 31.8387369914124,
         27: 32.1151136461104, 28: 32.1761105133283, 29: 32.5480310808019, 30: 32.962473671842, 31: 33.0384693073302,
         32: 33.4131042728418, 33: 33.9095769874486, 34: 33.9883727705133, 35: 34.4442142452638, 36: 34.9655873231108,
         37: 35.0305588086237, 38: 35.6573202732893, 39: 35.9708981981847, 40: 36.3372103415078, 41: 37.0051132053758,
         42: 37.0732091942938, 43: 37.8579846111171, 44: 38.0690633800128, 45: 38.7015443277972, 46: 39.1636036508839,
         47: 39.6085367597103, 48: 40.2896135272086, 49: 40.5811030310438, 50: 41.4479978053602, 51: 41.6219392865903,
         52: 42.6396872959076, 53: 42.7342850459903, 54: 43.8656395715611, 55: 43.9218964412266, 56: 45.1268397366221,
         57: 45.1890059544222, 58: 46.4243012185564, 59: 46.5402737542947, 60: 47.7590665823252, 61: 47.980739981585,
         62: 49.1322083681306, 63: 49.5157918757565, 64: 50.5448299532465, 65: 51.1511636961619, 66: 51.9980664386286,
         67: 52.8929900534008, 68: 53.4930855610164, 69: 54.7479337459424, 70: 55.0310886312581, 71: 56.6133114996152,
         72: 56.7231214396965, 73: 58.2410255488196, 74: 58.8265329229012, 75: 59.9155387156837, 76: 61.0689279953807,
         77: 61.6381965420826, 78: 63.4103832561534, 79: 63.4628373535272, 80: 65.2335228845812, 81: 66.0281986071365,
         82: 67.1090803968643, 83: 68.7793606423883, 84: 69.0385628824791, 85: 71.0235207618899, 86: 71.7504647901783,
         87: 73.0655490323766, 88: 74.967883060268, 89: 75.1662885496833, 90: 77.3274273465138, 91: 78.484646105575,
         92: 79.550701988938, 93: 81.8378989717951, 94: 82.3439785131439, 95: 84.1908561542179, 96: 86.6113399559495,
         97: 86.6114642364301, 98: 89.1016682790034, 99: 91.3517676850377, 100: 91.6634692657955, 101: 94.2989257118253,
         102: 96.6156846810723, 103: 97.010155317376, 104: 99.7993366696568, 105: 102.442612390407,
         106: 102.66871099339, 107: 105.620583951727, 108: 108.65732749895, 109: 108.854216906132,
         110: 111.781381786434, 111: 114.995257123412, 112: 115.889312264332, 113: 118.301535994114,
         114: 121.702875132903, 115: 123.682664206486, 116: 125.202007659071, 117: 128.801745273018,
         118: 132.50498051557, 119: 132.515624764872, 120: 136.314689092257, 121: 140.23393226442,
         122: 143.151657886912, 123: 144.265859309061, 124: 148.413710049421, 125: 152.680817458314,
         126: 157.070610336313, 127: 158.315611225733, 128: 161.586616066931, 129: 166.232463451027,
         130: 171.011885622701, 131: 175.928723049017, 132: 180.986926615989, 133: 186.190560803281,
         134: 190.945608931702, 135: 191.543806950184, 136: 197.050966615504, 137: 202.716465034044,
         138: 202.72194325633, 139: 208.544854672463, 140: 210.012775507536, 141: 214.540818887381,
         142: 215.648218393477, 143: 220.362251302392, 144: 220.709175688646, 145: 224.568267232947,
         146: 227.054881610816, 147: 228.352784041449, 148: 231.846527273584, 149: 233.583035695935,
         150: 235.008200023847, 151: 237.813120522392, 152: 240.095716599087, 153: 240.298883590837,
         154: 241.945168767866, 155: 243.207944303812, 156: 243.881827100676, 157: 243.993507757628,
         158: 243.574727781665, 159: 242.653773612109, 160: 241.248231046705, 161: 240.298883590837,
         162: 239.462293600652, 163: 237.364270279431, 164: 234.837171946818, 165: 233.583035695935,
         166: 232.055162233403, 167: 229.005802202826, 168: 227.054881610816, 169: 225.681339514584,
         170: 222.163612142889, 171: 220.709175688646, 172: 218.475841184341, 173: 214.540818887381,
         174: 214.49570301515, 175: 210.569433622307, 176: 208.544854672463, 177: 206.424072399439,
         178: 202.716465034044, 179: 202.11019074901, 180: 197.777923683319, 181: 197.050966615504,
         182: 193.417571192498, 183: 191.543806950184, 184: 188.966227070032, 185: 186.190560803281,
         186: 184.456033871717, 187: 180.986926615989, 188: 179.9133476863, 189: 175.928723049017,
         190: 175.359750144607, 191: 171.011885622701, 192: 170.81284817101, 193: 166.295553649104,
         194: 166.232463451027, 195: 161.82535834608, 196: 161.586616066931, 197: 157.381858415076,
         198: 157.070610336313, 199: 152.974380231362, 200: 152.680817458314, 201: 148.609876645022,
         202: 148.413710049421, 203: 144.293132127214, 204: 144.265859309061, 205: 140.23393226442,
         206: 140.051315421665, 207: 136.314689092257, 208: 135.86956602266, 209: 132.50498051557,
         210: 131.742718179527, 211: 128.801745273018, 212: 127.667463459456, 213: 125.202007659071,
         214: 123.63914445944, 215: 121.702875132903, 216: 119.651900858584, 217: 118.301535994114,
         218: 115.698880105686, 219: 114.995257123412, 220: 111.781381786434, 221: 111.773271465086,
         222: 108.65732749895, 223: 107.929323762665, 224: 105.620583951727, 225: 104.09933274618, 226: 102.66871099339,
         227: 100.277060266246, 228: 99.7993366696568, 229: 97.010155317376, 230: 96.4936499884601,
         231: 94.2989257118253, 232: 92.7447022078051, 233: 91.6634692657955, 234: 89.1016682790034,
         235: 89.0034395278167, 236: 86.6114642364301, 237: 85.3212290557887, 238: 84.1908561542179,
         239: 81.837898971795, 240: 81.652024789176, 241: 79.550701988938, 242: 78.0228264181191, 243: 77.3274273465138,
         244: 75.1662885496833, 245: 74.3996168824854, 246: 73.0655490323766, 247: 71.0235207618899,
         248: 70.7622230805459, 249: 69.0385628824791, 250: 67.1090803968643, 251: 67.0420405159401,
         252: 65.2335228845812, 253: 63.4103832561534, 254: 63.0598155207653, 255: 61.6381965420826,
         256: 59.9155387156837, 257: 58.3783916377793, 258: 58.2410255488196, 259: 56.6133114996152,
         260: 55.0310886312581, 261: 53.4930855610164, 262: 51.9980664386286, 263: 50.5448299532465,
         264: 49.1322083681306, 265: 47.7590665823252, 266: 47.6977238057479, 267: 46.4243012185564,
         268: 45.1268397366221, 269: 43.8656395715611, 270: 42.6396872959076, 271: 41.4479978053602,
         272: 40.2896135272086, 273: 39.8762453842556, 274: 39.1636036508839, 275: 38.0690633800128,
         276: 37.0051132053758, 277: 35.9708981981847, 278: 35.379312865542, 279: 34.9655873231108,
         280: 33.9883727705133, 281: 33.0384693073302, 282: 32.1151136461104, 283: 31.2175638316801,
         284: 30.3450986449507, 285: 30.2527872379455}
    ],
    'Sandstone': [
        {2: 1.72776264405674, 3: 1.78688276272424, 4: 1.84802583775283, 5: 1.91126109012062, 6: 1.97666010939053,
         7: 2.04429693475799, 8: 2.11424813887173, 9: 2.16400937729814, 10: 2.18659291452283, 11: 2.26141316430007,
         12: 2.33879359331302, 13: 2.418821805088, 14: 2.50158840074524, 15: 2.52693534659954, 16: 2.58718708156986,
         17: 2.67571475509236, 18: 2.76727164479917, 19: 2.7942580164516, 20: 2.86196140359706, 21: 2.95989123116017,
         22: 3.01846420635095, 23: 3.06117199529234, 24: 3.16591835744217, 25: 3.2187610048813, 26: 3.27424890251296,
         27: 3.38628627311439, 28: 3.40569404585434, 29: 3.5021573084081, 30: 3.58672008350809, 31: 3.62199318770411,
         32: 3.7459295789709, 33: 3.7646549621003, 34: 3.87410679242707, 35: 3.94443273520922, 36: 4.00666993938867,
         37: 4.12580893144681, 38: 4.14376909655183, 39: 4.2855594758968, 40: 4.31391474560993, 41: 4.43220160040573,
         42: 4.51079948618341, 43: 4.58386148579313, 44: 4.71698482307288, 45: 4.74071082845468, 46: 4.90292719984727,
         47: 4.93862295289347, 48: 5.07069424752026, 49: 5.17855451803144, 50: 5.24420190302561, 51: 5.42364659694217,
         52: 5.43776998867924, 53: 5.60923148125761, 54: 5.72170268921065, 55: 5.80116665935985, 56: 5.99966942389817,
         57: 6.02624011637323, 58: 6.20496450278343, 59: 6.34841621044003, 60: 6.41728431360586, 61: 6.63686922675844,
         62: 6.68264593091275, 63: 6.86396783756378, 64: 7.02329967445245, 65: 7.09883724771255, 66: 7.3417433563321,
         67: 7.36905674754322, 68: 7.59296116101478, 69: 7.71525937968259, 70: 7.85277506914683, 71: 8.0650148983801,
         72: 8.12147921989006, 73: 8.39937781718128, 74: 8.41704974976629, 75: 8.68678547412599, 76: 8.77063171966371,
         77: 8.98402756917651, 78: 9.12760940163685, 79: 9.29144061449778, 80: 9.48810356624604, 81: 9.60937263693773,
         82: 9.85234276554427, 83: 9.93818357203359, 84: 10.2206226631894, 85: 10.2782456715003, 86: 10.5932713948596,
         87: 10.629943924662, 88: 10.9706213981988, 89: 10.9936764943044, 90: 11.3529871986741, 91: 11.3698551674405,
         92: 11.7406481348493, 93: 11.7589058215009, 94: 12.1338348052984, 95: 12.1612689064758, 96: 12.5327179902726,
         97: 12.5773999435551, 98: 12.9373988496465, 99: 13.0077700408306, 100: 13.3478992644635, 101: 13.4528664266442,
         102: 13.7641512398982, 103: 13.9131930011868, 104: 14.1859843088304, 105: 14.3892709069706,
         106: 14.6131098645406, 107: 14.8816391188226, 108: 15.045101309534, 109: 15.3908550540659,
         110: 15.4813688352579, 111: 15.9174952035798, 112: 15.9211275393471, 113: 16.3743561816234,
         114: 16.4621557844542, 115: 16.8323705196012, 116: 17.0254534149752, 117: 17.2937246188441,
         118: 17.608025812708, 119: 17.7570544553317, 120: 18.2105325164665, 121: 18.2206282838178,
         122: 18.7008528314041, 123: 18.8336556329868, 124: 19.1828838830777, 125: 19.4781006091501, 126: 19.6631964193,
         127: 20.1395563052595, 128: 20.14459703063, 129: 20.6356743917528, 130: 20.8338994478668,
         131: 21.1266288385421, 132: 21.5467882303056, 133: 21.608365881628, 134: 22.1030867213416,
         135: 22.2840704498633, 136: 22.5946561165708, 137: 23.0465807946278, 138: 23.0696878588091,
         139: 23.5626081084835, 140: 23.8351825138196, 141: 24.0384750932153, 142: 24.5069618651701,
         143: 24.6507683950897, 144: 24.9749003213135, 145: 25.4183622532234, 146: 25.4942617752573,
         147: 25.866388534776, 148: 26.2809474962486, 149: 26.3666175856334, 150: 26.6920265591579,
         151: 27.0681685319622, 152: 27.2688234331121, 153: 27.4174153420498, 154: 27.7358336796429,
         155: 28.0014835607371, 156: 28.2019007182555, 157: 28.2105254481083, 158: 28.3530952029589,
         159: 28.3939282848512, 160: 28.2959229037687, 161: 28.2019007182555, 162: 27.976812349483,
         163: 27.2688234331121, 164: 27.262401617382, 165: 26.3666175856334, 166: 25.4942617752573,
         167: 24.6623111806441, 168: 24.6507683950897, 169: 23.8351825138196, 170: 23.0465807946278,
         171: 22.2840704498633, 172: 21.5467882303056, 173: 20.8338994478668, 174: 20.14459703063,
         175: 19.4781006091501, 176: 18.8336556329868, 177: 18.2105325164665, 178: 17.608025812708,
         179: 17.0254534149752, 180: 16.628488445737, 181: 16.4621557844542, 182: 15.9174952035798,
         183: 15.3908550540659, 184: 14.8816391188226, 185: 14.7700269999786, 186: 14.3892709069706,
         187: 13.9131930011868, 188: 13.6483224218852, 189: 13.4528664266442, 190: 13.0077700408306,
         191: 12.7711423236314, 192: 12.5773999435551, 193: 12.1612689064758, 194: 12.0303761119719,
         195: 11.7589058215009, 196: 11.3806067634834, 197: 11.3698551674405, 198: 10.9936764943044,
         199: 10.8025492723025, 200: 10.629943924662, 201: 10.2782456715003, 202: 10.2760183606976,
         203: 9.93818357203359, 204: 9.79597915138115, 205: 9.60937263693773, 206: 9.35434733004381,
         207: 9.29144061449778, 208: 8.98402756917651, 209: 8.94653818909095, 210: 8.68678547412599,
         211: 8.56890542749213, 212: 8.39937781718128, 213: 8.21882533844604, 214: 8.12147921989006,
         215: 7.89355708003728, 216: 7.85277506914683, 217: 7.59296116101478, 218: 7.59061119410217,
         219: 7.3417433563321, 220: 7.30699879210595, 221: 7.09883724771255, 222: 7.04188079341231,
         223: 6.86396783756378, 224: 6.79345801406266, 225: 6.63686922675845, 226: 6.56011015018329,
         227: 6.41728431360586, 228: 6.3403753274915, 229: 6.20496450278343, 230: 6.13293251611826,
         231: 5.99966942389817, 232: 5.93658544678709, 233: 5.80116665935985, 234: 5.75024717348764,
         235: 5.60923148125761, 236: 5.57292486708202, 237: 5.42364659694217, 238: 5.40370479086788,
         239: 5.24420190302561, 240: 5.24173771354298, 241: 5.08520749027769, 242: 5.07069424752026,
         243: 4.93406686104458, 244: 4.90292719984727, 245: 4.78778245356714, 246: 4.74071082845468,
         247: 4.64570739244589, 248: 4.58386148579313, 249: 4.50722956219377, 250: 4.43220160040573,
         251: 4.37177388132393, 252: 4.2855594758968, 253: 4.23880975801718, 254: 4.14376909655183,
         255: 4.10786375125241, 256: 4.00666993938867, 257: 3.9785366405475, 258: 3.87410679242707,
         259: 3.85052307073327, 260: 3.7459295789709, 261: 3.72363086643787, 262: 3.62199318770411,
         263: 3.59779631032578, 264: 3.5021573084081, 265: 3.47309151529326, 266: 3.38628627311439,
         267: 3.34972077896459, 268: 3.27424890251296, 269: 3.22800452367134, 270: 3.16591835744217,
         271: 3.10835177409581, 272: 3.06117199529234, 273: 2.99122447793555, 274: 2.95989123116017,
         275: 2.87709861893288, 276: 2.86196140359706, 277: 2.76727164479917, 278: 2.76634189476284,
         279: 2.67571475509236, 280: 2.65800149375359, 281: 2.58718708156986, 282: 2.55399728273961,
         283: 2.50158840074524, 284: 2.45459530004445, 285: 2.418821805088, 286: 2.35996764905571,
         287: 2.33879359331302, 288: 2.27020194894411, 289: 2.26141316430007, 290: 2.18659291452283,
         291: 2.18515756194769, 292: 2.11424813887173, 293: 2.10416304522263, 294: 2.04429693475799,
         295: 2.02822161258565, 296: 1.97666010939053, 297: 1.95722329417165, 298: 1.91126109012062,
         299: 1.89104520289664, 300: 1.84802583775283, 301: 1.82956291030692, 302: 1.78688276272424,
         303: 1.77266022841438, 304: 1.72776264405674, 305: 1.72023801784074, 306: 1.67203815427297,
         307: 1.67059855099101, 308: 1.62705097250703, 309: 1.61532576721321, 310: 1.58610035649858,
         311: 1.56188171758864, 312: 1.54920750808429, 313: 1.51584059531246, 314: 1.51020589731957,
         315: 1.48519788327647, 316: 1.46023980344681, 317: 1.45864575167505, 318: 1.43445152482636,
         319: 1.41424217543147, 320: 1.41192686861768, 321: 1.39688171434727, 322: 1.38347660285553,
         323: 1.37424947081967, 324: 1.36988776305687, 325: 1.37185569425704, 326: 1.3826615180185,
         327: 1.40617518872171, 328: 1.41192686861768, 329: 1.45234694631247, 330: 1.46023980344681,
         331: 1.51020589731957, 332: 1.54130889423192, 333: 1.56188171758864, 334: 1.61532576721321,
         335: 1.67059855099101, 336: 1.72713804824602, 337: 1.72776264405674},
        {2: 29.7894047655044, 3: 29.6627459479463, 4: 29.5858626894997, 5: 29.5561504219329, 6: 29.5696696114157,
         7: 29.6220319654179, 8: 29.7094226750243, 9: 29.7912752276929, 10: 29.8262527182505, 11: 29.9629957901982,
         12: 30.1252013119441, 13: 30.31510234925, 14: 30.5371142207221, 15: 30.6101221601201, 16: 30.7747108621384,
         17: 31.0409268632447, 18: 31.3529780802381, 19: 31.4514760276692, 20: 31.6878830679347, 21: 32.0676535589287,
         22: 32.3159554589366, 23: 32.4909298097964, 24: 32.953625423763, 25: 33.2041960862263, 26: 33.4612222172332,
         27: 34.0175304680393, 28: 34.1168510129159, 29: 34.6042135833306, 30: 35.0545912936689, 31: 35.2414274293112,
         32: 35.9158511205759, 33: 36.0181064278458, 34: 36.6175968496823, 35: 37.0081048664781, 36: 37.356575476442,
         37: 38.0253145331758, 38: 38.1273930880271, 39: 38.9166719070926, 40: 39.0704833593538, 41: 39.7220578118659,
         42: 40.1443798341686, 43: 40.543544809062, 44: 41.2477935695715, 45: 41.3754121463668, 46: 42.2070013392893,
         47: 42.3815358808922, 48: 43.0350249003872, 49: 43.5464403833811, 50: 43.8605278812227, 51: 44.6814303641424,
         52: 44.7433636051474, 53: 45.4955404112394, 54: 45.9731856169455, 55: 46.3093973325195, 56: 47.1281719849075,
         57: 47.2368106792709, 58: 47.9590941240101, 59: 48.5351679072426, 60: 48.807646552277, 61: 49.6831216772718,
         62: 49.8692119537607, 63: 50.5929459437436, 64: 51.2399237114415, 65: 51.5407437758543, 66: 52.5331680619451,
         67: 52.6483110338451, 68: 53.5754884865111, 69: 54.0954094765283, 70: 54.6701804270495, 71: 55.5822830584647,
         72: 55.8211930910157, 73: 57.0312220936871, 74: 57.1100250443942, 75: 58.3013245678911, 76: 58.679758748676,
         77: 59.6362049179811, 78: 60.2926383612366, 79: 61.0386061495414, 80: 61.9498497962191, 81: 62.5112255262359,
         82: 63.6526115639601, 83: 64.0568094749016, 84: 65.4021756669322, 85: 65.6782377401275, 86: 67.1998285203137,
         87: 67.378595011109, 88: 69.0468918978607, 89: 69.1612306635267, 90: 70.9447239037778, 91: 71.0298090127616,
         92: 72.8947199713012, 93: 72.9883537441646, 94: 74.8983138887297, 95: 75.0412911411388, 96: 76.9569788536571,
         97: 77.193497490598, 98: 79.0722285561811, 99: 79.4503566669364, 100: 81.2456182918856, 101: 81.817834394252,
         102: 83.4787461054149, 103: 84.3025760588038, 104: 85.7732539654797, 105: 86.9120352007794,
         106: 88.1308289721598, 107: 89.6546400117944, 108: 90.5532045973912, 109: 92.5400054215323,
         110: 93.0421619595489, 111: 95.579198861739, 112: 95.599531133063, 113: 98.2271924940318,
         114: 98.7611357143454, 115: 100.927078102819, 116: 102.116621826577, 117: 103.701173124657,
         118: 105.662887924797, 119: 106.55151728929, 120: 109.419431816797, 121: 109.480206390746,
         122: 112.489393828323, 123: 113.372584244832, 124: 115.581292189938, 125: 117.574523267435,
         126: 118.758174878992, 127: 122.022377785953, 128: 122.05839561679, 129: 125.376301005884,
         130: 126.818262102691, 131: 128.822410603177, 132: 131.935882256599, 133: 132.363240424797,
         134: 136.001393963361, 135: 137.4378952765, 136: 139.739546271431, 137: 143.406371238521,
         138: 143.580445928414, 139: 147.526917061537, 140: 149.927041111111, 141: 151.581861422361,
         142: 155.748260520374, 143: 157.141438573379, 144: 160.029177815228, 145: 164.427760969233,
         146: 165.252312328732, 147: 168.947244161761, 148: 173.590950467267, 149: 174.663809642982,
         150: 178.36229429867, 151: 183.264783917892, 152: 186.286801208545, 153: 188.302024015409,
         154: 193.477718360696, 155: 198.795672525525, 156: 204.057809069307, 157: 204.259796682118,
         158: 209.874108478207, 159: 215.642735991122, 160: 221.569920763072, 161: 223.667995361049,
         162: 227.660020919857, 163: 233.880234598938, 164: 233.917514375298, 165: 237.630798021436,
         166: 239.528455404709, 167: 240.347002123751, 168: 240.357540487048, 169: 240.55836309562,
         170: 240.347002123751, 171: 239.919144401843, 172: 239.367668799403, 173: 238.76557075927,
         174: 238.161501587793, 175: 237.578702249761, 176: 237.008273208245, 177: 236.403878505772,
         178: 235.68744331439, 179: 234.769013906203, 180: 233.917514375298, 181: 233.592481088992,
         182: 232.147596714385, 183: 230.360065284801, 184: 228.230904799884, 185: 227.660020919857,
         186: 225.875158617832, 187: 223.259039673128, 188: 221.569920763072, 189: 220.420720200302,
         190: 217.436838723132, 191: 215.642735991122, 192: 214.280912268033, 193: 211.01463470035,
         194: 209.874108478207, 195: 207.670314127753, 196: 204.259796682118, 197: 204.169063800144,
         198: 200.723432779401, 199: 198.795672525525, 200: 197.159642864455, 201: 193.502508103542,
         202: 193.477718360696, 203: 189.932204913601, 204: 188.302024015409, 205: 186.277321439627,
         206: 183.264783917892, 207: 182.558982079485, 208: 178.847109027171, 209: 178.36229429867,
         210: 175.162776087885, 211: 173.590950467267, 212: 171.430939891522, 213: 168.947244161761,
         214: 167.663768414728, 215: 164.427760969233, 216: 163.871187726633, 217: 160.065639298315,
         218: 160.029177815228, 219: 156.304715101007, 220: 155.748260520374, 221: 152.523297081124,
         222: 151.581861422361, 223: 148.729278656444, 224: 147.526917061537, 225: 144.929948686243,
         226: 143.580445928414, 227: 141.132313558457, 228: 139.739546271431, 229: 137.343392677017,
         230: 136.001393963361, 231: 133.570496318001, 232: 132.363240424797, 233: 129.821488443135,
         234: 128.822410603177, 235: 126.105028241902, 236: 125.376301005884, 237: 122.430773123678,
         238: 122.022377785953, 239: 118.809513652057, 240: 118.758174878992, 241: 115.581292189938,
         242: 115.29289526166, 243: 112.489393828323, 244: 111.863454683951, 245: 109.480206390746,
         246: 108.527148826549, 247: 106.55151728929, 248: 105.295797096608, 249: 103.701173124657,
         250: 102.180289229668, 251: 100.92707810282, 252: 99.1897938538221, 253: 98.2271924940318,
         254: 96.3310058914624, 255: 95.599531133063, 256: 93.6075566638776, 257: 93.0421619595489,
         258: 91.0196948627493, 259: 90.5532045973913, 260: 88.5643007939671, 261: 88.1308289721598,
         262: 86.2352320614724, 263: 85.7732539654797, 264: 84.0239354222094, 265: 83.4787461054149,
         266: 81.9202157151935, 267: 81.2456182918856, 268: 79.9130390354399, 269: 79.0722285561811,
         270: 77.9912626430255, 271: 76.9569788536571, 272: 76.1442183936874, 273: 74.8983138887297,
         274: 74.3621164504738, 275: 72.8947199713012, 276: 72.6362706541153, 277: 70.9614814026187,
         278: 70.9447239037778, 279: 69.3672983056884, 280: 69.0468918978607, 281: 67.8048798681264,
         282: 67.1998285203137, 283: 66.2691650554765, 284: 65.4021756669322, 285: 64.7559807200403,
         286: 63.6526115639601, 287: 63.2617729449983, 288: 61.9498497962191, 289: 61.7833430046909,
         290: 60.3211868186344, 291: 60.2926383612366, 292: 58.8860886549543, 293: 58.679758748676,
         294: 57.4496124912298, 295: 57.1100250443942, 296: 56.0078572392634, 297: 55.5822830584647,
         298: 54.5559451520173, 299: 54.0954094765283, 300: 53.0876356840658, 301: 52.6483110338451,
         302: 51.5948386463547, 303: 51.2399237114415, 304: 50.0669641416371, 305: 49.8692119537607,
         306: 48.5351679072426, 307: 48.4934811266257, 308: 47.2368106792709, 309: 46.8726451042804,
         310: 45.9731856169455, 311: 45.1616806436987, 312: 44.7433636051474, 313: 43.5464403833811,
         314: 43.3277765249623, 315: 42.3815358808922, 316: 41.3138438734564, 317: 41.2477935695715,
         318: 40.1443798341686, 319: 39.0704833593538, 320: 38.9254347321293, 321: 38.0253145331758,
         322: 37.0081048664781, 323: 36.0181064278458, 324: 35.0545912936689, 325: 34.1168510129159,
         326: 33.2041960862263, 327: 32.3159554589366, 328: 32.1777723834499, 329: 31.4514760276692,
         330: 31.3473505484726, 331: 30.8417958873283, 332: 30.6101221601201, 333: 30.4722071836042,
         334: 30.1872361751985, 335: 29.9620065575113, 336: 29.7912752276929, 337: 29.7894047655044}
    ],
    'Shale': [
        {2: 5.34032114502884, 3: 5.49636544930654, 4: 5.51516355142129, 5: 5.65696937167391, 6: 5.82226614427434,
         7: 5.99239289229746, 8: 6.02418998403431, 9: 6.16749074773405, 10: 6.34044437806987, 11: 6.34770496645481,
         12: 6.53318504871027, 13: 6.60588950681997, 14: 6.72408486315167, 15: 6.85023475332301, 16: 6.92056277447568,
         17: 7.07891886385238, 18: 7.122781774799, 19: 7.29504795427587, 20: 7.33090961887164, 21: 7.50091335758004,
         22: 7.5451189632412, 23: 7.69816993183121, 24: 7.76558750948349, 25: 7.88795676218176, 26: 7.99249815161836,
         27: 8.07097779863525, 28: 8.22603912783307, 29: 8.2475535156275, 30: 8.41626329829541, 31: 8.46640417663894,
         32: 8.57867596122945, 33: 8.71379269759095, 34: 8.73529652364239, 35: 8.883869799903, 36: 8.96840991670359,
         37: 9.02657640237422, 38: 9.16172103609719, 39: 9.23046705670012, 40: 9.2902873175226, 41: 9.41113298885773,
         42: 9.50018151223653, 43: 9.52573868252486, 44: 9.63221511048791, 45: 9.73289572163188, 46: 9.77777703024555,
         47: 9.82740728142764, 48: 9.9164468833067, 49: 10.0022115794617, 50: 10.0634838955504, 51: 10.0860696440569,
         52: 10.1700184420937, 53: 10.2565775257129, 54: 10.3474110659999, 55: 10.3575391219018, 56: 10.4467220864771,
         57: 10.5542930499373, 58: 10.660186648598, 59: 10.670007430218, 60: 10.8002206433734, 61: 10.9375352289281,
         62: 10.9716775428487, 63: 11.089120103214, 64: 11.2477501079486, 65: 11.2922702080532, 66: 11.4197321685286,
         67: 11.5962821317582, 68: 11.6222305981642, 69: 11.7874228106513, 70: 11.9618324383145, 71: 11.9793674029764,
         72: 12.186070184026, 73: 12.3113574518918, 74: 12.3946576665744, 75: 12.6094501901427, 76: 12.6710955942473,
         77: 12.8327855532848, 78: 13.0413452932343, 79: 13.0534294585395, 80: 13.2880850407909, 81: 13.4224136967745,
         82: 13.5207197001071, 83: 13.7558934862954, 84: 13.8146169276589, 85: 13.9984509541419, 86: 14.2182803457936,
         87: 14.2344206854518, 88: 14.4828403699356, 89: 14.6337388181085, 90: 14.7256415186232, 91: 14.9707626094295,
         92: 15.0613369963527, 93: 15.218090804844, 94: 15.4594340073366, 95: 15.5014296030072, 96: 15.7088157092598,
         97: 15.9460750909382, 98: 15.9543817255518, 99: 16.1947533625517, 100: 16.420569119331, 101: 16.4284025580109,
         102: 16.6723144048113, 103: 16.8998887450413, 104: 16.9003785192685, 105: 17.1368906622237,
         106: 17.3578339726355, 107: 17.3942079606915, 108: 17.5822351722934, 109: 17.7940380875525,
         110: 17.9024671095283, 111: 17.9996480915596, 112: 18.1981458500566, 113: 18.3804259383012,
         114: 18.425577602155, 115: 18.5554715857039, 116: 18.7138102856635, 117: 18.8514401833382,
         118: 18.963973395172, 119: 18.966700860678, 120: 19.0585111435479, 121: 19.1159679278116,
         122: 19.1318372095749, 123: 19.0954919860599, 124: 18.9918009344872, 125: 18.963973395172,
         126: 18.7936544882266, 127: 18.4669710407181, 128: 18.425577602155, 129: 17.9339326784246,
         130: 17.9024671095283, 131: 17.3942079606915, 132: 17.0395973380469, 133: 16.9003785192685,
         134: 16.420569119331, 135: 15.9543817255518, 136: 15.5014296030072, 137: 15.4350168426122,
         138: 15.0613369963527, 139: 14.6337388181085, 140: 14.2182803457936, 141: 13.8146169276589,
         142: 13.4224136967745, 143: 13.0413452932343, 144: 12.6710955942473, 145: 12.3658511338686,
         146: 12.3113574518918, 147: 11.9618324383145, 148: 11.6222305981642, 149: 11.2922702080532,
         150: 10.9716775428487, 151: 10.660186648598, 152: 10.3575391219018, 153: 10.1849245475589,
         154: 10.0634838955504, 155: 9.77777703024555, 156: 9.50018151223653, 157: 9.23046705670012,
         158: 8.96840991670359, 159: 8.71379269759095, 160: 8.46640417663894, 161: 8.22603912783307,
         162: 8.15049806378418, 163: 7.99249815161836, 164: 7.76558750948349, 165: 7.5876613113487,
         166: 7.5451189632412, 167: 7.33090961887164, 168: 7.21421517654408, 169: 7.122781774799, 170: 6.92056277447568,
         171: 6.91414118668846, 172: 6.72408486315167, 173: 6.66651846171336, 174: 6.53318504871027,
         175: 6.44969588753724, 176: 6.34770496645481, 177: 6.25729024170078, 178: 6.16749074773405,
         179: 6.08461542904594, 180: 5.99239289229746, 181: 5.92822603501731, 182: 5.82226614427434,
         183: 5.78559506424574, 184: 5.65696937167391, 185: 5.65488474334548, 186: 5.53537979138176,
         187: 5.49636544930654, 188: 5.42460611691967, 189: 5.34032114502884, 190: 5.32177792086222,
         191: 5.22636023200718, 192: 5.1887070092183, 193: 5.1369645546377, 194: 5.05319571305473,
         195: 5.04139726738582, 196: 4.97377395837462, 197: 4.89869878933086, 198: 4.89826971583701,
         199: 4.82617505362061, 200: 4.7592056202957, 201: 4.75695568870926, 202: 4.68876961462411,
         203: 4.6240896174056, 204: 4.62307121030388, 205: 4.55705066903131, 206: 4.49303061431399,
         207: 4.49280961902834, 208: 4.42766121294793, 209: 4.36525671925856, 210: 4.36404423380843,
         211: 4.29849906691897, 212: 4.2413251040789, 213: 4.23447687589484, 214: 4.1686001052406,
         215: 4.12091196357984, 216: 4.10378080518672, 217: 4.03784250133153, 218: 4.00391740667176,
         219: 3.97210866293954, 220: 3.90658042098374, 221: 3.89024437821833, 222: 3.83995824230818,
         223: 3.77979857852248, 224: 3.77488654490415, 225: 3.70786489155597, 226: 3.67248838509824,
         227: 3.64176013923381, 228: 3.57619779028306, 229: 3.56822477666353, 230: 3.50903275048294,
         231: 3.46692125929076, 232: 3.44288059716607, 233: 3.37673700904274, 234: 3.36849379465413,
         235: 3.30905307707228, 236: 3.27286073031397, 237: 3.24181103871272, 238: 3.17994273198035,
         239: 3.17474803289724, 240: 3.10587507215188, 241: 3.08966271769975, 242: 3.03630999502158,
         243: 3.00194579391022, 244: 2.96626369266523, 245: 2.91671919331197, 246: 2.8954788724198,
         247: 2.83391221450178, 248: 2.82374976094102, 249: 2.7534561633213, 250: 2.7509695927754,
         251: 2.67704361711576, 252: 2.67528429587045, 253: 2.60239408999178, 254: 2.5993317631387,
         255: 2.52755206367401, 256: 2.52553555720827, 257: 2.45383445898474, 258: 2.45298714062796,
         259: 2.38416898741148, 260: 2.3792872748074, 261: 2.316481350126, 262: 2.30735069431472, 263: 2.25071539551716,
         264: 2.237913058849, 265: 2.18681656614349, 266: 2.1715902693703, 267: 2.12473185347398, 268: 2.10883142539112,
         269: 2.06440975391383, 270: 2.04990575146005, 271: 2.00580022607863, 272: 1.99491861469886,
         273: 1.94885464928151, 274: 1.94384601168838, 275: 1.89662153545764, 276: 1.89352578319895,
         277: 1.85314875801326, 278: 1.83976772868159, 279: 1.81315015157017, 280: 1.78753588967771,
         281: 1.77641930550227, 282: 1.74290076487741, 283: 1.73678693623769, 284: 1.71252585772935,
         285: 1.68747876856882, 286: 1.68489577860397, 287: 1.66040527166803, 288: 1.63957048211055,
         289: 1.63845430978278, 290: 1.61971432952126, 291: 1.6036996358498, 292: 1.59302233360134,
         293: 1.5906676452449, 294: 1.58130263514235, 295: 1.57562313323595, 296: 1.57431112219662,
         297: 1.57840186360026, 298: 1.5894292393968, 299: 1.59302233360134, 300: 1.61189058468799,
         301: 1.63957048211055, 302: 1.65183559304712, 303: 1.68747876856882, 304: 1.73266225569473,
         305: 1.73678693623769, 306: 1.78753588967771, 307: 1.83976772868159, 308: 1.89352578319895,
         309: 1.94885464928151, 310: 2.00580022607863, 311: 2.04674479981759, 312: 2.06440975391383,
         313: 2.12473185347398, 314: 2.18681656614349, 315: 2.25071539551716, 316: 2.316481350126,
         317: 2.38416898741148, 318: 2.45383445898474, 319: 2.52553555720827, 320: 2.5993317631387,
         321: 2.67528429587045, 322: 2.7534561633213, 323: 2.83391221450178, 324: 2.91671919331197,
         325: 3.00194579391022, 326: 3.08966271769975, 327: 3.17994273198035, 328: 3.18392576617056,
         329: 3.27286073031397, 330: 3.36849379465413, 331: 3.46692125929076, 332: 3.56822477666353,
         333: 3.57185201375658, 334: 3.67248838509824, 335: 3.77979857852248, 336: 3.89024437821833,
         337: 4.00391740667176, 338: 4.12091196357984, 339: 4.2413251040789, 340: 4.36525671925856,
         341: 4.49280961902834, 342: 4.49351323333295, 343: 4.6240896174056, 344: 4.74111350916008,
         345: 4.7592056202957, 346: 4.89826971583701, 347: 4.92828849564327, 348: 5.04139726738582,
         349: 5.1887070092183, 350: 5.28654970714342, 351: 5.34032114502884},
        {2: 18.5346146583417, 3: 18.5483257574147, 4: 18.5592596520698, 5: 18.6427457768891, 6: 18.8003031445349,
         7: 19.0063825809515, 8: 19.0538318619289, 9: 19.2710119592922, 10: 19.5615835668407, 11: 19.5740159000336,
         12: 19.9322529159194, 13: 20.0828659775815, 14: 20.3338189326587, 15: 20.6180396640884, 16: 20.7810644120003,
         17: 21.1674748048643, 18: 21.2780240863052, 19: 21.7315514430298, 20: 21.8294535977783, 21: 22.310659749198,
         22: 22.4409316229642, 23: 22.9052002913551, 24: 23.1189864273286, 25: 23.515584311932, 26: 23.8712509566894,
         27: 24.1422340122601, 28: 24.7066515020632, 29: 24.7855828446069, 30: 25.446075811994, 31: 25.6545957003037,
         32: 26.124169776005, 33: 26.7248737104939, 34: 26.8203337727953, 35: 27.5350493375237, 36: 27.9704448593852,
         37: 28.2688108374293, 38: 29.0221258137838, 39: 29.4369367824444, 40: 29.7955153329575, 41: 30.5895143468389,
         42: 31.2241937524276, 43: 31.4046720628605, 44: 32.2415523238842, 45: 33.10073399821, 46: 33.5210013296314,
         47: 33.9828113799781, 48: 34.8883946002413, 49: 35.8181100489906, 50: 36.5161557048509, 51: 36.7726008084284,
         52: 37.7525270977868, 53: 38.7585667300001, 54: 39.7914155805463, 55: 39.8993127499471, 56: 40.8517880687828,
         57: 41.940417652109, 58: 42.9634544510113, 59: 43.0580573332967, 60: 44.2054801813409, 61: 45.3834798661899,
         62: 45.6573978031958, 63: 46.5928712077252, 64: 47.8344907393705, 65: 48.1678753678368, 66: 49.1091972867202,
         67: 50.4178725615873, 68: 50.6035333947043, 69: 51.7614217718813, 70: 53.0178455417349, 71: 53.1407742477391,
         72: 54.5568840843401, 73: 55.4417419595939, 74: 56.0107308018524, 75: 57.5033200229644, 76: 57.9384876782232,
         77: 59.0356841684718, 78: 60.5263399507803, 79: 60.6088831714014, 80: 62.2240052101638, 81: 63.2020136177451,
         82: 63.8821674612451, 83: 65.5845168719542, 84: 66.0260219656851, 85: 67.332230953765, 86: 69.010657894626,
         87: 69.126518596798, 88: 70.9686209060069, 89: 72.1734238719045, 90: 72.8598120596489, 91: 74.8014001906303,
         92: 75.5647922668326, 93: 76.79472829134, 94: 78.8411751425937, 95: 79.2179309058659, 96: 80.9421562673346,
         97: 83.0991249097467, 98: 83.1790549757745, 99: 85.3135730404613, 100: 87.5167829846199, 101: 87.5870323885498,
         102: 89.9210755010172, 103: 92.31731683053, 104: 92.3228654455692, 105: 94.777413852129, 106: 97.3030682097021,
         107: 97.756336149543, 108: 99.8960268930071, 109: 102.558083446061, 110: 104.062866942687,
         111: 105.291079207731, 112: 108.096904585383, 113: 110.977500362476, 114: 111.795703082567,
         115: 113.934859040994, 116: 116.971026219657, 117: 120.088102008857, 118: 123.219384938984,
         119: 123.288242483301, 120: 126.573661173362, 121: 129.946630596175, 122: 133.409483827529,
         123: 136.964616115652, 124: 140.614486538004, 125: 141.214280462147, 126: 144.361619702206,
         127: 148.208607492314, 128: 148.584818466617, 129: 152.158110861617, 130: 152.347265907474,
         131: 154.861525633332, 132: 156.212861673211, 133: 156.71339601128, 134: 158.162310464527,
         135: 159.315699941219, 136: 160.255252321119, 137: 160.375664589626, 138: 161.089573812608,
         139: 161.810457488296, 140: 162.433401638876, 141: 162.977246548762, 142: 163.458721343423,
         143: 163.894985841352, 144: 164.305233786124, 145: 164.649399012803, 146: 164.717267958861,
         147: 165.184126281383, 148: 165.698879351543, 149: 166.284663941135, 150: 166.956547440465, 151: 167.715313488,
         152: 168.541018664967, 153: 169.037021075769, 154: 169.409304342788, 155: 170.244020805502,
         156: 170.920226192068, 157: 171.348577852283, 158: 171.45623103436, 159: 171.195918488889,
         160: 170.54663966184, 161: 169.507289439468, 162: 169.037021075769, 163: 168.101472409844,
         164: 166.347438210439, 165: 164.649399012802, 166: 164.260403327118, 167: 161.887037856884,
         168: 160.375664589626, 169: 159.231149718347, 170: 156.317703745458, 171: 156.212861673211,
         172: 153.183731390577, 173: 152.158110861617, 174: 149.825246347241, 175: 148.208607492314,
         176: 146.257413637224, 177: 144.361619702206, 178: 142.48990748679, 179: 140.614486538004,
         180: 138.527030698796, 181: 136.964616115652, 182: 134.367650882387, 183: 133.409483827529,
         184: 130.004937798644, 185: 129.946630596175, 186: 126.573661173362, 187: 125.454345375679,
         188: 123.288242483301, 189: 120.68546069861, 190: 120.088102008857, 191: 116.971026219657,
         192: 115.720460403417, 193: 113.934859040994, 194: 110.977500362476, 195: 110.561999165265,
         196: 108.096904585383, 197: 105.291079207731, 198: 105.275398128477, 199: 102.558083446061,
         200: 99.9845058807835, 201: 99.8960268930071, 202: 97.3030682097021, 203: 94.8173273554242,
         204: 94.777413852129, 205: 92.31731683053, 206: 89.9210755010172, 207: 89.9133357151493, 208: 87.5870323885498,
         209: 85.3574301388732, 210: 85.3135730404613, 211: 83.0991249097467, 212: 81.1746050995648,
         213: 80.9421562673346, 214: 78.8411751425937, 215: 77.337226405485, 216: 76.79472829134, 217: 74.8014001906303,
         218: 73.7991922056199, 219: 72.8598120596489, 220: 70.9686209060069, 221: 70.5152492085473,
         222: 69.126518596798, 223: 67.4663653987279, 224: 67.332230953765, 225: 65.5845168719542,
         226: 64.6672287864417, 227: 63.8821674612451, 228: 62.2240052101638, 229: 62.0290454133176,
         230: 60.6088831714014, 231: 59.5989652528256, 232: 59.0356841684718, 233: 57.5033200229644,
         234: 57.3172298078787, 235: 56.0107308018524, 236: 55.2174846438863, 237: 54.5568840843401,
         238: 53.247282245023, 239: 53.1407742477391, 240: 51.7614217718813, 241: 51.4402157814242,
         242: 50.4178725615873, 243: 49.7648505997883, 244: 49.1091972867202, 245: 48.2083139384234,
         246: 47.8344907393705, 247: 46.7642534823783, 248: 46.5928712077252, 249: 45.4237485241284,
         250: 45.3834798661899, 251: 44.2054801813409, 252: 44.1778141113918, 253: 43.0580573332967,
         254: 43.0115526565603, 255: 41.940417652109, 256: 41.9106539047899, 257: 40.8641301036526,
         258: 40.8517880687828, 259: 39.8621229801342, 260: 39.7914155805463, 261: 38.8913657595372,
         262: 38.7585667300001, 263: 37.9413309467399, 264: 37.7525270977868, 265: 37.0024204297233,
         266: 36.7726008084284, 267: 36.0658538270208, 268: 35.8181100489906, 269: 35.1234764221877,
         270: 34.8883946002413, 271: 34.1675111889285, 272: 33.9828113799782, 273: 33.190271935908, 274: 33.10073399821,
         275: 32.2415523238842, 276: 32.1838837955861, 277: 31.4046720628605, 278: 31.1380257154108,
         279: 30.5895143468389, 280: 30.0410000303635, 281: 29.7955153329575, 282: 29.0221258137838,
         283: 28.8735339957818, 284: 28.2688108374293, 285: 27.6049556013819, 286: 27.5350493375237,
         287: 26.8203337727953, 288: 26.1600537189751, 289: 26.124169776005, 290: 25.446075811994,
         291: 24.7855828446069, 292: 24.2590522386749, 293: 24.1422340122601, 294: 23.515584311932,
         295: 22.9052002913551, 296: 22.310659749198, 297: 21.7315514430298, 298: 21.1674748048643,
         299: 21.0605104723387, 300: 20.6180396640884, 301: 20.2142110004061, 302: 20.0828659775815,
         303: 19.8023620546137, 304: 19.5615835668407, 305: 19.5437091773956, 306: 19.3824185954778,
         307: 19.2694836134055, 308: 19.1890296823883, 309: 19.1295243687017, 310: 19.0824825572215,
         311: 19.0538318619289, 312: 19.0418736959721, 313: 19.0032930956343, 314: 18.963692354111,
         315: 18.9221225956964, 316: 18.8791037917453, 317: 18.836474748774, 318: 18.7971014449125,
         319: 18.7644535531438, 320: 18.7421132584904, 321: 18.7333126439571, 322: 18.7405902426296,
         323: 18.7656178425928, 324: 18.8091961447602, 325: 18.8713757211706, 326: 18.9516402908624,
         327: 19.0490908578658, 328: 19.0538318619289, 329: 19.1591841773638, 330: 19.2818310533418,
         331: 19.4151488120489, 332: 19.5567922041104, 333: 19.5615835668407, 334: 19.6963623937742,
         335: 19.8346051133214, 336: 19.9661384088698, 337: 20.0828659775815, 338: 20.1663243940735,
         339: 20.208768370942, 340: 20.1898235841378, 341: 20.083891860472, 342: 20.0828659775815,
         343: 19.8545550101623, 344: 19.5615835668407, 345: 19.5129643508115, 346: 19.1276820183823,
         347: 19.0538318619289, 348: 18.8156897268304, 349: 18.6162406178927, 350: 18.5592596520698,
         351: 18.5346146583417}
    ],
    'Diabase': [
        {2: 9.30622997721815, 3: 9.42356076671131, 4: 9.54237083559009, 5: 9.66267883426594, 6: 9.66639845447479,
         7: 9.78450364829038, 8: 9.90786440131959, 9: 10.0327804581164, 10: 10.1592714275899, 11: 10.2873571658741,
         12: 10.3470874902809, 13: 10.4170577794443, 14: 10.5483936282735, 15: 10.6813853290288, 16: 10.8160537583072,
         17: 10.8816823765577, 18: 10.9524200559132, 19: 11.0905056281768, 20: 11.2303321513143, 21: 11.3598277173031,
         22: 11.3719215748305, 23: 11.5152961249648, 24: 11.6604783081794, 25: 11.7744247147784, 26: 11.807490914693,
         27: 11.9563570220583, 28: 12.107099998784, 29: 12.1408690719347, 30: 12.2597435080039, 31: 12.414311511191,
         32: 12.4719781934551, 33: 12.5708282719188, 34: 12.7293183596705, 35: 12.779165227236, 36: 12.8898066536957,
         37: 13.0523183469157, 38: 13.0693484804452, 39: 13.2168789498783, 40: 13.3461117711836, 41: 13.3835142947624,
         42: 13.5522505394331, 43: 13.6142852215973, 44: 13.7231141715477, 45: 13.87630241257, 46: 13.8961320127136,
         47: 14.0713312226992, 48: 14.1338252007691, 49: 14.2487393036967, 50: 14.3885591572804, 51: 14.4283841046394,
         52: 14.6102938255739, 53: 14.6419473057778, 54: 14.7944970220862, 55: 14.8950641344528, 56: 14.9810226097844,
         57: 15.1481266651601, 58: 15.1698998688382, 59: 15.3611584485746, 60: 15.4031376367561, 61: 15.5548283721326,
         62: 15.6600805360602, 63: 15.7509400411759, 64: 15.9186082292861, 65: 15.9495242406653, 66: 16.1506121436914,
         67: 16.1806103551147, 68: 16.3542353163678, 69: 16.4465866675345, 70: 16.5604257227863, 71: 16.7150134559877,
         72: 16.7692157300345, 73: 16.980638113277, 74: 16.9863607603529, 75: 17.1947260608998, 76: 17.2642830932305,
         77: 17.4115131797205, 78: 17.5448419997761, 79: 17.6310335002637, 80: 17.8279410549548, 81: 17.8533214821028,
         82: 18.0784120192697, 83: 18.116497692393, 84: 18.306340445732, 85: 18.4094949405355, 86: 18.5371425409398,
         87: 18.7045197026662, 88: 18.7708545354425, 89: 19.001344427965, 90: 19.0075131165753, 91: 19.2471554342194,
         92: 19.3047849793563, 93: 19.4898191066327, 94: 19.6099531781602, 95: 19.7355422263556, 96: 19.9159940458847,
         97: 19.9843633661901, 98: 20.222659410288, 99: 20.2363215852556, 100: 20.4914564351194, 101: 20.5335717666535,
         102: 20.749807966006, 103: 20.845664687921, 104: 21.0114167330838, 105: 21.1573376461832,
         106: 21.2763238028315, 107: 21.4683995988678, 108: 21.5445707594841, 109: 21.7786807760929,
         110: 21.8161997115614, 111: 22.0880306182489, 112: 22.0912532984773, 113: 22.3697746972337,
         114: 22.3990152666808, 115: 22.6518076291982, 116: 22.7086285305113, 117: 22.9373963669671,
         118: 23.0164264744696, 119: 23.2265857413155, 120: 23.3222993311528, 121: 23.5194211482343,
         122: 23.6261357788552, 123: 23.8159485560568, 124: 23.9278171917928, 125: 24.1162145126742,
         126: 24.227211679971, 127: 24.4202661528427, 128: 24.5241679691846, 129: 24.7281512055827,
         130: 24.8185091745224, 131: 25.0399180016709, 132: 25.1100265284618, 133: 25.3556154812273,
         134: 25.3984731379798, 135: 25.6752932013976, 136: 25.6835578645774, 137: 25.9678867102389,
         138: 25.9990013441324, 139: 26.2494724561629, 140: 26.3267907240648, 141: 26.527139465365,
         142: 26.658712796487, 143: 26.8003586635167, 144: 26.9948196654276, 145: 27.0685207602127,
         146: 27.3312620134367, 147: 27.3351640918305, 148: 27.5939333020041, 149: 27.6797995018377,
         150: 27.8497572900673, 151: 28.0287799951753, 152: 28.097697639652, 153: 28.3397361212014,
         154: 28.3821603536464, 155: 28.5768092218538, 156: 28.7399960497304, 157: 28.8025166957248,
         158: 29.0204398169727, 159: 29.1023432552905, 160: 29.2276815331485, 161: 29.4209231171552,
         162: 29.4692588503922, 163: 29.6022722732158, 164: 29.7656217209027, 165: 29.8408004322314,
         166: 29.9108311326098, 167: 30.0357166801145, 168: 30.1347444660765, 169: 30.2056957768941,
         170: 30.2170263241761, 171: 30.2478284416993, 172: 30.2571374871976, 173: 30.2323835658779,
         174: 30.2170263241761, 175: 30.1779921760415, 176: 30.0997184512705, 177: 30.0045282886968,
         178: 29.9022597091684, 179: 29.8408004322314, 180: 29.807117766614, 181: 29.7296769653919,
         182: 29.6688790461867, 183: 29.627377078131, 184: 29.6056568744086, 185: 29.6026054571212,
         186: 29.6161154341051, 187: 29.6435893210427, 188: 29.6822944308765, 189: 29.7295753965635,
         190: 29.78295594858, 191: 29.8401650030443, 192: 29.8408004322314, 193: 29.9030394602246,
         194: 29.9648316187302, 195: 30.0235087871221, 196: 30.0771269214761, 197: 30.1236848043596,
         198: 30.1610139928317, 199: 30.1866487805087, 200: 30.19766399004, 201: 30.1904632173878,
         202: 30.1604925250352, 203: 30.1018426416607, 204: 30.0066833909028, 205: 29.8644419850273,
         206: 29.8408004322314, 207: 29.6497418119162, 208: 29.4692588503922, 209: 29.324710493533,
         210: 29.1023432552905, 211: 28.7667062251594, 212: 28.7399960497304, 213: 28.3821603536464,
         214: 28.0287799951753, 215: 27.6797995018377, 216: 27.3351640918305, 217: 26.9948196654276,
         218: 26.658712796487, 219: 26.3267907240648, 220: 25.9990013441324, 221: 25.6752932013976,
         222: 25.5049907551247, 223: 25.3556154812273, 224: 25.0399180016709, 225: 24.7281512055827,
         226: 24.4202661528427, 227: 24.1162145126742, 228: 23.9033904324873, 229: 23.8159485560568,
         230: 23.5194211482343, 231: 23.2265857413155, 232: 22.9373963669671, 233: 22.6518076291982,
         234: 22.3697746972337, 235: 22.0912532984773, 236: 21.8161997115614, 237: 21.5445707594841,
         238: 21.2763238028315, 239: 21.0114167330838, 240: 20.749807966006, 241: 20.4914564351194,
         242: 20.2363215852556, 243: 19.9843633661901, 244: 19.7355422263556, 245: 19.4898191066327,
         246: 19.2471554342194, 247: 19.1189221566749, 248: 19.0075131165753, 249: 18.7708545354425,
         250: 18.5371425409398, 251: 18.4569271080283, 252: 18.306340445732, 253: 18.0784120192697,
         254: 17.9704562061751, 255: 17.8533214821028, 256: 17.6310335002637, 257: 17.5685043883724,
         258: 17.4115131797205, 259: 17.2201812393627, 260: 17.1947260608998, 261: 16.980638113277,
         262: 16.9117521044488, 263: 16.7692157300345, 264: 16.6316878487716, 265: 16.5604257227863,
         266: 16.3741985693998, 267: 16.3542353163678, 268: 16.1506121436914, 269: 16.1366780785321,
         270: 15.9495242406653, 271: 15.9159647871092, 272: 15.7509400411759, 273: 15.7091949427551,
         274: 15.5548283721326, 275: 15.5147768544677, 276: 15.3611584485746, 277: 15.3313958772329,
         278: 15.1698998688382, 279: 15.1579691935662, 280: 14.9939105992445, 281: 14.9810226097844,
         282: 14.8385170810542, 283: 14.7944970220862, 284: 14.6908589701187, 285: 14.6102938255739,
         286: 14.5504644592864, 287: 14.4283841046394, 288: 14.4169798949827, 289: 14.2909662297952,
         290: 14.2487393036967, 291: 14.1716470440737, 292: 14.0713312226992, 293: 14.0587555172816,
         294: 13.9534866536893, 295: 13.8961320127136, 296: 13.8551583956337, 297: 13.7646817339867,
         298: 13.7231141715477, 299: 13.6826217508954, 300: 13.60992598473, 301: 13.5522505394331, 302: 13.547317076861,
         303: 13.4971579035865, 304: 13.460287374177, 305: 13.4388653924234, 306: 13.4348514172452,
         307: 13.4495216357018, 308: 13.4829464192109, 309: 13.5335787448374, 310: 13.5522505394331,
         311: 13.595447761879, 312: 13.6636786880547, 313: 13.7231141715477, 314: 13.7332299533771,
         315: 13.7954841089545, 316: 13.8507243809098, 317: 13.8961320127136, 318: 13.9271682922044,
         319: 13.946201725057, 320: 13.9528719440284, 321: 13.9473366158933, 322: 13.9301744991338,
         323: 13.9022858206006, 324: 13.8961320127136, 325: 13.8620702636687, 326: 13.8122397579803,
         327: 13.7547546497842, 328: 13.7231141715477, 329: 13.6881500960657, 330: 13.613440840919,
         331: 13.5522505394331, 332: 13.5332192506871, 333: 13.4446154428609, 334: 13.3835142947624,
         335: 13.35168117654, 336: 13.2526260062694, 337: 13.2168789498783, 338: 13.1482241856379,
         339: 13.0523183469157, 340: 13.0409845878648, 341: 12.9274687165053, 342: 12.8898066536957,
         343: 12.8103733100167, 344: 12.7293183596705, 345: 12.6905580480031, 346: 12.5708282719187,
         347: 12.5679815671976, 348: 12.4404258326285, 349: 12.414311511191, 350: 12.3102429989694,
         351: 12.2597435080039, 352: 12.1776763258757, 353: 12.107099998784, 354: 12.0427671251963,
         355: 11.9563570220583, 356: 11.9055735260553, 357: 11.807490914693, 358: 11.7661659952626,
         359: 11.6604783081794, 360: 11.6246211665002, 361: 11.5152961249648, 362: 11.481014500668,
         363: 11.3719215748305, 364: 11.3354124097248, 365: 11.2303321513143, 366: 11.1878645368414,
         367: 11.0905056281768, 368: 11.0383969117137, 369: 10.9524200559132, 370: 10.8870067182424,
         371: 10.8160537583072, 372: 10.7336594565128, 373: 10.6813853290288, 374: 10.5782893881935,
         375: 10.5483936282735, 376: 10.4208043567047, 377: 10.4170577794443, 378: 10.2873571658741,
         379: 10.2587167245548, 380: 10.1592714275899, 381: 10.0936218483351, 382: 10.0327804581164,
         383: 9.92585363786453, 384: 9.90786440131959, 385: 9.78450364829038, 386: 9.75301916201566,
         387: 9.66267883426594, 388: 9.57655562198205, 389: 9.54237083559009, 390: 9.42356076671131,
         391: 9.39767796014839, 392: 9.30622997721815, 393: 9.21841515098697, 394: 9.19036004891153,
         395: 9.07593279291352, 396: 9.04353335104258, 397: 8.96293024681214, 398: 8.87747971859691,
         399: 8.85133467184164, 400: 8.74112855009794, 401: 8.72432276975288, 402: 8.63229458178872,
         403: 8.58643316268162, 404: 8.5248156825178, 405: 8.46306051290545, 406: 8.41867498060321,
         407: 8.35381330346294, 408: 8.31385581442881, 409: 8.25779154586802, 410: 8.21034172982873,
         411: 8.17377814264126, 412: 8.10811647750454, 413: 8.10042084376189, 414: 8.04014250078349,
         415: 8.00716401047438, 416: 7.98987834398342, 417: 7.95270146878448, 418: 7.92756900786537,
         419: 7.91812731577281, 420: 7.92894513297932, 421: 7.96523620594774, 422: 8.00716401047438,
         423: 8.03514753424916, 424: 8.10811647750454, 425: 8.14960880927394, 426: 8.21034172982873,
         427: 8.3053366705065, 428: 8.31385581442881, 429: 8.41867498060321, 430: 8.4818544269385, 431: 8.5248156825178,
         432: 8.63229458178872, 433: 8.6660844593301, 434: 8.74112855009794, 435: 8.85133467184164,
         436: 8.87536264987121, 437: 8.96293024681214, 438: 9.07593279291352, 439: 9.19036004891153,
         440: 9.25752345119452, 441: 9.30622997721815},
        {2: 87.8119729779413, 3: 87.7461688063663, 4: 87.7747741159554, 5: 87.8789043258244, 6: 87.8841980666456,
         7: 88.0493613709087, 8: 88.2657484826081, 9: 88.5153999413336, 10: 88.7890395986142, 11: 89.0802579742351,
         12: 89.2247249237774, 13: 89.3915680718595, 14: 89.7194284147485, 15: 90.0573562502711, 16: 90.4066868400885,
         17: 90.5856992822146, 18: 90.7753480537008, 19: 91.1645653973009, 20: 91.5722505145217, 21: 91.9674330344847,
         22: 92.0035774676607, 23: 92.4680048176983, 24: 92.9602680641381, 25: 93.3702428305155, 26: 93.4863740629318,
         27: 94.0497403644486, 28: 94.6499562649273, 29: 94.7944501502012, 30: 95.290010090206, 31: 95.970242673151,
         32: 96.2403813770757, 33: 96.6914235883436, 34: 97.4544425536087, 35: 97.7083678731093, 36: 98.2575058670668,
         37: 99.1053573031133, 38: 99.1987460546464, 39: 99.9875092188641, 40: 100.711857469502, 41: 100.916302879156,
         42: 101.879011990427, 43: 102.248048875232, 44: 102.880028784292, 45: 103.807672318603, 46: 103.924913601404,
         47: 104.995499242436, 48: 105.391085216265, 49: 106.102090198709, 50: 106.998650436665, 51: 107.248300782946,
         52: 108.421538268983, 53: 108.630736383202, 54: 109.617518352064, 55: 110.287717078653, 56: 110.848489944345,
         57: 111.969972250892, 58: 112.113050892395, 59: 113.391702007151, 60: 113.677887419906, 61: 114.691671386479,
         62: 115.411853986146, 63: 116.021549137316, 64: 117.172269320226, 65: 117.380450593713, 66: 118.75260482163,
         67: 118.959536853983, 68: 120.136183694851, 69: 120.774066172938, 70: 121.547107796377, 71: 122.616273110151,
         72: 122.985152144996, 73: 124.447060069191, 74: 124.486579841527, 75: 125.904484676944, 76: 126.385414982555,
         77: 127.389679135534, 78: 128.313213686543, 79: 128.902987196024, 80: 130.270417744333, 81: 130.444794899347,
         82: 131.994071539524, 83: 132.257475685553, 84: 133.558542924242, 85: 134.2748428814, 86: 135.154754292048,
         87: 136.322981648999, 88: 136.783487033457, 89: 138.402361357353, 90: 138.445545322216, 91: 140.109706706097,
         92: 140.513458534906, 93: 141.807827511875, 94: 142.656756978748, 95: 143.54492919399, 96: 144.832747865486,
         97: 145.322245424926, 98: 147.041929863809, 99: 147.141093421513, 100: 148.980423922189, 101: 149.284809248764,
         102: 150.859644331083, 103: 151.561900017778, 104: 152.788850389035, 105: 153.873724008453,
         106: 154.770039874181, 107: 156.220811018154, 108: 156.805410637873, 109: 158.60369892542,
         110: 158.897394067226, 111: 161.02293381323, 112: 161.048690019831, 113: 163.24889888845,
         114: 163.479070094146, 115: 165.516814414013, 116: 165.972670637374, 117: 167.857718541905,
         118: 168.504306897747, 119: 170.275565703948, 120: 171.074559046689, 121: 172.774723660595,
         122: 173.684016105171, 123: 175.360011826828, 124: 176.333276078698, 125: 178.036740971662,
         126: 179.022946094351, 127: 180.810754777062, 128: 181.753642539921, 129: 183.688474045711,
         130: 184.525991205167, 131: 186.676944805089, 132: 187.340627425228, 133: 189.783892209866,
         134: 190.19819622622, 135: 193.017783037736, 136: 193.099352473056, 137: 196.044761019523,
         138: 196.386461721275, 139: 199.035096860642, 140: 199.905429764223, 141: 202.071045287357,
         142: 203.588620188859, 143: 205.153302043582, 144: 207.450755549569, 145: 208.282573485647,
         146: 211.459576744166, 147: 211.510008870023, 148: 214.685039888386, 149: 215.824139687822,
         150: 217.959702093035, 151: 220.39732731703, 152: 221.284313807721, 153: 224.659636928907,
         154: 225.304896847807, 155: 228.086444974516, 156: 230.645792464919, 157: 231.565523261198,
         158: 235.097669084296, 159: 236.575118503953, 160: 238.683691900565, 161: 242.324413513676,
         162: 243.365019258775, 163: 246.020668262538, 164: 249.773303212513, 165: 251.822450056704,
         166: 253.583178349532, 167: 257.451166777174, 168: 261.378154916759, 169: 265.365042710487,
         170: 266.530040093816, 171: 269.412743827673, 172: 273.522185874134, 173: 277.694310604767,
         174: 278.860027580334, 175: 281.930074139368, 176: 286.230447181748, 177: 290.596415242184,
         178: 295.028978863268, 179: 297.802823139767, 180: 299.529153849202, 181: 304.097971498586,
         182: 308.736478840759, 183: 313.445738875749, 184: 318.226830817873, 185: 323.080850343064,
         186: 328.008909839965, 187: 333.012138664851, 188: 338.091683400443, 189: 343.248708118669,
         190: 348.484394647434, 191: 353.799942841456, 192: 353.857462794306, 193: 359.196570857234,
         194: 364.675515432215, 195: 370.238032168211, 196: 375.885395819145, 197: 381.618900583188,
         198: 387.439860399342, 199: 393.349609248559, 200: 399.349501459445, 201: 405.440912018629,
         202: 411.625236885869, 203: 417.90389331396, 204: 424.278320173524, 205: 430.749978282756,
         206: 431.576638264347, 207: 437.320350742195, 208: 441.386336092471, 209: 443.990943274605,
         210: 447.230611210748, 211: 450.76328457004, 212: 451.004702846813, 213: 453.364955514967,
         214: 454.789059472357, 215: 455.494006943148, 216: 455.642414632573, 217: 455.357243934621,
         218: 454.732617573231, 219: 453.841945672766, 220: 452.744196890389, 221: 451.488891893992,
         222: 450.76328457004, 223: 450.153022974432, 224: 448.798194368433, 225: 447.429665822918,
         226: 446.086199947409, 227: 444.809026447927, 228: 443.990943274605, 229: 443.664394847738,
         230: 442.718608617588, 231: 441.957168166023, 232: 441.411172380692, 233: 441.101103826665,
         234: 441.030359058609, 235: 441.179532233777, 236: 441.503590107523, 237: 441.933770983436,
         238: 442.384669484471, 239: 442.765005534852, 240: 442.989079202294, 241: 442.98577971157,
         242: 442.703253672532, 243: 442.109102912295, 244: 441.187313944115, 245: 439.933581742992,
         246: 438.350434547877, 247: 437.320350742195, 248: 436.446844866975, 249: 434.238634020971,
         250: 431.731928909953, 251: 430.749978282756, 252: 428.941805930441, 253: 425.883171919113,
         254: 424.278320173524, 255: 422.562157297368, 256: 418.99592586609, 257: 417.90389331396,
         258: 415.189586570123, 259: 411.625236885869, 260: 411.153689150523, 261: 406.899498333287,
         262: 405.440912018629, 263: 402.428159867275, 264: 399.349501459445, 265: 397.750585232291,
         266: 393.349609248559, 267: 392.874895932125, 268: 387.802030831767, 269: 387.439860399342,
         270: 382.532198924134, 271: 381.618900583188, 272: 377.072863228131, 273: 375.885395819145,
         274: 371.426690502235, 275: 370.238032168211, 276: 365.595284906094, 277: 364.675515432215,
         278: 359.57969318751, 279: 359.196570857234, 280: 353.799942841456, 281: 353.363469426866,
         282: 348.484394647434, 283: 346.930382811777, 284: 343.248708118669, 285: 340.291624764867,
         286: 338.091683400443, 287: 333.445118860279, 288: 333.012138664851, 289: 328.008909839965,
         290: 326.254259574871, 291: 323.080850343064, 292: 318.761105355503, 293: 318.226830817873,
         294: 313.445738875749, 295: 310.675114317196, 296: 308.736478840759, 297: 304.097971498586,
         298: 301.751059693973, 299: 299.529153849202, 300: 295.028978863268, 301: 290.933997787764,
         302: 290.596415242184, 303: 286.230447181748, 304: 281.930074139368, 305: 277.694310604767,
         306: 273.522185874134, 307: 269.412743827673, 308: 265.365042710487, 309: 261.378154916759,
         310: 260.231478946246, 311: 257.451166777174, 312: 253.583178349532, 313: 250.374244160611,
         314: 249.773303212513, 315: 246.020668262538, 316: 242.324413513676, 317: 238.683691900565,
         318: 235.097669084296, 319: 231.565523261198, 320: 228.086444974516, 321: 224.659636928907,
         322: 221.284313807721, 323: 217.959702093035, 324: 217.455851296936, 325: 214.685039888386,
         326: 211.459576744166, 327: 208.282573485647, 328: 206.791276030233, 329: 205.153302043582,
         330: 202.071045287357, 331: 199.751460659202, 332: 199.035096860642, 333: 196.044761019523,
         334: 194.102838284085, 335: 193.099352473056, 336: 190.19819622622, 337: 189.213624553655,
         338: 187.340627425228, 339: 184.820630431049, 340: 184.525991205167, 341: 181.753642539921,
         342: 180.868040438826, 343: 179.022946094351, 344: 177.195618994952, 345: 176.333276078698,
         346: 173.744696993581, 347: 173.684016105171, 348: 171.074559046689, 349: 170.552298728129,
         350: 168.504306897747, 351: 167.529685226842, 352: 165.972670637374, 353: 164.656887128295,
         354: 163.479070094146, 355: 161.921075715225, 356: 161.02293381323, 357: 159.310500431957,
         358: 158.60369892542, 359: 156.814587795306, 360: 156.220811018154, 361: 154.423986448704,
         362: 153.873724008453, 363: 152.130569741707, 364: 151.561900017778, 365: 149.927406622046,
         366: 149.284809248764, 367: 147.808710592622, 368: 147.041929863809, 369: 145.769775284065,
         370: 144.832747865486, 371: 143.80690402941, 372: 142.656756978748, 373: 141.917339849124,
         374: 140.513458534906, 375: 140.099201573206, 376: 138.402361357353, 377: 138.351431540926,
         378: 136.676424764021, 379: 136.322981648999, 380: 135.066311832264, 381: 134.2748428814,
         382: 133.520019062043, 383: 132.257475685553, 384: 132.037733369714, 385: 130.615253349263,
         386: 130.270417744333, 387: 129.245269203944, 388: 128.313213686543, 389: 127.927690299433,
         390: 126.652389361024, 391: 126.385414982555, 392: 125.402012508105, 393: 124.486579841527,
         394: 124.179782012718, 395: 122.959314447811, 396: 122.616273110151, 397: 121.721862137664,
         398: 120.774066172938, 399: 120.468171429589, 400: 119.164409030972, 401: 118.959536853983,
         402: 117.778938202137, 403: 117.172269320226, 404: 116.308835451044, 405: 115.411853986146,
         406: 114.724036298952, 407: 113.677887419906, 408: 112.984927646704, 409: 111.969972250892,
         410: 111.038386700581, 411: 110.287717078653, 412: 108.811740064331, 413: 108.630736383202,
         414: 106.998650436665, 415: 105.959572705069, 416: 105.391085216265, 417: 103.807672318603,
         418: 102.248048875232, 419: 100.711857469502, 420: 99.1987460546464, 421: 97.7083678731093,
         422: 96.7552787576289, 423: 96.2403813770757, 424: 95.2696966210209, 425: 94.7944501502012,
         426: 94.2145630737639, 427: 93.3702428305155, 428: 93.3018037812004, 429: 92.4695089127135,
         430: 91.9674330344847, 431: 91.6423070450376, 432: 90.8327701253854, 433: 90.5856992822146,
         434: 90.06151339145, 435: 89.358642545701, 436: 89.2247249237774, 437: 88.7713951007388, 438: 88.3153567687123,
         439: 87.9958268577516, 440: 87.8841980666456, 441: 87.8119729779413}
    ],
    'Flow Rock': [
        {2: 3.39380913663202, 3: 3.46136498537057, 4: 3.5302655746396, 5: 3.60053767232272, 6: 3.60649689274704,
         7: 3.6722085791346, 8: 3.74530613922738, 9: 3.8198587510081, 10: 3.83772621899545, 11: 3.89589537817147,
         12: 3.97344556095226, 13: 4.03902325270737, 14: 4.05253942760174, 15: 4.13320770609242, 16: 4.21548173605595,
         17: 4.24303360019236, 18: 4.29939348095852, 19: 4.3849755405187, 20: 4.46593894577591, 21: 4.4722611633724,
         22: 4.56128425998999, 23: 4.65207941585052, 24: 4.74303455530493, 25: 4.74468190487817, 26: 4.83912770314617,
         27: 4.93545350285354, 28: 5.03369672657995, 29: 5.13389554182447, 30: 5.23608887583357, 31: 5.34031643072443,
         32: 5.44661869890914, 33: 5.55503697882608, 34: 5.66561339098431, 35: 5.77839089432742, 36: 5.84547551525071,
         37: 5.89341330292308, 38: 6.01072530298479, 39: 6.13037247023249, 40: 6.25240128759874, 41: 6.37685916328732,
         42: 6.39527965012721, 43: 6.50379444919133, 44: 6.63325645967792, 45: 6.72713477451366, 46: 6.76529549074691,
         47: 6.89996283957078, 48: 6.95724938244824, 49: 7.03731082442364, 50: 7.15854213984459, 51: 7.17739280500687,
         52: 7.3202632031794, 53: 7.34413373197763, 54: 7.46597752410054, 55: 7.52129242835916, 56: 7.61459237779383,
         57: 7.69401779560526, 58: 7.76616550113995, 59: 7.86386733891086, 60: 7.92075578030756, 61: 8.03195537229933,
         62: 8.07842327363054, 63: 8.19909219639647, 64: 8.23922923494071, 65: 8.3658735241177, 66: 8.40323613736487,
         67: 8.53273952470458, 68: 8.5705076975957, 69: 8.70001465777809, 70: 8.74110890064565, 71: 8.86793497582835,
         72: 8.9151060250936, 73: 9.03666701423543, 74: 9.09256666883416, 75: 9.20632087971487, 76: 9.2735597753394,
         77: 9.37695923177625, 78: 9.45815566044342, 79: 9.54860327929177, 80: 9.64642603966003, 81: 9.72123654703345,
         82: 9.83844405604428, 83: 9.89480692532829, 84: 10.0342843086085, 85: 10.0692273527036, 86: 10.234022881304,
         87: 10.2443753680527, 88: 10.4217330817207, 89: 10.4377373725798, 90: 10.601038993914, 91: 10.6455069255295,
         92: 10.7812271946621, 93: 10.8574122586385, 94: 10.9620994907834, 95: 11.0735356971429, 96: 11.1434181761913,
         97: 11.2939612050132, 98: 11.3249020464492, 99: 11.5075701665573, 100: 11.5187744175742, 101: 11.6938495953296,
         102: 11.7480626747739, 103: 11.8802455206463, 104: 11.981915055116, 105: 12.0663826386859,
         106: 12.2204224102658, 107: 12.2518283957233, 108: 12.4392360815317, 109: 12.4636774003471,
         110: 12.6296450695782, 111: 12.7117745299398, 112: 12.8191275395753, 113: 12.9648101847955,
         114: 13.0071277152569, 115: 13.1964577617459, 116: 13.2228826692833, 117: 13.3892315366165,
         118: 13.4860922445808, 119: 13.5801337071486, 120: 13.7545411676257, 121: 13.7684578300528,
         122: 13.9621150300113, 123: 14.0283337308429, 124: 14.1549731229808, 125: 14.3075763026615,
         126: 14.3446858268792, 127: 14.5373658590649, 128: 14.5923773688396, 129: 14.7311335783996,
         130: 14.8828475746106, 131: 14.9210762278126, 132: 15.1142141483997, 133: 15.1790997676691,
         134: 15.3077503494237, 135: 15.4812490420121, 136: 15.496659847837, 137: 15.691601939557, 138: 15.789412782653,
         139: 15.8836781101194, 140: 16.0735824238808, 141: 16.103710711226, 142: 16.2682935507812,
         143: 16.4242649324974, 144: 16.4576109536646, 145: 16.6513512647966, 146: 16.7511999818039,
         147: 16.8430248984973, 148: 17.0335631992651, 149: 17.0846428734341, 150: 17.2272569528274,
         151: 17.4155585959966, 152: 17.4247231499741, 153: 17.611028480525, 154: 17.7715729326342,
         155: 17.8003466902244, 156: 17.9949559021762, 157: 18.1253269725784, 158: 18.1859561636543,
         159: 18.3794754102044, 160: 18.4861227032751, 161: 18.5718475106968, 162: 18.7646725974567,
         163: 18.85410029389, 164: 18.9578653756, 165: 19.1499837503932, 166: 19.2294027037419, 167: 19.3429571484284,
         168: 19.5337175906793, 169: 19.6121757378423, 170: 19.724573704181, 171: 19.9122992502376,
         172: 20.002568103541, 173: 20.097716238367, 174: 20.2790313430532, 175: 20.4007314682982,
         176: 20.4533406994173, 177: 20.6219330040485, 178: 20.7767747156694, 179: 20.8068205186081,
         180: 20.919685341815, 181: 21.0414814237255, 182: 21.1350617271616, 183: 21.1904133971766,
         184: 21.1900515728918, 185: 21.1020530376907, 186: 20.8636766207791, 187: 20.8068205186081,
         188: 20.4007314682982, 189: 20.1858189770514, 190: 20.002568103541, 191: 19.6121757378423,
         192: 19.2294027037419, 193: 18.85410029389, 194: 18.7390884615101, 195: 18.4861227032751,
         196: 18.1253269725784, 197: 17.7715729326342, 198: 17.5620571713662, 199: 17.4247231499741,
         200: 17.0846428734341, 201: 16.7834436074109, 202: 16.7511999818039, 203: 16.4242649324974,
         204: 16.142675972653, 205: 16.103710711226, 206: 15.789412782653, 207: 15.5736129783325, 208: 15.4812490420121,
         209: 15.1790997676691, 210: 15.0478212413099, 211: 14.8828475746106, 212: 14.5923773688396,
         213: 14.5516157175824, 214: 14.3075763026615, 215: 14.073080823267, 216: 14.0283337308429,
         217: 13.7545411676257, 218: 13.599254981434, 219: 13.4860922445808, 220: 13.2228826692833,
         221: 13.1205584191043, 222: 12.9648101847955, 223: 12.7117745299398, 224: 12.6131259657018,
         225: 12.4636774003471, 226: 12.2204224102658, 227: 12.0104029523997, 228: 11.981915055116,
         229: 11.7480626747739, 230: 11.5187744175742, 231: 11.2939612050132, 232: 11.1357638920856,
         233: 11.0735356971429, 234: 10.9893624702608, 235: 10.9540281909754, 236: 10.9575024778269,
         237: 10.9795267741252, 238: 11.0101135043504, 239: 11.0431281715148, 240: 11.0735356971429,
         241: 11.0936704793667, 242: 11.0965763067185, 243: 11.0735356971429, 244: 11.0696130488863,
         245: 10.9642903617769, 246: 10.8574122586385, 247: 10.6455069255295, 248: 10.4377373725798,
         249: 10.234022881304, 250: 10.046596087416, 251: 10.0342843086085, 252: 9.83844405604428,
         253: 9.70068927734365, 254: 9.64642603966003, 255: 9.45815566044342, 256: 9.42349714459545,
         257: 9.2735597753394, 258: 9.18858668851173, 259: 9.09256666883416, 260: 8.97756330701128,
         261: 8.9151060250936, 262: 8.78588046901575, 263: 8.74110890064565, 264: 8.61010819712056,
         265: 8.5705076975957, 266: 8.44763696462485, 267: 8.40323613736487, 268: 8.29646774778955,
         269: 8.23922923494071, 270: 8.15506091707796, 271: 8.07842327363054, 272: 8.02222598853458,
         273: 7.92075578030756, 274: 7.89704017115429, 275: 7.77980013514963, 276: 7.76616550113995,
         277: 7.67051896401299, 278: 7.61459237779383, 279: 7.56651712833185, 280: 7.46753509109633,
         281: 7.46597752410054, 282: 7.37657107493702, 283: 7.3202632031794, 284: 7.28893432186387,
         285: 7.20657482962857, 286: 7.17739280500687, 287: 7.12866614754328, 288: 7.05362452468001,
         289: 7.03731082442364, 290: 6.98309927691327, 291: 6.91363215493962, 292: 6.89996283957078,
         293: 6.84755214357744, 294: 6.78112485725977, 295: 6.76529549074691, 296: 6.71629210464888,
         297: 6.64985672384252, 298: 6.63325645967792, 299: 6.58341397925864, 300: 6.5141617848279,
         301: 6.50379444919133, 302: 6.4441922742528, 303: 6.37685916328732, 304: 6.37067317122089,
         305: 6.29615657496015, 306: 6.25240128759874, 307: 6.21876736049153, 308: 6.13927014241714,
         309: 6.13037247023249, 310: 6.05870005350895, 311: 6.01072530298479, 312: 5.97631268050092,
         313: 5.89341330292308, 314: 5.89272626576581, 315: 5.80901659899066, 316: 5.77839089432742,
         317: 5.72471499005799, 318: 5.66561339098431, 319: 5.6402672994749, 320: 5.55608798383339,
         321: 5.55503697882608, 322: 5.47266695380419, 323: 5.44661869890914, 324: 5.38987502841365,
         325: 5.34031643072443, 326: 5.30799188221706, 327: 5.23608887583357, 328: 5.22726072156879,
         329: 5.1478618749827, 330: 5.13389554182447, 331: 5.06977534798094, 332: 5.03369672657995,
         333: 4.99312786842938, 334: 4.93545350285354, 335: 4.91805984886173, 336: 4.84463254187944,
         337: 4.83912770314617, 338: 4.77263686962904, 339: 4.74468190487817, 340: 4.70226898454266,
         341: 4.65207941585052, 342: 4.63362707777057, 343: 4.56668540981147, 344: 4.56128425998999,
         345: 4.50104473250663, 346: 4.4722611633724, 347: 4.43709073328573, 348: 4.3849755405187,
         349: 4.37492573325059, 350: 4.3141448733208, 351: 4.29939348095852, 352: 4.25474576994062,
         353: 4.21548173605595, 354: 4.19711681251079, 355: 4.14108088693844, 356: 4.13320770609242,
         357: 4.08613747594753, 358: 4.05253942760174, 359: 4.03299186460494, 360: 3.98145920027552,
         361: 3.97344556095226, 362: 3.93097977146988, 363: 3.89589537817147, 364: 3.88238349913617,
         365: 3.83516624979348, 366: 3.8198587510081, 367: 3.78929310703526, 368: 3.74544138011619,
         369: 3.74530613922738, 370: 3.70244293559259, 371: 3.6722085791346, 372: 3.661449406762, 373: 3.62184062268702,
         374: 3.60053767232272, 375: 3.58388702376547, 376: 3.54759932860788, 377: 3.5302655746396,
         378: 3.51288687757519, 379: 3.47994682228715, 380: 3.46136498537057, 381: 3.44867984025117,
         382: 3.41922811270779, 383: 3.39380913663202, 384: 3.39159470395073, 385: 3.3658994324674,
         386: 3.34220879498891, 387: 3.32757178297217, 388: 3.32051299176255, 389: 3.30137142203058,
         390: 3.28461375490357, 391: 3.2704239265627, 392: 3.26262719117465, 393: 3.2595443490267,
         394: 3.25319299332991, 395: 3.25216505624112, 396: 3.25881221771219, 397: 3.26262719117465,
         398: 3.28186554790925, 399: 3.32757178297217, 400: 3.3481531162953, 401: 3.39380913663202},
        {2: 39.0783220867793, 3: 39.02026316395, 4: 39.095701297652, 5: 39.2527777475432, 6: 39.2717261809162,
         7: 39.4712501159874, 8: 39.7256489367063, 9: 40.0073440659185, 10: 40.0806333694868, 11: 40.3119231025986,
         12: 40.6306643582838, 13: 40.9062021847124, 14: 40.9616713321401, 15: 41.2966633550612, 16: 41.6369822928698,
         17: 41.7487758177608, 18: 41.9740749627477, 19: 42.3056136830213, 20: 42.6087045287483, 21: 42.6321450884561,
         22: 42.935921651424, 23: 43.2240306302343, 24: 43.4863457923436, 25: 43.4910721611744, 26: 43.7154825634003,
         27: 43.90333296726, 28: 44.0468534038453, 29: 44.1382995332538, 30: 44.171453111289, 31: 44.1435327474756,
         32: 44.0571706505299, 33: 43.9219003330814, 34: 43.754555016954, 35: 43.578196278475, 36: 43.4863457923436,
         37: 43.4136750955455, 38: 43.2905867581361, 39: 43.2435218649797, 40: 43.2918785467188, 41: 43.4470292912348,
         42: 43.4863457923436, 43: 43.699090174818, 44: 44.0544420728389, 45: 44.3820644463708, 46: 44.5057686868836,
         47: 45.03493333194, 48: 45.2962328434737, 49: 45.6395711290691, 50: 46.2292310059038, 51: 46.3159434455941,
         52: 47.0479708586227, 53: 47.1814467834965, 54: 47.8334200519951, 55: 48.1532760149012, 56: 48.6722003806713,
         57: 49.1451226921324, 58: 49.560375618265, 59: 50.157399128511, 60: 50.4950369905084, 61: 51.1905261300629,
         62: 51.4741157814438, 63: 52.2449331704502, 64: 52.496237885162, 65: 53.321058569504, 66: 53.5606111285683,
         67: 54.4193496754352, 68: 54.6669385010439, 69: 55.5402630507987, 70: 55.8153521445268, 71: 56.6842646622869,
         72: 57.0063642419716, 73: 57.8518300744344, 74: 58.2408319077703, 75: 59.0434446473104, 76: 59.5199339134132,
         77: 60.2596037382849, 78: 60.8451576361768, 79: 61.5008129079496, 80: 62.2182950429769, 81: 62.7675881302812,
         82: 63.64144684958, 83: 64.060456007133, 84: 65.1170342528902, 85: 65.3799539871445, 86: 66.6478178408921,
         87: 66.7266305891604, 88: 68.1010456302517, 89: 68.2275938796567, 90: 69.5037704584324, 91: 69.8611997118783,
         92: 70.9353881901712, 93: 71.5576243422514, 94: 72.3964939527939, 95: 73.320944768434, 96: 73.8876951318799,
         97: 75.1557232670821, 98: 75.4096116237538, 99: 76.962876093178, 100: 77.0607266121845, 101: 78.5481342363531,
         102: 79.0291196799863, 103: 80.1660450493358, 104: 81.0820222390514, 105: 81.8172811019847,
         106: 83.2259626754731, 107: 83.5025288175501, 108: 85.2224887580216, 109: 85.4556203052585,
         110: 86.9778759153537, 111: 87.773119398609, 112: 88.7694200086898, 113: 90.2006628386947,
         114: 90.5978657877085, 115: 92.4639733422179, 116: 92.735790020067, 117: 94.3685184181272,
         118: 95.3790288161751, 119: 96.3122927399262, 120: 98.1565417699644, 121: 98.296104339807,
         122: 100.320777893566, 123: 101.055649853055, 124: 102.387155063422, 125: 104.102122349999,
         126: 104.496094847901, 127: 106.64847393892, 128: 107.298188859459, 129: 108.845187086233,
         130: 110.657294500145, 131: 111.087147469379, 132: 113.375287077295, 133: 114.190201433105,
         134: 115.710557095745, 135: 117.910537569379, 136: 118.093928302732, 137: 120.52639147205,
         138: 121.830089027232, 139: 123.008957785155, 140: 125.542659251513, 141: 125.964857353399,
         142: 128.12854913761, 143: 130.327717075323, 144: 130.767702404799, 145: 133.461216156164,
         146: 134.938760387189, 147: 136.210210092584, 148: 139.015826978204, 149: 139.808562064327,
         150: 141.879233115477, 151: 144.801618830006, 152: 144.950657162245, 153: 147.78419896536,
         154: 150.39218100031, 155: 150.82821338809, 156: 153.934927503147, 157: 156.14678498427, 158: 157.105632779909,
         159: 160.341647289054, 160: 162.230622057727, 161: 163.644316250481, 162: 167.015012592524,
         163: 168.670200778408, 164: 170.455137522682, 165: 173.966121110103, 166: 175.506991844509,
         167: 177.549422880069, 168: 181.206532420725, 169: 182.812882938321, 170: 184.938970002303,
         171: 188.748287209103, 172: 190.722303432746, 173: 192.636067584493, 174: 196.603927289188,
         175: 199.506214104213, 176: 200.653515773096, 177: 204.786516460998, 178: 209.004647452351,
         179: 209.984133013915, 180: 213.309662235506, 181: 217.703350416642, 182: 222.187538463703,
         183: 226.764090465673, 184: 231.434908907479, 185: 236.201935460857, 186: 241.067151791517,
         187: 241.748596678309, 188: 245.078413958371, 189: 246.032580382918, 190: 246.635252294115,
         191: 247.16384146384, 192: 247.02960887761, 193: 246.383101369212, 194: 246.032580382918,
         195: 245.313786261899, 196: 243.919567630274, 197: 242.250688179544, 198: 241.067151791517,
         199: 240.343521648629, 200: 238.26466574416, 201: 236.201935460857, 202: 235.995277615835,
         203: 233.647874506279, 204: 231.434908907479, 205: 231.147079028806, 206: 228.629328620903,
         207: 226.764090465673, 208: 226.010013955852, 209: 223.391226908552, 210: 222.187538463703,
         211: 220.751386809172, 212: 218.086481976913, 213: 217.703350416642, 214: 215.514382764958,
         215: 213.309662235506, 216: 212.906980416027, 217: 210.437349185043, 218: 209.004647452351,
         219: 208.000707895366, 220: 205.672886227952, 221: 204.786516460998, 222: 203.484114045017,
         223: 201.40856890609, 224: 200.653515773096, 225: 199.546060113039, 226: 197.89284968729,
         227: 196.603927289188, 228: 196.434410123218, 229: 195.472768734978, 230: 194.980146940966,
         231: 195.317351473564, 232: 196.603927289188, 233: 197.698625761082, 234: 200.653515773096,
         235: 204.786516460998, 236: 209.004647452351, 237: 213.309662235506, 238: 217.703350416642,
         239: 222.187538463703, 240: 226.764090465673, 241: 231.434908907479, 242: 236.201935460857,
         243: 240.534675450437, 244: 241.067151791517, 245: 246.032580382918, 246: 248.325181090109,
         247: 249.811752069591, 248: 249.401628052729, 249: 247.977831997235, 250: 246.032580382918,
         251: 245.909989106186, 252: 243.244268139353, 253: 241.067151791517, 254: 240.238713047905,
         255: 236.899229268977, 256: 236.201935460857, 257: 233.267026970759, 258: 231.434908907479,
         259: 229.411434674125, 260: 226.764090465673, 261: 225.352602692017, 262: 222.187538463703,
         263: 221.106353522914, 264: 217.703350416642, 265: 216.684865767541, 266: 213.309662235506,
         267: 212.097295963601, 268: 209.004647452351, 269: 207.350363111438, 270: 204.786516460998,
         271: 202.448916929626, 272: 200.653515773096, 273: 197.396506747842, 274: 196.603927289188,
         275: 192.636067584493, 276: 192.167603478211, 277: 188.748287209103, 278: 186.732078674156,
         279: 184.938970002303, 280: 181.206532420725, 281: 181.146005164858, 282: 177.549422880069,
         283: 175.271298955771, 284: 173.966121110103, 285: 170.455137522682, 286: 169.191660364881,
         287: 167.015012592524, 288: 163.644316250481, 289: 162.900375805329, 290: 160.341647289054,
         291: 157.105632779909, 292: 156.469530234282, 293: 153.934927503147, 294: 150.82821338809,
         295: 150.108814059516, 296: 147.78419896536, 297: 144.801618830006, 298: 144.096879696266,
         299: 141.879233115477, 300: 139.015826978204, 301: 138.617530505624, 302: 136.210210092584,
         303: 133.70240994869, 304: 133.461216156164, 305: 130.767702404799, 306: 129.306713604392,
         307: 128.12854913761, 308: 125.542659251513, 309: 125.274803344881, 310: 123.008957785155,
         311: 121.591074310095, 312: 120.52639147205, 313: 118.114790756438, 314: 118.093928302732,
         315: 115.710557095745, 316: 114.885714448725, 317: 113.375287077295, 318: 111.793982261261,
         319: 111.087147469379, 320: 108.845187086233, 321: 108.818643033509, 322: 106.64847393892,
         323: 105.989762261522, 324: 104.496094847901, 325: 103.238847578531, 326: 102.387155063422,
         327: 100.553992351145, 328: 100.320777893566, 329: 98.296104339807, 330: 97.9518038684093,
         331: 96.3122927399262, 332: 95.4137875532708, 333: 94.3685184181272, 334: 92.9159569681758,
         335: 92.4639733422179, 336: 90.5978657877085, 337: 90.462128303295, 338: 88.7694200086898,
         339: 88.0700269360616, 340: 86.9778759153536, 341: 85.7032340268751, 342: 85.2224887580216,
         343: 83.5025288175501, 344: 83.3670729489192, 345: 81.8172811019847, 346: 81.0830130285417,
         347: 80.1660450493358, 348: 78.8136423657009, 349: 78.5481342363531, 350: 76.962876093178,
         351: 76.5820415884186, 352: 75.4096116237538, 353: 74.3769127953314, 354: 73.8876951318799,
         355: 72.3964939527939, 356: 72.1891101559377, 357: 70.9353881901712, 358: 70.0325161785342,
         359: 69.5037704584324, 360: 68.1010456302517, 361: 67.8836346157892, 362: 66.7266305891604,
         363: 65.7542345824658, 364: 65.3799539871445, 365: 64.060456007133, 366: 63.6280506500863,
         367: 62.7675881302812, 368: 61.5008129079496, 369: 61.4968832292824, 370: 60.2596037382849,
         371: 59.3599131354525, 372: 59.0434446473104, 373: 57.8518300744344, 374: 57.1921863795221,
         375: 56.6842646622869, 376: 55.5402630507987, 377: 54.9753916763967, 378: 54.4193496754352,
         379: 53.321058569504, 380: 52.675944512518, 381: 52.2449331704502, 382: 51.1905261300629,
         383: 50.2383527349974, 384: 50.157399128511, 385: 49.1451226921325, 386: 48.1532760149012,
         387: 47.4924584044399, 388: 47.1814467834965, 389: 46.2292310059038, 390: 45.2962328434737,
         391: 44.3820644463708, 392: 43.7367017766898, 393: 43.4863457923436, 394: 42.6087045287483,
         395: 41.7487758177608, 396: 40.9062021847124, 397: 40.711965653461, 398: 40.0806333694868,
         399: 39.4046156317694, 400: 39.2717261809162, 401: 39.0783220867793}
    ],
    'Intrusive Rock': [
        {2: 6.53119652333152, 3: 6.67076354116225, 4: 6.81331300675683, 5: 6.95890865289969, 6: 7.05294495143964,
         7: 7.10761557429949, 8: 7.25950025669247, 9: 7.41463060656766, 10: 7.46938391532168, 11: 7.57307598152742,
         12: 7.73490722129668, 13: 7.78133579435613, 14: 7.9001966793948, 15: 8.05712080786541, 16: 8.06901825548436,
         17: 8.24144742841105, 18: 8.31251654951862, 19: 8.41756128994977, 20: 8.55350273493563, 21: 8.59743857927171,
         22: 8.78115971814809, 23: 8.78304811526039, 24: 8.96880684690608, 25: 9.00570433597272, 26: 9.16046386115316,
         27: 9.22114844596652, 28: 9.35621644928616, 29: 9.43117212435543, 30: 9.55615213080194, 31: 9.63750958726705,
         32: 9.76036029542666, 33: 9.84184674300605, 34: 9.96893224308127, 35: 10.04581680049, 36: 10.181961224701,
         37: 10.2509738203308, 38: 10.3995424839271, 39: 10.4587389084147, 40: 10.6217732996897, 41: 10.6703206692437,
         42: 10.8487530297003, 43: 10.8866211775902, 44: 11.0805831548739, 45: 11.1081478144602, 46: 11.3173673247005,
         47: 11.3349550067169, 48: 11.5592114035857, 49: 11.5666344776672, 50: 11.8027034162636, 51: 11.8062235181822,
         52: 12.0425281262512, 53: 12.0585141057322, 54: 12.2842116562549, 55: 12.3161959634431, 56: 12.5264220756622,
         57: 12.5793842989183, 58: 12.7677890938073, 59: 12.8481967816655, 60: 13.0069292388447, 61: 13.1227535957062,
         62: 13.2424295045444, 63: 13.4031774933087, 64: 13.472794674552, 65: 13.6895938498698, 66: 13.6963658338659,
         67: 13.9192131143253, 68: 13.9821307199693, 69: 14.1348832965561, 70: 14.2809188946222, 71: 14.3406622955759,
         72: 14.5405726255675, 73: 14.5860919597543, 74: 14.7366561978502, 75: 14.8977863559275, 76: 14.9190855430946,
         77: 15.1026744630934, 78: 15.2161414393411, 79: 15.2741636763904, 80: 15.4433845299186, 81: 15.5412995441376,
         82: 15.6043855665542, 83: 15.7641438831852, 84: 15.8734060460382, 85: 15.9154490940558, 86: 16.0705127570666,
         87: 16.2126094273403, 88: 16.2131333611827, 89: 16.3677754561367, 90: 16.5112673817009, 91: 16.5590613433016,
         92: 16.6604985754754, 93: 16.8077430982938, 94: 16.9129166899452, 95: 16.9521775166148, 96: 17.1050916616424,
         97: 17.2493248859768, 98: 17.2743336733116, 99: 17.4046719818546, 100: 17.5550969918783, 101: 17.6434738801917,
         102: 17.7066150719419, 103: 17.8632909592352, 104: 18.0114052809602, 105: 18.0205023503711,
         106: 18.1724665804295, 107: 18.325512908863, 108: 18.4055876504181, 109: 18.4802966904878,
         110: 18.6374704363418, 111: 18.7855807716807, 112: 18.7989019490485, 113: 18.9438065006599,
         114: 19.0939260567439, 115: 19.2006210941008, 116: 19.2400211247332, 117: 19.3906101546166,
         118: 19.5311619180534, 119: 19.6109246911567, 120: 19.6693059250685, 121: 19.806819404832,
         122: 19.9337534115451, 123: 20.0299961838411, 124: 20.053188550724, 125: 20.1720460394286,
         126: 20.2788090625644, 127: 20.3736526605785, 128: 20.4564464711346, 129: 20.4580229358387,
         130: 20.5327531276883, 131: 20.5937737104182, 132: 20.6385588484089, 133: 20.6659872893108,
         134: 20.6746476436616, 135: 20.6629012372642, 136: 20.6289869174469, 137: 20.5711770428816,
         138: 20.4879860296615, 139: 20.4580229358387, 140: 20.3813027822159, 141: 20.2497243738095,
         142: 20.0929136312749, 143: 20.0299961838411, 144: 19.914940007604, 145: 19.7171614595716,
         146: 19.6109246911567, 147: 19.4999894383177, 148: 19.2628958573364, 149: 19.2006210941008,
         150: 18.9943849443347, 151: 18.7989019490485, 152: 18.6758474067363, 153: 18.4055876504181,
         154: 18.236743171265, 155: 18.0205023503711, 156: 17.6434738801917, 157: 17.2743336733116,
         158: 16.9129166899452, 159: 16.5590613433016, 160: 16.2126094273403, 161: 16.1116475407567,
         162: 15.8734060460382, 163: 15.5412995441376, 164: 15.4933734030661, 165: 15.2161414393411,
         166: 15.0122420884884, 167: 14.8977863559275, 168: 14.5860919597543, 169: 14.5856257919931,
         170: 14.2809188946222, 171: 14.2040654210009, 172: 13.9821307199693, 173: 13.8455989319025,
         174: 13.6895938498698, 175: 13.5048819876417, 176: 13.4031774933087, 177: 13.1781064477804,
         178: 13.1227535957062, 179: 12.8624601031256, 180: 12.8481967816655, 181: 12.5793842989183,
         182: 12.5555909786273, 183: 12.3161959634431, 184: 12.2550944022666, 185: 12.0585141057322,
         186: 11.9593375587872, 187: 11.8062235181822, 188: 11.6667548735368, 189: 11.5592114035857,
         190: 11.3757124274081, 191: 11.3173673247005, 192: 11.0844717160114, 193: 11.0805831548739,
         194: 10.8487530297003, 195: 10.7868078208931, 196: 10.6217732996897, 197: 10.4837949983117,
         198: 10.3995424839271, 199: 10.181961224701, 200: 10.1734811183746, 201: 9.96893224308127,
         202: 9.84810736272094, 203: 9.76036029542666, 204: 9.55615213080194, 205: 9.51348459451125,
         206: 9.35621644928616, 207: 9.17144674143546, 208: 9.16046386115316, 209: 8.96880684690608,
         210: 8.83160768264874, 211: 8.78115971814809, 212: 8.59743857927171, 213: 8.50666118961587,
         214: 8.41756128994977, 215: 8.24144742841105, 216: 8.20396020284828, 217: 8.06901825548436,
         218: 7.92649069542754, 219: 7.9001966793948, 220: 7.73490722129668, 221: 7.67333825956531,
         222: 7.57307598152742, 223: 7.44170794513801, 224: 7.41463060656766, 225: 7.25950025669247,
         226: 7.22909501069685, 227: 7.10761557429949, 228: 7.03316364637591, 229: 6.95890865289969,
         230: 6.85207054061292, 231: 6.81331300675683, 232: 6.68433792240568, 233: 6.67076354116226,
         234: 6.53119652333152, 235: 6.5286356603776, 236: 6.39454955390992, 237: 6.38377895889912,
         238: 6.26076153907428, 239: 6.24939064459714, 240: 6.12977266321828, 241: 6.1248826049736,
         242: 6.00940165185141, 243: 6.00152436220944, 244: 5.90237583553464, 245: 5.87595929720548,
         246: 5.80378986968108, 247: 5.75302132901857, 248: 5.71353559312673, 249: 5.63265549301596,
         250: 5.63163460999115, 251: 5.55562507816448, 252: 5.51480797454565, 253: 5.48760950499018,
         254: 5.42632298522895, 255: 5.39942608487633, 256: 5.37161323037673, 257: 5.32329227799055,
         258: 5.2864582376406, 259: 5.28191349337917, 260: 5.24553573037852, 261: 5.21586621938342,
         262: 5.19249200038312, 263: 5.17585392577112, 264: 5.17513941017047, 265: 5.16332751453568,
         266: 5.15788728012667, 267: 5.15892081768879, 268: 5.16665024368171, 269: 5.17585392577112,
         270: 5.18128240913436, 271: 5.20308180417135, 272: 5.23270158491632, 273: 5.27045994160321,
         274: 5.2864582376406, 275: 5.31645009454225, 276: 5.37032867963007, 277: 5.39942608487633,
         278: 5.43116600669921, 279: 5.4968565123567, 280: 5.51480797454565, 281: 5.56436614544434,
         282: 5.63032236312491, 283: 5.63265549301596, 284: 5.69076551835683, 285: 5.74423010474646,
         286: 5.75302132901857, 287: 5.78846822833214, 288: 5.82397294017092, 289: 5.85134713458088,
         290: 5.87130579366343, 291: 5.87595929720548, 292: 5.88447679894721, 293: 5.89219751755222,
         294: 5.8956164981484, 295: 5.89569133748887, 296: 5.89332872240426, 297: 5.88938293719684,
         298: 5.88466192525475, 299: 5.87993770864329, 300: 5.87595929720548, 301: 5.87341887786651,
         302: 5.87316493480856, 303: 5.87595929720548, 304: 5.87596018249044, 305: 5.88253911434475,
         306: 5.89383833723853, 307: 5.91085317818974, 308: 5.93472359372241, 309: 5.9667895116182,
         310: 6.00152436220944, 311: 6.00905820995255, 312: 6.06653972674104, 313: 6.12977266321828,
         314: 6.14289368617238, 315: 6.25567162018338, 316: 6.26076153907428, 317: 6.39454955390992,
         318: 6.47861961270336, 319: 6.53119652333152},
        {2: 72.7752418935877, 3: 72.5830708942913, 4: 72.5895175588147, 5: 72.7518440344959, 6: 72.9373791957268,
         7: 73.0408146891443, 8: 73.4338117695724, 9: 73.9161827066687, 10: 74.1121864226272, 11: 74.4769735766238,
         12: 75.1095953351032, 13: 75.3059163478148, 14: 75.8075730341823, 15: 76.5188737604518, 16: 76.5730731564659,
         17: 77.3966503097109, 18: 77.7513683589598, 19: 78.2853380458892, 20: 79.0037148300934, 21: 79.2412739323778,
         22: 80.2656454862745, 23: 80.2762329292879, 24: 81.3523113756272, 25: 81.5692475623006, 26: 82.5106049372362,
         27: 82.8830888681675, 28: 83.7404766779025, 29: 84.218092303496, 30: 85.0399811387943, 31: 85.5745987281155,
         32: 86.4047482932413, 33: 86.9529544921074, 34: 87.827908061969, 35: 88.3535115242369, 36: 89.3006371379393,
         37: 89.7766274218093, 38: 90.8133137915516, 39: 91.2226655419735, 40: 92.3570348430962, 41: 92.6919950944961,
         42: 93.9250967980746, 43: 94.1849912360303, 44: 95.5140672536993, 45: 95.7020351659022, 46: 97.1242589571221,
         47: 97.243514223441, 48: 98.7596539185079, 49: 98.8098219868763, 50: 100.401358373829, 51: 100.42504710931,
         52: 102.018529743418, 53: 102.126936332127, 54: 103.661749000017, 55: 103.881767808778, 56: 105.331435698679,
         57: 105.703460322012, 58: 107.028016152256, 59: 107.608421794209, 60: 108.751923540251, 61: 109.616090144036,
         62: 110.503598019417, 63: 111.749818514841, 64: 112.283486836142, 65: 114.038184454804, 66: 114.092044440641,
         67: 115.92973260299, 68: 116.483986982401, 69: 117.797020531024, 70: 119.15607767671, 71: 119.694384990142,
         72: 121.622310425034, 73: 122.09127750851, 74: 123.581289083374, 75: 125.349257685045, 76: 125.5718211415,
         77: 127.594414832126, 78: 128.980060909145, 79: 129.649586574103, 80: 131.737861104275, 81: 133.060428308129,
         82: 133.859771611456, 83: 136.015859872571, 84: 137.628424271346, 85: 138.206676390979, 86: 140.432780537034,
         87: 142.687039810555, 88: 142.694740690907, 89: 144.993134387704, 90: 147.328548464929, 91: 148.13006884213,
         92: 149.701579212317, 93: 152.112832524081, 94: 153.93673319433, 95: 154.562924053611, 96: 157.052479370669,
         97: 159.582134121112, 98: 160.026526492253, 99: 162.152534189184, 100: 164.764335862431, 101: 166.369452737345,
         102: 167.418205999267, 103: 170.114822199238, 104: 172.854872976032, 105: 173.026208441177,
         106: 175.639057933271, 107: 178.468087943142, 108: 180.022909147913, 109: 181.342685327893,
         110: 184.263584044271, 111: 187.231529870908, 112: 187.50874967986, 113: 190.247280598744,
         114: 193.311606224508, 115: 195.645233873104, 116: 196.425289147319, 117: 199.589124368448,
         118: 202.803919694306, 119: 204.7703546314, 120: 206.070495942696, 121: 209.389687152388, 122: 212.76234079607,
         123: 215.577976202699, 124: 216.189317996727, 125: 219.671493747513, 126: 223.209757135153,
         127: 226.805011566949, 128: 230.458175001449, 129: 230.543279819462, 130: 234.170180182818,
         131: 237.941974878993, 132: 241.774522123673, 133: 245.668800462206, 134: 249.625804201434,
         135: 253.646543663565, 136: 257.732045444135, 137: 261.883352674123, 138: 266.101525286288,
         139: 267.32591309479, 140: 270.387640285795, 141: 274.742792025206, 142: 279.168092483889,
         143: 280.799104215556, 144: 283.664671551941, 145: 288.233677318672, 146: 290.576102652321,
         147: 292.876276365746, 148: 297.59365406503, 149: 298.803319078713, 150: 302.38701488126,
         151: 305.587713784648, 152: 307.257582679563, 153: 310.664550878712, 154: 312.206601037945,
         155: 314.020355942218, 156: 315.861560613384, 157: 316.453772129495, 158: 316.046980091627,
         159: 314.835026758327, 160: 312.957219913851, 161: 312.206601037945, 162: 310.574449491838,
         163: 307.747463328888, 164: 307.257582679563, 165: 304.625528131054, 166: 302.38701488126,
         167: 301.218947632984, 168: 297.599680315285, 169: 297.59365406503, 170: 293.901115238603,
         171: 292.876276365746, 172: 290.097405764579, 173: 288.233677318673, 174: 286.229888736974,
         175: 283.664671551941, 176: 282.332287688384, 177: 279.168092483889, 178: 278.431907121647,
         179: 274.742792025206, 180: 274.550956795124, 181: 270.739776320781, 182: 270.387640285795,
         183: 267.000654234002, 184: 266.101525286288, 185: 263.329341023861, 186: 261.883352674123,
         187: 259.739226864295, 188: 257.732045444135, 189: 256.242719660403, 190: 253.646543663565,
         191: 252.851065089793, 192: 249.625804201434, 193: 249.573860459025, 194: 246.494834553137,
         195: 245.668800462206, 196: 243.549583975821, 197: 241.774522123673, 198: 240.731610190728,
         199: 238.044540096722, 200: 237.941974878993, 201: 235.574285780729, 202: 234.170180182818,
         203: 233.195701519211, 204: 230.930782202659, 205: 230.458175001449, 206: 228.80310980668,
         207: 226.805011566949, 208: 226.692219199566, 209: 224.704482156269, 210: 223.209757135153,
         211: 222.689335537101, 212: 220.711879943011, 213: 219.671493747513, 214: 218.70465568231,
         215: 216.655440533114, 216: 216.189317996728, 217: 214.59630554445, 218: 212.76234079607,
         219: 212.439704931286, 220: 210.266073123926, 221: 209.389687152388, 222: 208.020269635295,
         223: 206.070495942697, 224: 205.682552245516, 225: 203.302443990211, 226: 202.803919694306,
         227: 200.864681563187, 228: 199.589124368448, 229: 198.341577139374, 230: 196.425289147319,
         231: 195.738371018767, 232: 193.311606224508, 233: 193.05718816884, 234: 190.300040208151,
         235: 190.247280598744, 236: 187.464849241495, 237: 187.231529870908, 238: 184.523310919159,
         239: 184.263584044271, 240: 181.460822066798, 241: 181.342685327893, 242: 178.468087943142,
         243: 178.264074399188, 244: 175.639057933271, 245: 174.901293896861, 246: 172.854872976032,
         247: 171.319137984563, 248: 170.114822199238, 249: 167.45185708403, 250: 167.418205999267,
         251: 164.764335862431, 252: 163.191203357239, 253: 162.152534189184, 254: 159.582134121112,
         255: 158.325855325551, 256: 157.052479370669, 257: 154.562924053611, 258: 152.374566229832,
         259: 152.112832524081, 260: 149.701579212317, 261: 147.328548464929, 262: 144.993134387704,
         263: 142.785098526814, 264: 142.694740690907, 265: 140.432780537034, 266: 138.206676390979,
         267: 136.015859872571, 268: 133.859771611456, 269: 132.518617020598, 270: 131.737861104275,
         271: 129.649586574103, 272: 127.594414832126, 273: 125.5718211415, 274: 124.855383594652,
         275: 123.581289083374, 276: 121.622310425034, 277: 120.675227445383, 278: 119.694384990142,
         279: 117.797020531024, 280: 117.290458583368, 281: 115.92973260299, 282: 114.092044440641,
         283: 114.022747527965, 284: 112.283486836142, 285: 110.503598019417, 286: 110.164843516932,
         287: 108.751923540251, 288: 107.028016152256, 289: 105.331435698679, 290: 103.661749000017,
         291: 103.096547815875, 292: 102.018529743418, 293: 100.401358373829, 294: 98.8098219868763,
         295: 97.243514223441, 296: 95.7020351659022, 297: 94.1849912360303, 298: 92.6919950944961,
         299: 91.2226655419735, 300: 89.7766274218093, 301: 88.3535115242369, 302: 86.9529544921074,
         303: 85.5750293436909, 304: 85.5745987281155, 305: 84.218092303496, 306: 82.8830888681675,
         307: 81.5692475623006, 308: 80.2762329292879, 309: 79.0037148300934, 310: 77.9542696851231,
         311: 77.7513683589598, 312: 76.5188737604518, 313: 75.4799644729258, 314: 75.3059163478148,
         315: 74.1121864226272, 316: 74.0677352198753, 317: 73.2378177576516, 318: 72.9373791957268,
         319: 72.7752418935877}
    ],
    'Gneiss': [
        {2: 5.52835793239968, 3: 5.60448097860981, 4: 5.68165220553383, 5: 5.7598860461571, 6: 5.83919713220075,
         7: 5.91960029685829, 8: 6.00111057756972, 9: 6.08374321883398, 10: 6.16751367506, 11: 6.25243761345708,
         12: 6.33853091696511, 13: 6.42580968722502, 14: 6.51429024759021, 15: 6.53217073905012, 16: 6.60398914617947,
         17: 6.69492315897187, 18: 6.78710929294428, 19: 6.86341681081281, 20: 6.88056478925215, 21: 6.97530712645401,
         22: 7.07135402378042, 23: 7.12786677273645, 24: 7.16872344444793, 25: 7.26743359901862, 26: 7.36105007714153,
         27: 7.36750294880599, 28: 7.46895020932766, 29: 7.57179435380565, 30: 7.57504424593564, 31: 7.67605461671488,
         32: 7.77693648680238, 33: 7.78175049738047, 34: 7.88890176362466, 35: 7.97132279144465, 36: 7.99752845546386,
         37: 8.10765088885662, 38: 8.1616679888885, 39: 8.21928965950331, 40: 8.33246564669797, 41: 8.35072634859336,
         42: 8.44720001723329, 43: 8.54186839229041, 44: 8.56351422935937, 45: 8.6814300367969, 46: 8.73866114974696,
         47: 8.80096949280571, 48: 8.92215495430927, 49: 8.94446798126955, 50: 9.04500908607601, 51: 9.16527553387568,
         52: 9.16955486495822, 53: 9.29581558418927, 54: 9.4106418887416, 55: 9.42381485774008, 56: 9.55357662473551,
         57: 9.6851251539316, 58: 9.69421206468951, 59: 9.81848504825442, 60: 9.95368124940149, 61: 10.0492595740182,
         62: 10.0907390425065, 63: 10.2296840608681, 64: 10.3705422907444, 65: 10.5133400762126, 66: 10.5761425261122,
         67: 10.6581041240963, 68: 10.8048615089603, 69: 10.953639678174, 70: 11.1044664570452, 71: 11.2573700540237,
         72: 11.4123790659772, 73: 11.5695224835399, 74: 11.7288296965338, 75: 11.8903304994661, 76: 12.0540550971012,
         77: 12.2200341101094, 78: 12.3882985807945, 79: 12.4322454868485, 80: 12.558879978899, 81: 12.7318102074897,
         82: 12.9071216089247, 83: 13.084846970902, 84: 13.1976166533327, 85: 13.2650195325918, 86: 13.4476729908528,
         87: 13.6328415065348, 88: 13.8205597108673, 89: 13.8344702056656, 90: 14.0108627119364, 91: 14.2037861012513,
         92: 14.3993659604004, 93: 14.5976388677995, 94: 14.6254547223637, 95: 14.7986419055333, 96: 15.0024126662903,
         97: 15.0204377990689, 98: 15.2089892603937, 99: 15.4184103229289, 100: 15.4226281396428, 101: 15.5974020671758,
         102: 15.6307150209696, 103: 15.7252675265986, 104: 15.8349128874071, 105: 15.8459430609026,
         106: 15.9275234197911, 107: 16.0146366291449, 108: 16.0641346958542, 109: 16.0962280731027,
         110: 16.1729959135309, 111: 16.2482923477594, 112: 16.2853307332185, 113: 16.3210685505753,
         114: 16.391996202131, 115: 16.4624636099107, 116: 16.5095725422893, 117: 16.5321910444308,
         118: 16.6012467858467, 119: 16.6705691502156, 120: 16.7369020619972, 121: 16.7402755890995,
         122: 16.8106492398549, 123: 16.8821362174886, 124: 16.9549347206584, 125: 16.9673618087536,
         126: 17.0299877924888, 127: 17.107264527397, 128: 17.1868679122526, 129: 17.200994884402,
         130: 17.2703794155138, 131: 17.3572293857025, 132: 17.4378449842792, 133: 17.4475519218163,
         134: 17.5435096078067, 135: 17.6432168367224, 136: 17.6779564053873, 137: 17.74879366694,
         138: 17.8593957588943, 139: 17.921374054679, 140: 17.9755917747723, 141: 18.0976909943734,
         142: 18.1681434574556, 143: 18.225242613128, 144: 18.3585299097589, 145: 18.4183107658816,
         146: 18.4973030646304, 147: 18.640377732764, 148: 18.6719227676166, 149: 18.7890657560789,
         150: 18.9290268945656, 151: 18.9397859375997, 152: 19.0953657532372, 153: 19.1896712317499,
         154: 19.2516465742729, 155: 19.4087931391158, 156: 19.4539045263002, 157: 19.5662165997307,
         158: 19.7203163005181, 159: 19.721776196574, 160: 19.8737925633473, 161: 19.9933363413973,
         162: 20.021134813897, 163: 20.1644717930914, 164: 20.2686357494351, 165: 20.2999019344282,
         166: 20.4290312046954, 167: 20.5477259086898, 168: 20.5478084167725, 169: 20.6595002670593,
         170: 20.7598527492471, 171: 20.8306590161308, 172: 20.849346416698, 173: 20.929264654572,
         174: 20.9973009836957, 175: 21.0535633881547, 176: 21.0982118867798, 177: 21.1174879874568,
         178: 21.1319126573145, 179: 21.1547232342647, 180: 21.1663094598751, 181: 21.1670026180611,
         182: 21.157160233295, 183: 21.1371609117552, 184: 21.1174879874568, 185: 21.1077257514796,
         186: 21.0698815512861, 187: 21.0233901707037, 188: 20.9686388458694, 189: 20.9059952654207,
         190: 20.8357964937653, 191: 20.8306590161308, 192: 20.7606461369464, 193: 20.6788755869645,
         194: 20.5904839443573, 195: 20.5477259086898, 196: 20.497114250076, 197: 20.3986494990579,
         198: 20.2936855500417, 199: 20.2686357494351, 200: 20.1843005281727, 201: 20.068595775947,
         202: 19.9933363413973, 203: 19.9464854847476, 204: 19.8180116994437, 205: 19.721776196574,
         206: 19.6813424780635, 207: 19.5364890184409, 208: 19.4539045263002, 209: 19.3813506678865,
         210: 19.214523736142, 211: 19.1896712317499, 212: 19.0340790057267, 213: 18.9290268945656,
         214: 18.8369046865128, 215: 18.6719227676166, 216: 18.6195731554423, 217: 18.4183107658816,
         218: 18.3769033295759, 219: 18.1681434574556, 220: 18.101068531786, 221: 17.921374054679,
         222: 17.7801016387202, 223: 17.6779564053873, 224: 17.4378449842792, 225: 17.3926072762404,
         226: 17.200994884402, 227: 16.9673618087536, 228: 16.88539144263, 229: 16.7369020619972, 230: 16.5095725422893,
         231: 16.2853307332185, 232: 16.0641346958542, 233: 16.042949877777, 234: 15.8459430609026,
         235: 15.6307150209696, 236: 15.4184103229289, 237: 15.2089892603937, 238: 15.0024126662903,
         239: 14.7986419055333, 240: 14.5976388677995, 241: 14.5140161841652, 242: 14.3993659604004,
         243: 14.2037861012513, 244: 14.0108627119364, 245: 13.8205597108673, 246: 13.6328415065348,
         247: 13.5624357613877, 248: 13.4476729908528, 249: 13.2650195325918, 250: 13.084846970902,
         251: 12.9298625375254, 252: 12.9071216089247, 253: 12.7318102074897, 254: 12.558879978899,
         255: 12.3926580377138, 256: 12.3882985807945, 257: 12.2200341101094, 258: 12.0540550971012,
         259: 11.8940861729748, 260: 11.8903304994661, 261: 11.7288296965338, 262: 11.5695224835399,
         263: 11.4123790659772, 264: 11.4031270262774, 265: 11.2573700540237, 266: 11.1044664570452,
         267: 10.953639678174, 268: 10.8918750685892, 269: 10.8048615089603, 270: 10.6581041240963,
         271: 10.5133400762126, 272: 10.3705422907444, 273: 10.3187067161063, 274: 10.2296840608681,
         275: 10.0907390425065, 276: 9.95368124940149, 277: 9.81848504825442, 278: 9.6851251539316,
         279: 9.56520267773625, 280: 9.55357662473551, 281: 9.42381485774008, 282: 9.29581558418927,
         283: 9.16955486495822, 284: 9.04500908607601, 285: 8.92215495430927, 286: 8.80096949280571,
         287: 8.6814300367969, 288: 8.56351422935937, 289: 8.44720001723329, 290: 8.33246564669797,
         291: 8.21928965950331, 292: 8.10765088885662, 293: 7.99752845546386, 294: 7.88890176362466,
         295: 7.78175049738047, 296: 7.67605461671488, 297: 7.57179435380565, 298: 7.46895020932766,
         299: 7.36750294880599, 300: 7.26743359901862, 301: 7.16872344444793, 302: 7.07135402378042,
         303: 6.97530712645401, 304: 6.88056478925215, 305: 6.78710929294428, 306: 6.69492315897187,
         307: 6.64512957972852, 308: 6.60398914617947, 309: 6.51429024759021, 310: 6.42580968722502,
         311: 6.33853091696511, 312: 6.30885876405948, 313: 6.25243761345708, 314: 6.16751367506, 315: 6.08374321883398,
         316: 6.07566764018993, 317: 6.00111057756972, 318: 5.91960029685829, 319: 5.89540998047466,
         320: 5.83919713220075, 321: 5.7598860461571, 322: 5.74737666470423, 323: 5.68165220553383,
         324: 5.62225170962114, 325: 5.60448097860981, 326: 5.52835793239968, 327: 5.51397541958057,
         328: 5.45326882995463, 329: 5.41904671451799, 330: 5.37919962769965, 331: 5.33478167257533,
         332: 5.30613647280704, 333: 5.25944794762855, 334: 5.2340657006056, 335: 5.1917008872499,
         336: 5.16297383202496, 337: 5.13050147562216, 338: 5.09284757107467, 339: 5.07505433820991,
         340: 5.024751784147, 341: 5.02367380235752, 342: 4.97889481768101, 343: 4.95543958861659,
         344: 4.93722558215194, 345: 4.89934557702859, 346: 4.88813216831568, 347: 4.86482141958313,
         348: 4.83358550492781, 349: 4.82173895325258, 350: 4.80521414751686, 351: 4.77960240630769,
         352: 4.75675637153309, 353: 4.75624752620475, 354: 4.73600872307557, 355: 4.71768778649906,
         356: 4.70163986234724, 357: 4.69164563860697, 358: 4.68760995031243, 359: 4.67535418444515,
         360: 4.66502232380486, 361: 4.65650380146766, 362: 4.64969843920913, 363: 4.64451488618636,
         364: 4.64086918867741, 365: 4.63868346967933, 366: 4.63788469998627, 367: 4.6384035448446,
         368: 4.64017327252704, 369: 4.64312871330368, 370: 4.64720525944603, 371: 4.65233789922045,
         372: 4.65846028045821, 373: 4.66550380237852, 374: 4.67339673802997, 375: 4.6820633941185,
         376: 4.69142332017986, 377: 4.69164563860697, 378: 4.70110946525052, 379: 4.71128800526653,
         380: 4.72187039640227, 381: 4.73275528611691, 382: 4.74383476593308, 383: 4.75499446656822,
         384: 4.75624752620475, 385: 4.7658641618354, 386: 4.77654437120051, 387: 4.78694219935822,
         388: 4.79693013629563, 389: 4.80637970222043, 390: 4.81516361214262, 391: 4.82173895325258,
         392: 4.8231305936745, 393: 4.83008649141021, 394: 4.83605877961966, 395: 4.84095475329731,
         396: 4.84469718240176, 397: 4.84722754741587, 398: 4.8485090858037, 399: 4.84852950406726,
         400: 4.84730322146237, 401: 4.84487303564285, 402: 4.84131113632983, 403: 4.83671943776609,
         404: 4.83122925018055, 405: 4.82500036002004, 406: 4.82173895325258, 407: 4.8182149869824,
         408: 4.81110578703052, 409: 4.80392131736062, 410: 4.7969192641202, 411: 4.79037494094699,
         412: 4.78457980741706, 413: 4.7798405764718, 414: 4.77647903299121, 415: 4.7748326590493,
         416: 4.77525613860145, 417: 4.7781237978076, 418: 4.78383302843427, 419: 4.79280874159642,
         420: 4.80550890771168, 421: 4.82173895325258, 422: 4.82245140842119, 423: 4.8448253192903,
         424: 4.87285366087688, 425: 4.88813216831568, 426: 4.90807340868014, 427: 4.95160994376055,
         428: 4.95543958861659, 429: 5.00650965406293, 430: 5.02367380235752, 431: 5.07555670267758,
         432: 5.09284757107467, 433: 5.16297383202496, 434: 5.16450089751264, 435: 5.2340657006056,
         436: 5.28699764241768, 437: 5.30613647280704, 438: 5.37919962769965, 439: 5.45326882995463,
         440: 5.47600852564486, 441: 5.52835793239968},
        {2: 47.6618521153169, 3: 47.4468802141306, 4: 47.2832873522638, 5: 47.1670369708019, 6: 47.0946040444193,
         7: 47.0629244163068, 8: 47.0693508361283, 9: 47.1116147354718, 10: 47.1877928984154, 11: 47.2962782864566,
         12: 47.4357543598813, 13: 47.6051723038645, 14: 47.8037306188593, 15: 47.8490589597429, 16: 48.0336079188502,
         17: 48.2920144267639, 18: 48.5778832973976, 19: 48.833497169114, 20: 48.8918966531823, 21: 49.2364952066304,
         22: 49.6077726461739, 23: 49.8381890388316, 24: 50.0079670836309, 25: 50.4374084399711, 26: 50.8635512641779,
         27: 50.8935413050239, 28: 51.3807289094479, 29: 51.8934325670627, 30: 51.9100091134512, 31: 52.4366466566031,
         32: 52.9779966043458, 33: 53.0044181706752, 34: 53.6006405950676, 35: 54.0679566839606, 36: 54.2198992799279,
         37: 54.862928191953, 38: 55.1803414125107, 39: 55.5262633316215, 40: 56.2067220351489, 41: 56.3156121508198,
         42: 56.9023259519137, 43: 57.4742397516684, 44: 57.607391454877, 45: 58.318576139041, 46: 58.6567047550805,
         47: 59.0304627297182, 48: 59.738050877732, 49: 59.8634975876268, 50: 60.4355264596587, 51: 61.0951187658288,
         52: 61.1188115932376, 53: 61.7801840506743, 54: 62.3520791037479, 55: 62.4180950663114, 56: 63.023938269823,
         57: 63.5986115091844, 58: 63.634899924845, 59: 64.1325886524169, 60: 64.6281918656177, 61: 64.9441132781991,
         62: 65.0813731334347, 63: 65.4873453211546, 64: 65.8489256153085, 65: 66.1648009427286, 66: 66.2802621591745,
         67: 66.4311280237645, 68: 66.6485105581148, 69: 66.8187620086961, 70: 66.9419631930546, 71: 67.0184960289511,
         72: 67.0490423817039, 73: 67.0345812607408, 74: 66.9763856379681, 75: 66.8760204668384, 76: 66.7353438517708,
         77: 66.5565137891862, 78: 66.342003529135, 79: 66.2802621591745, 80: 66.0899801853607, 81: 65.8057139962235,
         82: 65.4943271400904, 83: 65.1599635070895, 84: 64.9441132781991, 85: 64.8032181974863, 86: 64.4262543237528,
         87: 64.0423223510905, 88: 63.6599508556514, 89: 63.634899924845, 90: 63.2757398242458, 91: 62.9164624884502,
         92: 62.6035505988266, 93: 62.3665265492609, 94: 62.3520791037479, 95: 62.2433680994125, 96: 62.3214973976578,
         97: 62.3520791037479, 98: 62.7050659362977, 99: 63.6059512477784, 100: 63.634899924845, 101: 64.9441132781991,
         102: 65.2219824151033, 103: 66.2802621591745, 104: 67.6439007346275, 105: 67.7836341787022,
         106: 69.0355945727466, 107: 70.4559208776222, 108: 71.2879076208975, 109: 71.9054687286409,
         110: 73.384839324806, 111: 74.8946462340846, 112: 75.6444283344278, 113: 76.4355156478843,
         114: 78.0080866407657, 115: 79.6130114354981, 116: 80.6983773411745, 117: 81.2509556735686,
         118: 82.9225986912562, 119: 84.6286338013866, 120: 86.2825705764186, 121: 86.3697685808826,
         122: 88.1467251642314, 123: 89.9602405429897, 124: 91.8110668714499, 125: 92.119894342488,
         126: 93.6999717785961, 127: 95.6277386864772, 128: 97.5951671351313, 129: 97.9342301616721,
         130: 99.6030731141938, 131: 101.652289401329, 132: 103.520115366152, 133: 103.743665907624,
         134: 105.878070030088, 135: 108.056387011406, 136: 108.794817249838, 137: 110.279520307091,
         138: 112.548391960194, 139: 113.794243445718, 140: 114.863942983718, 141: 117.227133750904,
         142: 118.572294395023, 143: 119.638944393545, 144: 122.100375208494, 145: 123.197151687341,
         146: 124.612447072539, 147: 127.176201865808, 148: 127.742061232784, 149: 129.79270290389,
         150: 132.276700122527, 151: 132.463035378843, 152: 135.188306809278, 153: 136.882432029341,
         154: 137.969647499702, 155: 140.80821100931, 156: 141.651847519304, 157: 143.70517463042,
         158: 146.661739876762, 159: 146.691060397943, 160: 149.679132981797, 161: 152.187355173502,
         162: 152.758605407301, 163: 155.901434362405, 164: 158.379911705034, 165: 159.108923333322,
         166: 162.38240262396, 167: 165.720956193239, 168: 165.723229907669, 169: 169.132790790334,
         170: 172.612499385056, 171: 175.435133289806, 172: 176.163798898651, 173: 179.788162230221,
         174: 183.487092582037, 175: 187.262124082994, 176: 191.114822424886, 177: 193.390005581216,
         178: 195.046785511778, 179: 199.059644122736, 180: 203.155062588188, 181: 207.334739480209,
         182: 211.600408316999, 183: 215.953838281861, 184: 218.892013611358, 185: 220.396834956966,
         186: 224.931241072217, 187: 229.558937269525, 188: 234.281842882797, 189: 239.101916733983,
         190: 244.021157945495, 191: 244.356296542548, 192: 249.04160676934, 193: 254.165345433316,
         194: 259.394499004613, 195: 261.811409802513, 196: 264.731236271185, 197: 270.177770641248,
         198: 275.736361061296, 199: 277.022238263354, 200: 281.409312952995, 201: 287.198979169354,
         202: 290.832348720085, 203: 293.107760970572, 204: 299.138109019953, 205: 303.475519145529,
         206: 305.292524400327, 207: 311.573559651364, 208: 315.007571470845, 209: 317.983819828239,
         210: 324.52596358208, 211: 325.466321748205, 212: 331.202704262643, 213: 334.894383875649,
         214: 338.016811043667, 215: 343.355598631822, 216: 344.97111007139, 217: 350.916629062088,
         218: 352.068485636689, 219: 357.647737141652, 220: 359.311881371343, 221: 363.614616998235,
         222: 366.704301468895, 223: 368.87186867159, 224: 373.469850915374, 225: 374.248811930647,
         226: 377.478056831833, 227: 380.903879863074, 228: 381.948541837273, 229: 383.819098180763,
         230: 386.24269819967, 231: 388.190811908419, 232: 389.697762977041, 233: 389.806684646613,
         234: 390.825744783209, 235: 391.568020816134, 236: 391.947311036209, 237: 391.98734373638,
         238: 391.709859595182, 239: 391.134785947964, 240: 390.280403536364, 241: 389.806684646613,
         242: 389.191071225188, 243: 387.889599505488, 244: 386.371838337883, 245: 384.651933350075,
         246: 382.743106483428, 247: 381.948541837273, 248: 380.723335104664, 249: 378.59505408961,
         250: 376.331354543812, 251: 374.248811930647, 252: 373.960303093071, 253: 371.602393016456,
         254: 369.158680837857, 255: 366.704301468895, 256: 366.64366231935, 257: 364.217319990901,
         258: 361.750809647612, 259: 359.311881371343, 260: 359.258059637973, 261: 356.903316626813,
         262: 354.549477472321, 263: 352.206554300191, 264: 352.068485636689, 265: 350.029593106188,
         266: 347.897993553792, 267: 345.812112037367, 268: 344.97111007139, 269: 343.861932718907,
         270: 342.032599842689, 271: 340.276054041436, 272: 338.599862810302, 273: 338.016811043667,
         274: 337.08059673998, 275: 335.69116348738, 276: 334.396558097546, 277: 333.200628426049,
         278: 332.106178339369, 279: 331.202704262643, 280: 331.120877782174, 281: 330.294520337582,
         282: 329.563723026299, 283: 328.925706348845, 284: 328.376296050275, 285: 327.909926853032,
         286: 327.519684981764, 287: 327.19738760401, 288: 326.93369492952, 289: 326.718248671657,
         290: 326.539829058452, 291: 326.386521704757, 292: 326.245885458084, 293: 326.105112769137,
         294: 325.951175108096, 295: 325.770947299003, 296: 325.55130620672, 297: 325.279200816874,
         298: 324.941692254499, 299: 324.52596358208, 300: 324.052156403507, 301: 323.481320324122,
         302: 322.801582285715, 303: 322.000968553784, 304: 321.067295612644, 305: 319.988041866424,
         306: 318.750201183325, 307: 317.983819828239, 308: 317.379047974826, 309: 315.87875188813,
         310: 314.188425254832, 311: 312.292405496962, 312: 311.573559651364, 313: 310.252923788243,
         314: 308.026536220187, 315: 305.553268268211, 316: 305.292524400327, 317: 302.942892375143,
         318: 300.070173662851, 319: 299.138109019953, 320: 297.006331522018, 321: 293.675991716916,
         322: 293.107760970572, 323: 290.144151259563, 324: 287.198979169354, 325: 286.318675992745,
         326: 282.238624899173, 327: 281.409312952995, 328: 277.881163608027, 329: 275.736361061296,
         330: 273.202403078438, 331: 270.177770641248, 332: 268.185117290265, 333: 264.731236271185,
         334: 262.799749279621, 335: 259.394499004613, 336: 257.00250313314, 337: 254.165345433316,
         338: 250.732632722902, 339: 249.04160676934, 340: 244.021157945495, 341: 243.90915916085,
         342: 239.101916733983, 343: 236.420161088679, 344: 234.281842882797, 345: 229.558937269525,
         346: 228.073970240166, 347: 224.931241072217, 348: 220.396834956966, 349: 218.551922154784,
         350: 215.953838281861, 351: 211.600408316999, 352: 207.334739480209, 353: 207.232143951299,
         354: 203.155062588188, 355: 199.059644122736, 356: 195.046785511778, 357: 192.237088967826,
         358: 191.114822424886, 359: 187.262124082994, 360: 183.487092582037, 361: 179.788162230221,
         362: 176.163798898651, 363: 172.612499385056, 364: 169.132790790334, 365: 165.723229907669,
         366: 162.38240262396, 367: 159.108923333322, 368: 155.901434362405, 369: 152.758605407301,
         370: 149.679132981797, 371: 146.661739876762, 372: 143.70517463042, 373: 140.80821100931,
         374: 137.969647499702, 375: 135.188306809278, 376: 132.463035378843, 377: 132.402822630071,
         378: 129.79270290389, 379: 127.176201865808, 380: 124.612447072539, 381: 122.100375208494,
         382: 119.638944393545, 383: 117.227133750904, 384: 116.95743125646, 385: 114.863942983718,
         386: 112.548391960194, 387: 110.279520307091, 388: 108.056387011406, 389: 105.878070030088,
         390: 103.743665907624, 391: 102.018934683623, 392: 101.652289401329, 393: 99.6030731141938,
         394: 97.5951671351313, 395: 95.6277386864772, 396: 93.6999717785961, 397: 91.8110668714499,
         398: 89.9602405429897, 399: 88.1467251642314, 400: 86.3697685808826, 401: 84.6286338013866,
         402: 82.9225986912562, 403: 81.2509556735685, 404: 79.6130114354981, 405: 78.0080866407657,
         406: 77.2456250894849, 407: 76.4355156478843, 408: 74.8946462340846, 409: 73.384839324806,
         410: 71.9054687286409, 411: 70.4559208776222, 412: 69.0355945727466, 413: 67.6439007346275,
         414: 66.2802621591745, 415: 64.9441132781991, 416: 63.634899924845, 417: 62.3520791037479,
         418: 61.0951187658288, 419: 59.8634975876268, 420: 58.6567047550805, 421: 57.5211953866269,
         422: 57.4742397516684, 423: 56.3156121508198, 424: 55.1803414125107, 425: 54.6753699744422,
         426: 54.0679566839606, 427: 52.9779966043458, 428: 52.8961928095248, 429: 51.9100091134512,
         430: 51.626434347126, 431: 50.8635512641779, 432: 50.6414943036051, 433: 49.8532099013152,
         434: 49.8381890388316, 435: 49.2263031385026, 436: 48.833497169114, 437: 48.7045055185804,
         438: 48.2844503767346, 439: 47.9365251499558, 440: 47.8490589597429, 441: 47.6618521153169}
    ],
    'Marble': [
        {2: 4.83315435087456, 3: 4.89022599601214, 4: 4.94797156390125, 5: 5.00639901246695, 6: 5.06551639360438,
         7: 5.12533185428837, 8: 5.18585363769621, 9: 5.24036663752504, 10: 5.24709008434362, 11: 5.30904963323417,
         12: 5.37174082302225, 13: 5.43517229318978, 14: 5.49935278523684, 15: 5.56429114388633, 16: 5.62999631830283,
         17: 5.63870458787263, 18: 5.69647736332592, 19: 5.76374344071805, 20: 5.83180382042705, 21: 5.84855810116691,
         22: 5.90066788186369, 23: 5.97034511519424, 24: 5.99566336576264, 25: 6.0408451226483, 26: 6.10778454678561,
         27: 6.11217761984208, 28: 6.18435243711734, 29: 6.19651905987726, 30: 6.25737952089608, 31: 6.26855430450291,
         32: 6.32775241928577, 33: 6.33126893505127, 34: 6.3767072901179, 35: 6.40603086229377, 36: 6.41725971794181,
         37: 6.45080198766155, 38: 6.47824925305989, 39: 6.48167560557557, 40: 6.50066509268721, 41: 6.51855371548733,
         42: 6.53245901102091, 43: 6.542878911857, 44: 6.5502444802672, 45: 6.55493607521443, 46: 6.55729974241749,
         47: 6.5576637977933, 48: 6.55635563925176, 49: 6.55371881569288, 50: 6.55013030422519, 51: 6.54601779455409,
         52: 6.54187655099902, 53: 6.53828511961511, 54: 6.53591878198258, 55: 6.5355592565903, 56: 6.53809876567644,
         57: 6.54453630199191, 58: 6.55596385845499, 59: 6.55821358950969, 60: 6.57375126879459, 61: 6.59904234989037,
         62: 6.63302932954318, 63: 6.63565536180675, 64: 6.67769701206402, 65: 6.71401159472858, 66: 6.73410895715581,
         67: 6.79329308655899, 68: 6.80423705378406, 69: 6.87351076309182, 70: 6.89036071457553, 71: 6.95467567913667,
         72: 6.99502060524489, 73: 7.03679902004235, 74: 7.11989210323835, 75: 7.12095985701246, 76: 7.20396637979448,
         77: 7.27348210247699, 78: 7.28903343599894, 79: 7.37510499495506, 80: 7.45673654133207, 81: 7.46219291819681,
         82: 7.55030920732348, 83: 7.63946600565363, 84: 7.67663441349783, 85: 7.72967559989851, 86: 7.82095042185536,
         87: 7.91330305012057, 88: 7.93409499111793, 89: 8.00674621182322, 90: 8.10129278437892, 91: 8.1969557972645,
         92: 8.22241015397274, 93: 8.29374843381361, 94: 8.39168403303347, 95: 8.49077609144318, 96: 8.5230441457777,
         97: 8.59103826493363, 98: 8.69248437064945, 99: 8.79512838889312, 100: 8.81543325340716, 101: 8.89898446505166,
         102: 9.00406691154592, 103: 9.08700154867141, 104: 9.11039020980305, 105: 9.21796901225216,
         106: 9.32681814434356, 107: 9.33424587023239, 108: 9.43695260659189, 109: 9.5483875766433,
         110: 9.55788708891965, 111: 9.66113841136715, 112: 9.76042411194057, 113: 9.77522064897225,
         114: 9.89065001114827, 115: 9.94435634884765, 116: 10.0074424052323, 117: 10.1118694010969,
         118: 10.125613926401, 119: 10.2451808598889, 120: 10.2646040491866, 121: 10.3661596832324,
         122: 10.4039243444998, 123: 10.4885670685404, 124: 10.5308347573432, 125: 10.6124198847927,
         126: 10.6460986197616, 127: 10.7377352001635, 128: 10.7502346320253, 129: 10.8438408772516,
         130: 10.8645302843748, 131: 10.9271855882173, 132: 10.9928226110753, 133: 10.999982120993,
         134: 11.0630378989452, 135: 11.1154336983768, 136: 11.1226298602491, 137: 11.1578936600544,
         138: 11.1896465724948, 139: 11.2104169269502, 140: 11.2199067014452, 141: 11.2176735301292,
         142: 11.2031438151001, 143: 11.1756289258525, 144: 11.1343460488541, 145: 11.1226298602491,
         146: 11.0790668392129, 147: 11.0087893309217, 148: 10.9928226110753, 149: 10.9237227171829,
         150: 10.8645302843748, 151: 10.8237896064481, 152: 10.7377352001635, 153: 10.7102652658468,
         154: 10.6124198847927, 155: 10.5855120924252, 156: 10.4885670685404, 157: 10.45302945988,
         158: 10.3661596832324, 159: 10.3170846961808, 160: 10.2451808598889, 161: 10.1820137039371,
         162: 10.125613926401, 163: 10.0514716169821, 164: 10.0074424052323, 165: 9.92793500670346,
         166: 9.89065001114827, 167: 9.81259237067914, 168: 9.77522064897225, 169: 9.70555431531137,
         170: 9.66113841136715, 171: 9.606210945145, 172: 9.5483875766433, 173: 9.51358157101842, 174: 9.43695260659189,
         175: 9.42657511625726, 176: 9.34481069338595, 177: 9.32681814434356, 178: 9.26684209172373,
         179: 9.21796901225216, 180: 9.19124138724022, 181: 9.11728000746188, 182: 9.11039020980305,
         183: 9.04413930396848, 184: 9.00406691154592, 185: 8.97001951435279, 186: 8.89898446505166,
         187: 8.89361778854435, 188: 8.81276913720459, 189: 8.79512838889312, 190: 8.72430777705443,
         191: 8.69248437064945, 192: 8.6234195866509, 193: 8.59103826493363, 194: 8.50123984191311,
         195: 8.49077609144318, 196: 8.39168403303347, 197: 8.33425430152789, 198: 8.29374843381361,
         199: 8.1969557972645, 200: 8.10129278437892, 201: 8.01828578773662, 202: 8.00674621182322,
         203: 7.91330305012057, 204: 7.82095042185536, 205: 7.72967559989851, 206: 7.63946600565363,
         207: 7.55030920732348, 208: 7.51517120812242, 209: 7.46219291819681, 210: 7.37510499495506,
         211: 7.28903343599894, 212: 7.20396637979448, 213: 7.11989210323835, 214: 7.07754128698554,
         215: 7.03679902004235, 216: 6.95467567913667, 217: 6.87351076309182, 218: 6.79775078437442,
         219: 6.79329308655899, 220: 6.71401159472858, 221: 6.63565536180675, 222: 6.56756448036104,
         223: 6.55821358950969, 224: 6.48167560557557, 225: 6.40603086229377, 226: 6.36187310406464,
         227: 6.33126893505127, 228: 6.25737952089608, 229: 6.18435243711734, 230: 6.16919999803463,
         231: 6.11217761984208, 232: 6.0408451226483, 233: 5.98262166705576, 234: 5.97034511519424,
         235: 5.90066788186369, 236: 5.83180382042705, 237: 5.79584296981564, 238: 5.76374344071805,
         239: 5.69647736332592, 240: 5.62999631830283, 241: 5.60279216666032, 242: 5.56429114388633,
         243: 5.49935278523684, 244: 5.43517229318978, 245: 5.39613156125098, 246: 5.37174082302225,
         247: 5.30904963323417, 248: 5.24709008434362, 249: 5.18585363769621, 250: 5.16837339278928,
         251: 5.12533185428837, 252: 5.06551639360438, 253: 5.00639901246695, 254: 4.94797156390125,
         255: 4.92092043044327, 256: 4.89022599601214, 257: 4.83315435087456, 258: 4.77674876343684,
         259: 4.72100146043682, 260: 4.68204984912139, 261: 4.66590475933062, 262: 4.61145106723389,
         263: 4.55763287987545, 264: 4.50444278056312, 265: 4.48331572084786, 266: 4.45187343916162,
         267: 4.39991761108242, 268: 4.34856813628533, 269: 4.32577220915364, 270: 4.29781793829181,
         271: 4.24766002320974, 272: 4.19808747876958, 273: 4.14909347337183, 274: 4.10067125514551,
         275: 4.09197672545471, 276: 4.05281415101772, 277: 4.00551556579404, 278: 4.00076159948214,
         279: 3.95876898124959, 280: 3.92095729029041, 281: 3.91256795523079, 282: 3.86690612076758,
         283: 3.84989850169202, 284: 3.82177718519594, 285: 3.78575731317876, 286: 3.77717492929074,
         287: 3.73309320640863, 288: 3.7273474896986, 289: 3.68952594164103, 290: 3.6737428625749,
         291: 3.64646713097687, 292: 3.62412969868831, 293: 3.60391084047523, 294: 3.57794704300117,
         295: 3.56185120544756, 296: 3.53472408626214, 297: 3.52028242964948, 298: 3.49406412072295,
         299: 3.47919878448199, 300: 3.45563128326771, 301: 3.438594608202, 302: 3.41913965585033,
         303: 3.39846430514211, 304: 3.38434436498962, 305: 3.35880234493946, 306: 3.35103438931909,
         307: 3.31960326177357, 308: 3.31902684333723, 309: 3.28804676401276, 310: 3.28086165361313,
         311: 3.2580195961092, 312: 3.24257218147152, 313: 3.22883434861722, 314: 3.20472956867104,
         315: 3.20038999558355, 316: 3.17250233053833, 317: 3.16732860011575, 318: 3.14509247194369,
         319: 3.13036412157277, 320: 3.11818774017568, 321: 3.09383103896196, 322: 3.09175835467844,
         323: 3.06562442964203, 324: 3.05772431765394, 325: 3.03988979468704, 326: 3.02203898177621,
         327: 3.01461962446565, 328: 2.98979306103301, 329: 2.98677011352747, 330: 2.96536000201683,
         331: 2.95191285249991, 332: 2.94153341230065, 333: 2.91837926466681, 334: 2.91746239500933,
         335: 2.8957864412419, 336: 2.88341399343321, 337: 2.87404699336527, 338: 2.85320460017651,
         339: 2.8497629555564, 340: 2.8332326392696, 341: 2.81650464392451, 342: 2.81441232100478, 343: 2.7966276443176,
         344: 2.78363447520481, 345: 2.78015384296773, 346: 2.76492724551913, 347: 2.75119584853022,
         348: 2.75114791955458, 349: 2.73885816851273, 350: 2.72817837939167, 351: 2.71921690618591,
         352: 2.7190404999969, 353: 2.71201656561524, 354: 2.70678673807493, 355: 2.70366623473114,
         356: 2.7028321399731, 357: 2.70450760436785, 358: 2.7089692630375, 359: 2.71655612604502, 360: 2.7190404999969,
         361: 2.72779417048063, 362: 2.74321564178533, 363: 2.75114791955458, 364: 2.76371324392736,
         365: 2.78363447520481, 366: 2.79035950944569, 367: 2.81650464392451, 368: 2.82491975946005,
         369: 2.8497629555564, 370: 2.86984287221893, 371: 2.88341399343321, 372: 2.91746239500933,
         373: 2.92878990374462, 374: 2.95191285249991, 375: 2.98677011352747, 376: 3.00726513487814,
         377: 3.02203898177621, 378: 3.05772431765394, 379: 3.09383103896196, 380: 3.11135710323285,
         381: 3.13036412157277, 382: 3.16732860011575, 383: 3.20472956867104, 384: 3.24062328335783,
         385: 3.24257218147152, 386: 3.28086165361313, 387: 3.31960326177357, 388: 3.35880234493946,
         389: 3.37716286853989, 390: 3.39846430514211, 391: 3.438594608202, 392: 3.47919878448199,
         393: 3.49801929769742, 394: 3.52028242964948, 395: 3.56185120544756, 396: 3.59566295068154,
         397: 3.60391084047523, 398: 3.64646713097687, 399: 3.67255006748947, 400: 3.68952594164103,
         401: 3.73309320640864, 402: 3.7334932222858, 403: 3.77717492929074, 404: 3.78219195173854,
         405: 3.82177718519594, 406: 3.82194780383974, 407: 3.85500993708743, 408: 3.86690612076758,
         409: 3.88334155403542, 410: 3.90835378377218, 411: 3.91256795523079, 412: 3.93127954405137,
         413: 3.9531106504921, 414: 3.95876898124959, 415: 3.97487883278048, 416: 3.9973451477691,
         417: 4.00551556579404, 418: 4.02155836231141, 419: 4.04827372119038, 420: 4.05281415101772, 421: 4.07896864862,
         422: 4.10067125514551, 423: 4.11470709392599, 424: 4.14909347337183, 425: 4.15750141417766,
         426: 4.19808747876958, 427: 4.21036282066712, 428: 4.24766002320974, 429: 4.27785644097563,
         430: 4.29781793829181, 431: 4.34856813628533, 432: 4.36873483555302, 433: 4.39991761108242,
         434: 4.45187343916162, 435: 4.50402878926657, 436: 4.50444278056312, 437: 4.55763287987545,
         438: 4.61145106723389, 439: 4.66590475933062, 440: 4.72100146043682, 441: 4.77674876343684,
         442: 4.79990754215654, 443: 4.83315435087456},
        {2: 24.3350502757448, 3: 24.3090799112342, 4: 24.2937964490893, 5: 24.2885374216053, 6: 24.2928175540197,
         7: 24.306325789127, 8: 24.3289253600201, 9: 24.3571166958392, 10: 24.3606980941352, 11: 24.4022535440139,
         12: 24.4536892577301, 13: 24.5156651734482, 14: 24.5890773156971, 15: 24.6750756305531, 16: 24.7750831989054,
         17: 24.7897546805329, 18: 24.8929339528225, 19: 25.0295690363181, 20: 25.1873416858998, 21: 25.2300773032786,
         22: 25.3737673963962, 23: 25.5910149282309, 24: 25.6782210607875, 25: 25.8494500527809, 26: 26.1343248742637,
         27: 26.1551896444232, 28: 26.5295090614024, 29: 26.5985301324691, 30: 26.9926428347352, 31: 27.0709807355526,
         32: 27.5518231396583, 33: 27.5850818505248, 34: 28.0412064023256, 35: 28.3964978759383, 36: 28.5392822286961,
         37: 29.0462050185407, 38: 29.562131914123, 39: 29.640590909536, 40: 30.0872228489117, 41: 30.6216405971588,
         42: 31.1655508243587, 43: 31.719122138603, 44: 32.2825261428479, 45: 32.8559374881099, 46: 33.4395339276057,
         47: 34.0334963718553, 48: 34.6380089447624, 49: 35.2532590406911, 50: 35.8794373825576, 51: 36.516738080952,
         52: 37.1653586943117, 53: 37.8255002901628, 54: 38.4973675074497, 55: 39.1811686199713, 56: 39.8771156009448,
         57: 40.5854241887152, 58: 41.3063139536332, 59: 41.4017729421644, 60: 42.0400083661199, 61: 42.7867348659411,
         62: 43.5467249327123, 63: 43.5938276363598, 64: 44.3202141576547, 65: 44.8344033227818, 66: 45.1074423166278,
         67: 45.7882686802215, 68: 45.9086534444575, 69: 46.5705724114305, 70: 46.7240959105849, 71: 47.2438145894193,
         72: 47.5540224960597, 73: 47.8439637218352, 74: 48.3919801823119, 75: 48.3986904718997, 76: 48.8778226635416,
         77: 49.2583616788432, 78: 49.3375870710939, 79: 49.7560263610766, 80: 50.1333026085176, 81: 50.1570950144231,
         82: 50.5250504679997, 83: 50.8811369414171, 84: 51.02378448605, 85: 51.2185615221777, 86: 51.5423673855218,
         87: 51.8602608072239, 88: 51.9300833541446, 89: 52.1665437240319, 90: 52.4691032479693, 91: 52.7722525478894,
         92: 52.8524801586543, 93: 53.073028271391, 94: 53.3770304102037, 95: 53.6884272468069, 96: 53.7912608356713,
         97: 54.0062374804167, 98: 54.3344179315858, 99: 54.6770632292839, 100: 54.7467164001655, 101: 55.0341965965673,
         102: 55.409933588145, 103: 55.7191430361971, 104: 55.8074669344428, 105: 56.2287345044113,
         106: 56.6771449249694, 107: 56.7088421887309, 108: 57.1574998968311, 109: 57.6707748182457,
         110: 57.7161206570823, 111: 58.2255673816919, 112: 58.7412906900231, 113: 58.8214632221754,
         114: 59.4698020344821, 115: 59.7846700825757, 116: 60.1743568408721, 117: 60.8465822745273,
         118: 60.9407153722937, 119: 61.785812443753, 120: 61.9273564506943, 121: 62.7230183816945,
         122: 63.0273276429665, 123: 63.7684332088775, 124: 64.1468368341647, 125: 64.9494860015701,
         126: 65.286231063743, 127: 66.3054425890426, 128: 66.4458635353684, 129: 67.6260937264108,
         130: 67.9242207115777, 131: 68.8272874993788, 132: 69.9302468849348, 133: 70.0498172153345,
         134: 71.2940618493218, 135: 72.5604071078468, 136: 72.7824409976899, 137: 73.8492455484432,
         138: 75.1609767013626, 139: 76.4960071934257, 140: 77.8547508740736, 141: 79.2376289436581,
         142: 80.6450700840105, 143: 82.0775105913299, 144: 83.5353945114316, 145: 83.8551684500338,
         146: 85.0191737773982, 147: 86.5293083496753, 148: 86.8234678842222, 149: 88.0662663586557,
         150: 89.0008925014818, 151: 89.6305242497965, 152: 90.8418346945495, 153: 91.2225669313135,
         154: 92.4952056639842, 155: 92.8428879244994, 156: 94.0482301088928, 157: 94.4919895167112,
         158: 95.558297458197, 159: 96.1703829170756, 160: 97.0682386751384, 161: 97.8785884149607,
         162: 98.6143325760478, 163: 99.6171355412608, 164: 100.230613600958, 165: 101.386563232548,
         166: 101.950836151422, 167: 103.187419998137, 168: 103.808474734005, 169: 105.020264090121,
         170: 105.834718879596, 171: 106.885663676424, 172: 108.054394595781, 173: 108.784197016928,
         174: 110.480121605833, 175: 110.716452642733, 176: 112.683029538592, 177: 113.140148981539,
         178: 114.684537328596, 179: 116.001030890132, 180: 116.72159646515, 181: 118.79483842131,
         182: 118.997302753253, 183: 120.904905886536, 184: 122.085860445977, 185: 123.052452965919,
         186: 125.092508369414, 187: 125.238145382948, 188: 127.462660685882, 189: 127.947842218765,
         190: 129.726688457784, 191: 130.514417372442, 192: 132.030930530284, 193: 132.726461148472,
         194: 134.376101201147, 195: 134.563266020913, 196: 136.067773652369, 197: 136.762927455692,
         198: 137.241545808823, 199: 138.146150864191, 200: 138.798877611191, 201: 139.192149192161,
         202: 139.246271034974, 203: 139.531313768825, 204: 139.661662406565, 205: 139.659130545943,
         206: 139.540678898347, 207: 139.319490436221, 208: 139.192149192161, 209: 139.015952430608,
         210: 138.640130132416, 211: 138.191359811471, 212: 137.674360120811, 213: 137.092728093966,
         214: 136.762927455692, 215: 136.468053605747, 216: 135.808545271775, 217: 135.096658670693,
         218: 134.376101201147, 219: 134.336473336611, 220: 133.576216688344, 221: 132.773162927304,
         222: 132.030930530284, 223: 131.935231057155, 224: 131.109504389799, 225: 130.250558636658,
         226: 129.726688457784, 227: 129.384639496621, 228: 128.528211517483, 229: 127.649362224875,
         230: 127.462660685882, 231: 126.799074719214, 232: 125.94788994317, 233: 125.238145382948,
         234: 125.096513689689, 235: 124.287389001586, 236: 123.476713513881, 237: 123.052452965919,
         238: 122.693442987846, 239: 121.944254055681, 240: 121.203885352883, 241: 120.904905886536,
         242: 120.50320723008, 243: 119.835787154674, 244: 119.1837467986, 245: 118.79483842131, 246: 118.563840530399,
         247: 117.984917149916, 248: 117.422133366162, 249: 116.874470227938, 250: 116.72159646515,
         251: 116.363376174301, 252: 115.872078446991, 253: 115.388271283758, 254: 114.908256702096,
         255: 114.684537328596, 256: 114.442533124219, 257: 113.985018967892, 258: 113.518066843604,
         259: 113.036492495457, 260: 112.683029538592, 261: 112.542939424659, 262: 112.044858602614,
         263: 111.517797879102, 264: 110.956255901955, 265: 110.716452642733, 266: 110.373711975137,
         267: 109.76143185918, 268: 109.101533191507, 269: 108.784197016928, 270: 108.408541157239,
         271: 107.67710034218, 272: 106.885663676424, 273: 106.07105137699, 274: 105.190085972234,
         275: 105.020264090121, 276: 104.273864778357, 277: 103.292660549982, 278: 103.187419998137,
         279: 102.27570912321, 280: 101.386563232548, 281: 101.192255651273, 282: 100.065655629862,
         283: 99.6171355412608, 284: 98.8833143993853, 285: 97.8785884149607, 286: 97.6408261805501,
         287: 96.3479351308142, 288: 96.1703829170756, 289: 95.0050572368628, 290: 94.4919895167112,
         291: 93.6053019883094, 292: 92.8428879244994, 293: 92.1510069034411, 294: 91.2225669313135,
         295: 90.6443017097496, 296: 89.6305242497965, 297: 89.0874161373167, 298: 88.0662663586557,
         299: 87.4829888214702, 300: 86.5293083496753, 301: 85.8343549986172, 302: 85.0191737773982,
         303: 84.1457814884601, 304: 83.5353945114316, 305: 82.4226114653546, 306: 82.0775105913299,
         307: 80.6712819371245, 308: 80.6450700840105, 309: 79.2376289436581, 310: 78.9099161199043,
         311: 77.8547508740736, 312: 77.1390271952357, 313: 76.4960071934257, 314: 75.3660208808235,
         315: 75.1609767013626, 316: 73.8492455484432, 317: 73.6071458608263, 318: 72.5604071078468,
         319: 71.8685479292952, 320: 71.2940618493218, 321: 70.1476661364621, 322: 70.0498172153345,
         323: 68.8272874993788, 324: 68.4591198587743, 325: 67.6260937264108, 326: 66.7927009715151,
         327: 66.4458635353684, 328: 65.286231063743, 329: 65.1453649751267, 330: 64.1468368341647,
         331: 63.5149985227811, 332: 63.0273276429665, 333: 61.9273564506943, 334: 61.8834600327967,
         335: 60.8465822745273, 336: 60.2416905656456, 337: 59.7846700825757, 338: 58.7412906900231,
         339: 58.5640835600789, 340: 57.7161206570823, 341: 56.8202797118149, 342: 56.7088421887309,
         343: 55.7191430361971, 344: 54.9508144725404, 345: 54.7467164001655, 346: 53.7912608356713,
         347: 52.8524801586543, 348: 52.8488478923686, 349: 51.9300833541446, 350: 51.02378448605,
         351: 50.1333026085176, 352: 50.1114336785975, 353: 49.2583616788432, 354: 48.3986904718997,
         355: 47.5540224960597, 356: 46.7240959105849, 357: 45.9086534444575, 358: 45.1074423166278,
         359: 44.3202141576547, 360: 44.1410044817649, 361: 43.5467249327123, 362: 42.7867348659411,
         363: 42.4828444062143, 364: 42.0400083661199, 365: 41.4783023561527, 366: 41.3063139536332,
         367: 40.7466864556658, 368: 40.5854241887152, 369: 40.1725475311001, 370: 39.8771156009448,
         371: 39.6987643544338, 372: 39.2998889981766, 373: 39.1811686199713, 374: 38.9574087004126,
         375: 38.6564740741274, 376: 38.4973675074497, 377: 38.388394179178, 378: 38.1471530643128,
         379: 37.9254586343227, 380: 37.8255002901628, 381: 37.7192082806976, 382: 37.524214949993,
         383: 37.3374447044009, 384: 37.1653586943117, 385: 37.1559343755495, 386: 36.9735820930462,
         387: 36.7907414133927, 388: 36.6049885989297, 389: 36.516738080952, 390: 36.4101556877017,
         391: 36.203384149666, 392: 35.9850869479788, 393: 35.8794373825576, 394: 35.7459784377675,
         395: 35.4824078955092, 396: 35.2532590406911, 397: 35.1923750056439, 398: 34.8584978349605,
         399: 34.6380089447624, 400: 34.4787362509971, 401: 34.0377914723627, 402: 34.0334963718553,
         403: 33.5044009175443, 404: 33.4395339276057, 405: 32.8585823160396, 406: 32.8559374881099,
         407: 32.2825261428479, 408: 32.0507939341142, 409: 31.719122138603, 410: 31.1655508243587,
         411: 31.0667104438721, 412: 30.6216405971588, 413: 30.0872228489117, 414: 29.9498554723835,
         415: 29.562131914123, 416: 29.0462050185407, 417: 28.8714406644856, 418: 28.5392822286961,
         419: 28.0412064023256, 420: 27.9651934224204, 421: 27.5518231396583, 422: 27.2512903043046,
         423: 27.0709807355526, 424: 26.6845936961911, 425: 26.5985301324691, 426: 26.2331190186691,
         427: 26.1343248742637, 428: 25.8675595640187, 429: 25.6782210607875, 430: 25.5655132991798,
         431: 25.3157738653052, 432: 25.2300773032786, 433: 25.1084018481736, 434: 24.9352296082051,
         435: 24.7897546805329, 436: 24.7886720157799, 437: 24.6698076721189, 438: 24.5707802150855,
         439: 24.4894625619171, 440: 24.4240145571006, 441: 24.3728567283821, 442: 24.3571166958392,
         443: 24.3350502757448}
    ],
    'Quartzite': [
        {2: 9.65923094863073, 3: 9.75043074211146, 4: 9.84249161887875, 5: 9.93542170904342, 6: 10.0292292194785,
         7: 10.1239224345442, 8: 10.2195097168191, 9: 10.3159995078392, 10: 10.413400328843, 11: 10.5117207815243,
         12: 10.5279726553071, 13: 10.6109695487917, 14: 10.7111553955352, 15: 10.8122871694008, 16: 10.9143738015714,
         17: 11.0174243075557, 18: 11.1214477879841, 19: 11.226453429413, 20: 11.3324505051355, 21: 11.3661766978582,
         22: 11.4394483760008, 23: 11.5474564912403, 24: 11.6564843893027, 25: 11.7665416986961, 26: 11.8776381388383,
         27: 11.9897835209149, 28: 12.1029877487464, 29: 12.2172608196623, 30: 12.2790529881848, 31: 12.332612825384,
         32: 12.4490539529162, 33: 12.5665944854466, 34: 12.6852448032539, 35: 12.8022654795732, 36: 12.8050153846244,
         37: 12.9259168067776, 38: 13.0479597468001, 39: 13.1711549825887, 40: 13.1723570666245, 41: 13.295513393802,
         42: 13.4210459628216, 43: 13.4738699720966, 44: 13.5477637757214, 45: 13.6756780232472, 46: 13.7380968263701,
         47: 13.8048000018045, 48: 13.9351411144565, 49: 13.9769618439374, 50: 14.066712871931, 51: 14.1980015610898,
         52: 14.1995268936368, 53: 14.33359490869, 54: 14.4038519512517, 55: 14.4689287569499, 56: 14.599995505836,
         57: 14.6055403900643, 58: 14.7434418725252, 59: 14.7865427749695, 60: 14.8826453827342, 61: 14.9661517164776,
         62: 15.0231632140782, 63: 15.1398936900056, 64: 15.1650077760146, 65: 15.3081915951677, 66: 15.3085734784151,
         67: 15.4527273164345, 68: 15.472789747697, 69: 15.5986277041017, 70: 15.6334527092403, 71: 15.7459056429731,
         72: 15.7910929519183, 73: 15.894574139507, 74: 15.946184307342, 75: 16.0446463229651, 76: 16.0991488755027,
         77: 16.1961354465721, 78: 16.2503612763633, 79: 16.3490548886859, 80: 16.4001522283368, 81: 16.5034181539793,
         82: 16.5488115507775, 83: 16.6592388746323, 84: 16.6965906830411, 85: 16.8165308115362, 86: 16.843704807071,
         87: 16.975307855509, 88: 16.9903346536124, 89: 17.1355840285219, 90: 17.1366280639302, 91: 17.2831057539004,
         92: 17.2973734849377, 93: 17.4296068573504, 94: 17.4606905127606, 95: 17.5761710899916, 96: 17.6255495348984,
         97: 17.7228361643225, 98: 17.791965110436, 99: 17.8696131605801, 100: 17.9599519359211, 101: 18.0164878478177,
         102: 18.1295248466622, 103: 18.1634219270929, 104: 18.3006988180387, 105: 18.3103541823607,
         106: 18.457862190828, 107: 18.4734889668232, 108: 18.6057455824254, 109: 18.647910552517,
         110: 18.7535247083972, 111: 18.8239789786973, 112: 18.901071408934, 113: 19.0017097943774,
         114: 19.0482400405766, 115: 19.1811186953804, 116: 19.1948676965105, 117: 19.3417896954386,
         118: 19.3622215257249, 119: 19.4886884559256, 120: 19.5450342790243, 121: 19.6347482264678,
         122: 19.7295730998995, 123: 19.779758838672, 124: 19.9158542854041, 125: 19.9234920325513,
         126: 20.0676618026423, 127: 20.1038942864643, 128: 20.2107799561305, 129: 20.2937097093312,
         130: 20.3522082630745, 131: 20.4853173170478, 132: 20.491662761663, 133: 20.6314890460297,
         134: 20.6787340309288, 135: 20.7694727996916, 136: 20.8739769320555, 137: 20.9049579603513,
         138: 21.039362476566, 139: 21.0710632627841, 140: 21.1726175805532, 141: 21.270010428268,
         142: 21.3027410216918, 143: 21.4315110101453, 144: 21.4708359979958, 145: 21.5585211188971,
         146: 21.673557707342, 147: 21.6816133925309, 148: 21.8044269810464, 149: 21.8781934591337,
         150: 21.923328861081, 151: 22.0397816807411, 152: 22.0847613252315, 153: 22.153685788043,
         154: 22.2637044290708, 155: 22.2932795481256, 156: 22.3717053791164, 157: 22.4750944525862,
         158: 22.5037665425468, 159: 22.5761736302077, 160: 22.672621329896, 161: 22.7162408970925,
         162: 22.7656331619299, 163: 22.8547236269862, 164: 22.9307213758689, 165: 22.9383842477856,
         166: 23.0196186696086, 167: 23.0949335748143, 168: 23.1472269201472, 169: 23.1653272930876,
         170: 23.2320672160711, 171: 23.292929858947, 172: 23.3480846065064, 173: 23.3657766500373,
         174: 23.3989409518053, 175: 23.4446994983861, 176: 23.484800755832, 177: 23.5194291477282,
         178: 23.5487850057857, 179: 23.57309542275, 180: 23.5863898661756, 181: 23.5928448646534,
         182: 23.6084074508628, 183: 23.6196652952612, 184: 23.6270192281811, 185: 23.6308910863276,
         186: 23.6317093299425, 187: 23.6298903784885, 188: 23.6258168725717, 189: 23.61981435578,
         190: 23.6121279062622, 191: 23.6029000100674, 192: 23.5921504895939, 193: 23.5863898661756,
         194: 23.5799014839585, 195: 23.5658488004504, 196: 23.5493858449638, 197: 23.5298440059297,
         198: 23.5063308541777, 199: 23.4776955300009, 200: 23.4424813496229, 201: 23.398860266331,
         202: 23.3657766500373, 203: 23.3441625942117, 204: 23.2744626683438, 205: 23.1859764917048,
         206: 23.1472269201472, 207: 23.0692534845722, 208: 22.9307213758689, 209: 22.9136027813593,
         210: 22.7162408970925, 211: 22.6876272376622, 212: 22.5037665425468, 213: 22.3038088151508,
         214: 22.2932795481256, 215: 22.0847613252315, 216: 21.8781934591337, 217: 21.673557707342,
         218: 21.4708359979958, 219: 21.270010428268, 220: 21.0710632627841, 221: 20.8739769320555,
         222: 20.7966180496044, 223: 20.6787340309288, 224: 20.4853173170478, 225: 20.2937097093312,
         226: 20.180666308553, 227: 20.1038942864643, 228: 19.9158542854041, 229: 19.7295730998995,
         230: 19.7250508207861, 231: 19.5450342790243, 232: 19.3622215257249, 233: 19.3433252623845,
         234: 19.1811186953804, 235: 19.0031070327767, 236: 19.0017097943774, 237: 18.8239789786973,
         238: 18.6937018824573, 239: 18.647910552517, 240: 18.4734889668232, 241: 18.4052949663792,
         242: 18.3006988180387, 243: 18.1332891409595, 244: 18.1295248466622, 245: 17.9599519359211,
         246: 17.876196332629, 247: 17.791965110436, 248: 17.6295343984013, 249: 17.6255495348984,
         250: 17.4606905127606, 251: 17.3929665226656, 252: 17.2973734849377, 253: 17.1640897733796,
         254: 17.1355840285219, 255: 16.975307855509, 256: 16.9420434275182, 257: 16.8165308115362,
         258: 16.7258289318509, 259: 16.6592388746323, 260: 16.5146100559574, 261: 16.5034181539793,
         262: 16.3490548886859, 263: 16.3073707517723, 264: 16.1961354465721, 265: 16.1036591379073,
         266: 16.0446463229651, 267: 15.9030007696693, 268: 15.894574139507, 269: 15.7459056429731,
         270: 15.704038273999, 271: 15.5986277041017, 272: 15.5067709969857, 273: 15.4527273164345,
         274: 15.3108137318118, 275: 15.3081915951677, 276: 15.1650077760146, 277: 15.1141568204595,
         278: 15.0231632140782, 279: 14.9174401436924, 280: 14.8826453827342, 281: 14.7434418725252,
         282: 14.7192563570956, 283: 14.6055403900643, 284: 14.5183402467469, 285: 14.4689287569499,
         286: 14.33359490869, 287: 14.3143959445063, 288: 14.1995268936368, 289: 14.1050803078088, 290: 14.066712871931,
         291: 13.9351411144565, 292: 13.8895473499171, 293: 13.8048000018045, 294: 13.6756780232472,
         295: 13.666376857898, 296: 13.5477637757214, 297: 13.4324986032613, 298: 13.4210459628216,
         299: 13.295513393802, 300: 13.1863327017459, 301: 13.1711549825887, 302: 13.0479597468001,
         303: 12.9264810436202, 304: 12.9259168067776, 305: 12.8050153846244, 306: 12.6852448032539,
         307: 12.6515619574008, 308: 12.5665944854466, 309: 12.4490539529162, 310: 12.3647354276918,
         311: 12.332612825384, 312: 12.2172608196623, 313: 12.1029877487464, 314: 12.0714582057785,
         315: 11.9897835209149, 316: 11.8776381388383, 317: 11.7805065394133, 318: 11.7665416986961,
         319: 11.6564843893027, 320: 11.5474564912403, 321: 11.5011804895804, 322: 11.4394483760008,
         323: 11.3324505051355, 324: 11.2391483533708, 325: 11.226453429413, 326: 11.1214477879841,
         327: 11.0174243075557, 328: 10.997478541641, 329: 10.9143738015714, 330: 10.8122871694008,
         331: 10.7758140426088, 332: 10.7111553955352, 333: 10.6109695487917, 334: 10.572526389562,
         335: 10.5117207815243, 336: 10.413400328843, 337: 10.3857462210275, 338: 10.3159995078392,
         339: 10.2195097168191, 340: 10.2135164979038, 341: 10.1239224345442, 342: 10.0545327649784,
         343: 10.0292292194785, 344: 9.93542170904342, 345: 9.90685301562967, 346: 9.84249161887875,
         347: 9.76935691394705, 348: 9.75043074211146, 349: 9.65923094863073, 350: 9.64102894408833,
         351: 9.56888418437003, 352: 9.52103755189043, 353: 9.47938247059583, 354: 9.40850853403047,
         355: 9.39071790320299, 356: 9.30288265201669, 357: 9.215868960101, 358: 9.20372011400202,
         359: 9.12966914307377, 360: 9.11048919307443, 361: 9.04427558842805, 362: 9.02282692855776,
         363: 8.95968075485982, 364: 8.94042301034197, 365: 8.87587717160197, 366: 8.86301650377695,
         367: 8.79285743776453, 368: 8.79039306097102, 369: 8.72235872884746, 370: 8.71061422168114,
         371: 8.65876143198021, 372: 8.6291402602615, 373: 8.59950249349628, 374: 8.54842835835001,
         375: 8.54452139462363, 376: 8.49374092057048, 377: 8.4684713880903, 378: 8.44714415431189,
         379: 8.40477663604995, 380: 8.38926228829579, 381: 8.36664549244038, 382: 8.33287501138581,
         383: 8.31079406382609, 384: 8.30352653409281, 385: 8.27887104202871, 386: 8.25903391325744,
         387: 8.24427747510473, 388: 8.234960069191, 389: 8.23305978496923, 390: 8.23155425362638,
         391: 8.23305978496923, 392: 8.23452862693631, 393: 8.24455190934473, 394: 8.2622474399135,
         395: 8.28826336901013, 396: 8.31079406382609, 397: 8.32348918549491, 398: 8.36881577278551,
         399: 8.38926228829579, 400: 8.42463848382329, 401: 8.4684713880903, 402: 8.4908011529083,
         403: 8.54842835835001, 404: 8.56642007795623, 405: 8.6291402602615, 406: 8.64925580715174,
         407: 8.71061422168114, 408: 8.73583113663019, 409: 8.79285743776453, 410: 8.8220568131023,
         411: 8.87587717160197, 412: 8.90409072168825, 413: 8.95968075485982, 414: 8.97900288875029,
         415: 9.04427558842805, 416: 9.04498745020116, 417: 9.10136619609985, 418: 9.12966914307377,
         419: 9.14801993332201, 420: 9.1854373749256, 421: 9.21417783616271, 422: 9.215868960101, 423: 9.23545588333849,
         424: 9.24990557051306, 425: 9.2584745205712, 426: 9.26211283935937, 427: 9.26173464327536,
         428: 9.25821515842711, 429: 9.25239652068987, 430: 9.24510100245206, 431: 9.23715117523006,
         432: 9.22939737268081, 433: 9.22275381425103, 434: 9.21824601700905, 435: 9.21707388261839,
         436: 9.22069746744897, 437: 9.23095656462592, 438: 9.25024199173038, 439: 9.28174802199873,
         440: 9.3028826520167, 441: 9.33350030419166, 442: 9.39071790320299, 443: 9.41996170728562,
         444: 9.47938247059583, 445: 9.56888418437003, 446: 9.59481736262913, 447: 9.65923094863073},
        {2: 94.4696836952233, 3: 94.277282636547, 4: 94.1724174223699, 5: 94.1352800173716, 6: 94.1505080901522,
         7: 94.2059779540137, 8: 94.2919570706711, 9: 94.4005054019044, 10: 94.5250544277162, 11: 94.6601171306709,
         12: 94.6834847118591, 13: 94.8065755832407, 14: 94.9554628107666, 15: 95.1025259237776, 16: 95.2454402109576,
         17: 95.3826314731009, 18: 95.5132905575034, 19: 95.6373884016926, 20: 95.7556759152714, 21: 95.7918788528707,
         22: 95.8723766934969, 23: 95.9878452293597, 24: 96.1036401334511, 25: 96.2230760359283, 26: 96.3497383987722,
         27: 96.4873229081378, 28: 96.639488697273, 29: 96.8097404424074, 30: 96.9132481983286, 31: 97.0036464456056,
         32: 97.2244837944065, 33: 97.4718149974445, 34: 97.7478674722182, 35: 98.0477446399871, 36: 98.0548134572278,
         37: 98.4002033327041, 38: 98.7784418536979, 39: 99.1911323269355, 40: 99.1955218476922, 41: 99.6456637076799,
         42: 100.135703778778, 43: 100.356735290197, 44: 100.66637705822, 45: 101.236402832845, 46: 101.531542256218,
         47: 101.847622870772, 48: 102.499668268925, 49: 102.720101875746, 50: 103.194634380203, 51: 103.922575141592,
         52: 103.931064504457, 53: 104.712094555637, 54: 105.139124931203, 55: 105.536582887972, 56: 106.369916028715,
         57: 106.405357583205, 58: 107.319338256772, 59: 107.615115147283, 60: 108.278883675373, 61: 108.874890951654,
         62: 109.284538595072, 63: 110.149414081018, 64: 110.336765779545, 65: 111.435856777838, 66: 111.438857172121,
         67: 112.580692626565, 68: 112.743394882647, 69: 113.772257449956, 70: 114.063203914877, 71: 115.010316738069,
         72: 115.398463039623, 73: 116.294446614224, 74: 116.749353120444, 75: 117.624042283385, 76: 118.116057138145,
         77: 118.998340539699, 78: 119.498760215558, 79: 120.416455100328, 80: 120.897649642623, 81: 121.87742258968,
         82: 122.312914901752, 83: 123.380256290748, 84: 123.744747693497, 85: 124.924004392831, 86: 125.193341962517,
         87: 126.507809429041, 88: 126.658893923846, 89: 128.130965889999, 90: 128.141602089472, 91: 129.641667295226,
         92: 129.788785720357, 93: 131.159292727985, 94: 131.483959324712, 95: 132.694683953196, 96: 133.216832170614,
         97: 134.248048942715, 98: 134.987806660194, 99: 135.819598102985, 100: 136.797644649548, 101: 137.409544303529,
         102: 138.647483691151, 103: 139.018102905788, 104: 140.538849439127, 105: 140.64549179229,
         106: 142.291931396162, 107: 142.468477553781, 108: 143.957644730992, 109: 144.440127295695,
         110: 145.642857421033, 111: 146.459630591125, 112: 147.347797731763, 113: 148.530205063779,
         114: 149.072696600809, 115: 150.655510501612, 116: 150.817787669225, 117: 152.583307313138,
         118: 152.833905072252, 119: 154.369494675767, 120: 155.071615973079, 121: 156.176591699818,
         122: 157.37758421854, 123: 158.00484316025, 124: 159.757582853994, 125: 159.854496697435,
         126: 161.725802850699, 127: 162.210893613825, 128: 163.619015092259, 129: 164.750408978541,
         130: 165.534389861558, 131: 167.385643674446, 132: 167.472186599995, 133: 169.432667786072,
         134: 170.121220077551, 135: 171.416098970946, 136: 172.971929565397, 137: 173.422748814397,
         138: 175.45288912122, 139: 175.95068601916, 140: 177.506794878041, 141: 179.072311230605,
         142: 179.584744290563, 143: 181.687018821253, 144: 182.358407484999, 145: 183.813903227464,
         146: 185.82876916804, 147: 185.965685600005, 148: 188.142657402168, 149: 189.52557275555,
         150: 190.345113509202, 151: 192.573352248259, 152: 193.481908529836, 153: 194.827675438797,
         154: 197.10838843347, 155: 197.756895036392, 156: 199.415800159483, 157: 201.750223160438,
         158: 202.438585075735, 159: 204.111973638668, 160: 206.501371498072, 161: 207.659307869564,
         162: 208.91874038744, 163: 211.364407744294, 164: 213.620672443644, 165: 213.838704839242,
         166: 216.34196682085, 167: 218.874532761033, 168: 220.799577479163, 169: 221.436745700991,
         170: 224.028952697666, 171: 226.651504870758, 172: 229.304757450284, 173: 230.267203679679,
         174: 231.98906982469, 175: 234.704805589538, 176: 237.452332596749, 177: 240.232023004435,
         178: 243.044253327302, 179: 245.889404487659, 180: 247.856589989508, 181: 248.767861867004,
         182: 251.680015358233, 183: 254.626259418448, 184: 257.606993122388, 185: 260.622620216483,
         186: 263.673549173546, 187: 266.760193248097, 188: 269.882970532342, 189: 273.042304012802,
         190: 276.238621627612, 191: 279.472356324481, 192: 282.743946119337, 193: 284.294294837537,
         194: 286.05383415566, 195: 289.402468764504, 196: 292.790303525223, 197: 296.217797326914,
         198: 299.685414430569, 199: 303.193624531964, 200: 306.74290282528, 201: 310.333730067466,
         202: 312.584125980601, 203: 313.966592643361, 204: 317.641982631576, 205: 321.360397871146,
         206: 322.713988054467, 207: 325.122342028963, 208: 328.568879661844, 209: 328.928324668, 210: 332.382579808565,
         211: 332.778861316332, 212: 334.969207044992, 213: 336.674473536964, 214: 336.754004838346,
         215: 337.891409140985, 216: 338.555965060852, 217: 338.82942943912, 218: 338.774856056438,
         219: 338.440712048303, 220: 337.863945287731, 221: 337.072282017117, 222: 336.674473536964,
         223: 336.09312565927, 224: 334.949309483336, 225: 333.648976294921, 226: 332.778861316332,
         227: 332.21077059016, 228: 330.65680048685, 229: 328.973119225611, 230: 328.928324668, 231: 327.210114778116,
         232: 325.33143337582, 233: 325.122342028963, 234: 323.389835756845, 235: 321.360397871146,
         236: 321.345003267809, 237: 319.261277000914, 238: 317.641982631576, 239: 317.091058336375,
         240: 314.877479732364, 241: 313.966592643361, 242: 312.612277965331, 243: 310.333730067466,
         244: 310.284012096824, 245: 307.948844489365, 246: 306.74290282528, 247: 305.564469636469,
         248: 303.193624531964, 249: 303.137050613753, 250: 300.717352292756, 251: 299.685414430569,
         252: 298.267006397611, 253: 296.217797326914, 254: 295.790583536932, 255: 293.317951702538,
         256: 292.790303525223, 257: 290.847773320811, 258: 289.402468764504, 259: 288.366126357956,
         260: 286.05383415566, 261: 285.878893994046, 262: 283.421760810611, 263: 282.743946119337,
         264: 280.974380044213, 265: 279.472356324481, 266: 278.533679359877, 267: 276.238621627612,
         268: 276.104770823629, 269: 273.722195867707, 270: 273.042304012802, 271: 271.363746013852,
         272: 269.882970532342, 273: 269.027814483817, 274: 266.760193248097, 275: 266.719024330468,
         276: 264.474941467023, 277: 263.673549173546, 278: 262.264866530212, 279: 260.622620216483,
         280: 260.091178431133, 281: 257.972645921696, 282: 257.606993122388, 283: 255.917733887108,
         284: 254.626259418448, 285: 253.906563251784, 286: 251.953046000735, 287: 251.680015358233,
         288: 250.075306269716, 289: 248.767861867004, 290: 248.245654862792, 291: 246.487843040786,
         292: 245.889404487659, 293: 244.797295863231, 294: 243.159236429817, 295: 243.044253327302,
         296: 241.60684843481, 297: 240.232023004435, 298: 240.097981700595, 299: 238.671633976498,
         300: 237.452332596749, 301: 237.286251358396, 302: 235.976244830199, 303: 234.704805589538,
         304: 234.699026739888, 305: 233.493459845648, 306: 232.315216903255, 307: 231.98906982469,
         308: 231.186727875727, 309: 230.088641400005, 310: 229.304757450284, 311: 229.013666378404,
         312: 227.974221990713, 313: 226.939043374976, 314: 226.651504870758, 315: 225.926881410089,
         316: 224.919355345248, 317: 224.028952697666, 318: 223.90432972563, 319: 222.903758622962,
         320: 221.883324888781, 321: 221.436745700991, 322: 220.856935974636, 323: 219.817884961569,
         324: 218.874532761033, 325: 218.749390122571, 326: 217.676739814144, 327: 216.564221596633,
         328: 216.34196682085, 329: 215.438039877095, 330: 214.273759837393, 331: 213.838704839242,
         332: 213.083929130115, 333: 211.857312938228, 334: 211.364407744294, 335: 210.599290232731,
         336: 209.300693033531, 337: 208.91874038744, 338: 207.970490600821, 339: 206.590597891744,
         340: 206.501371498072, 341: 205.184195457112, 342: 204.111973638668, 343: 203.724393688799,
         344: 202.226259386043, 345: 201.750223160438, 346: 200.68353566342, 347: 199.415800159483,
         348: 199.088190612974, 349: 197.448223595177, 350: 197.10838843347, 351: 195.758552142059,
         352: 194.827675438797, 353: 194.012177550642, 354: 192.573352248259, 355: 192.208384660469,
         356: 190.345113509202, 357: 188.419597940044, 358: 188.142657402168, 359: 186.423123545295,
         360: 185.965685600005, 361: 184.349877322295, 362: 183.813903227464, 363: 182.191991520532,
         364: 181.687018821253, 365: 179.939186070096, 366: 179.584744290563, 367: 177.578302821639,
         368: 177.506794878041, 369: 175.45288912122, 370: 175.08086406456, 371: 173.422748814397,
         372: 172.422868367469, 373: 171.416098970946, 374: 169.57402177513, 375: 169.432667786072,
         376: 167.472186599995, 377: 166.420375353761, 378: 165.534389861558, 379: 163.619015092259,
         380: 162.845516636853, 381: 161.725802850699, 382: 159.854496697435, 383: 158.458725455963,
         384: 158.00484316025, 385: 156.176591699818, 386: 154.369494675767, 387: 152.583307313138,
         388: 150.817787669225, 389: 149.834659585898, 390: 149.072696600809, 391: 148.176103407405,
         392: 147.347797731763, 393: 145.642857421033, 394: 143.957644730992, 395: 142.291931396162,
         396: 141.211567791582, 397: 140.64549179229, 398: 139.018102905788, 399: 138.402276979248,
         400: 137.409544303529, 401: 136.333615973688, 402: 135.819598102985, 403: 134.60698399343,
         404: 134.248048942715, 405: 133.060843322694, 406: 132.694683953196, 407: 131.599139506125,
         408: 131.159292727985, 409: 130.152806985832, 410: 129.641667295226, 411: 128.659008209811,
         412: 128.141602089472, 413: 127.04507641458, 414: 126.658893923846, 415: 125.209427187591,
         416: 125.193341962517, 417: 123.744747693497, 418: 122.882287180753, 419: 122.312914901752,
         420: 120.897649642623, 421: 119.498760215558, 422: 119.389417989134, 423: 118.116057138145,
         424: 116.749353120444, 425: 115.398463039623, 426: 114.063203914877, 427: 112.743394882647,
         428: 111.438857172121, 429: 110.149414081018, 430: 108.874890951654, 431: 107.615115147283,
         432: 106.369916028715, 433: 105.139124931203, 434: 103.922575141592, 435: 102.720101875746,
         436: 101.531542256218, 437: 100.356735290197, 438: 99.1955218476922, 439: 98.0477446399871,
         440: 97.5237655607272, 441: 96.9132481983286, 442: 96.1041517807271, 443: 95.7918788528707,
         444: 95.3030574930046, 445: 94.7867874165212, 446: 94.6834847118591, 447: 94.4696836952233}
    ],
    'Schist': [
        {2: 4.97245303290997, 3: 5.1674101282601, 4: 5.37001098993157, 5: 5.58055531034372, 6: 5.79935453208492,
         7: 6.02673230860646, 8: 6.22649711355175, 9: 6.26302498297912, 10: 6.50858208542044, 11: 6.66009306129943,
         12: 6.7637668503289, 13: 7.02009498226722, 14: 7.02895675358957, 15: 7.30454407094621, 16: 7.33494973416729,
         17: 7.59093645826561, 18: 7.62519595288457, 19: 7.88855755455274, 20: 7.8981454011855, 21: 8.15627235172142,
         22: 8.1978476086084, 23: 8.40450418349194, 24: 8.51926413025667, 25: 8.64614183336273, 26: 8.85328256710522,
         27: 8.88300805860679, 28: 9.11509752551523, 29: 9.20039700783966, 30: 9.3459634151117, 31: 9.56112091309227,
         32: 9.57686939957828, 33: 9.80840525634322, 34: 9.93598787496622, 35: 10.0428504133864, 36: 10.2805069970847,
         37: 10.3255524063388, 38: 10.5235680533028, 39: 10.730390761111, 40: 10.7713806521224, 41: 11.0264456650083,
         42: 11.1511017866174, 43: 11.2884397574666, 44: 11.5567024017947, 45: 11.5883078094565, 46: 11.8354617563724,
         47: 12.042655556052, 48: 12.1202982547808, 49: 12.4146125888185, 50: 12.5148171093078, 51: 12.7184553521087,
         52: 13.0054909027696, 53: 13.0274854305133, 54: 13.3500589517451, 55: 13.5154027537666, 56: 13.679170133853,
         57: 14.0141267375209, 58: 14.0453069370585, 59: 14.3637451669228, 60: 14.5959873005787, 61: 14.7173177556726,
         62: 15.079828203884, 63: 15.1682584249221, 64: 15.4544846801258, 65: 15.7629668282939, 66: 15.8314381712506,
         67: 16.2225753313113, 68: 16.3809922187009, 69: 16.621469078997, 70: 17.0210703572016, 71: 17.0232487952386,
         72: 17.4428025786816, 73: 17.6906866003977, 74: 17.8654101630338, 75: 18.2956316470101, 76: 18.3842929253919,
         77: 18.7426149748751, 78: 19.1050937705842, 79: 19.1885545556291, 80: 19.6531496805044, 81: 19.8541553631731,
         82: 20.1251690540983, 83: 20.5978296353795, 84: 20.6325857343835, 85: 21.0971634420659, 86: 21.4415363584951,
         87: 21.593502118231, 88: 22.1052442238129, 89: 22.2822038561326, 90: 22.6302778729615, 91: 23.1499969060775,
         92: 23.1558317643381, 93: 23.7045411744748, 94: 24.0637123760429, 95: 24.2531024879212, 96: 24.816534168529,
         97: 25.0071886516607, 98: 25.3951212868379, 99: 25.966441780846, 100: 25.9876562056292, 101: 26.575299436423,
         102: 27.006565370839, 103: 27.1738163515059, 104: 27.7936810901774, 105: 28.0654233440034,
         106: 28.4221124810456, 107: 29.0504669753931, 108: 29.1657964151427, 109: 29.7086286907742,
         110: 30.3093122844805, 111: 30.3508642936131, 112: 31.0336344074138, 113: 31.4976624701803,
         114: 31.7046166911113, 115: 32.3975263174652, 116: 32.7326048104827, 117: 33.0966508969268,
         118: 33.8006394235764, 119: 34.0159660639445, 120: 34.5269696248004, 121: 35.2429191806589,
         122: 35.3496446116279, 123: 35.9949578765514, 124: 36.7234341222382, 125: 36.7356132652341,
         126: 37.4987954866677, 127: 38.1759221853377, 128: 38.2470069276611, 129: 39.0347084779537,
         130: 39.6727019140364, 131: 39.7994635100343, 132: 40.5960988684592, 133: 41.2281665265047,
         134: 41.3706245548987, 135: 42.1726329679258, 136: 42.8446169061104, 137: 42.9475017286431,
         138: 43.7494051547986, 139: 44.5131468436025, 140: 44.5244441479408, 141: 45.3063097487535,
         142: 46.0596010441176, 143: 46.2701330957723, 144: 46.8177298207485, 145: 47.5499466287489,
         146: 48.084266017715, 147: 48.2525805009484, 148: 48.9514198012359, 149: 49.6031006503582,
         150: 49.9695264259708, 151: 50.2266993952563, 152: 50.8262702143874, 153: 51.374509446493,
         154: 51.8721224802463, 155: 51.9287030463537, 156: 52.3454614801259, 157: 52.7671088294185,
         158: 53.133829806489, 159: 53.4461965277147, 160: 53.704743922879, 161: 53.9100174404209,
         162: 53.9646939434445, 163: 54.0684416078387, 164: 54.1746044738312, 165: 54.2258797851426,
         166: 54.2227159705157, 167: 54.1651313173777, 168: 54.0525247029379, 169: 53.9646939434445,
         170: 53.8875001990849, 171: 53.6703840488138, 172: 53.3926606656544, 173: 53.048614374386,
         174: 52.630515182645, 175: 52.1282347296158, 176: 51.9287030463537, 177: 51.5411368168061,
         178: 50.846393607769, 179: 50.0152626015341, 180: 49.9695264259708, 181: 49.0293484593567,
         182: 48.084266017715, 183: 47.8338697360328, 184: 46.3602032953928, 185: 46.2701330957723,
         186: 44.5244441479408, 187: 44.4654253231318, 188: 42.8446169061104, 189: 41.7873455625529,
         190: 41.2281665265047, 191: 39.6727019140364, 192: 38.1759221853377, 193: 36.7356132652341,
         194: 35.5691763453444, 195: 35.3496446116279, 196: 34.0159660639445, 197: 33.8990861659863,
         198: 32.7326048104827, 199: 31.4976624701803, 200: 30.3093122844805, 201: 29.1657964151427,
         202: 28.0654233440034, 203: 27.7321596116564, 204: 27.006565370839, 205: 25.9876562056292,
         206: 25.0071886516607, 207: 25.0039750185951, 208: 24.0637123760429, 209: 23.1558317643381,
         210: 23.0286169380188, 211: 22.2822038561326, 212: 21.4415363584951, 213: 21.426323730366,
         214: 20.6325857343835, 215: 20.0830317368877, 216: 19.8541553631731, 217: 19.1050937705842,
         218: 18.9092455620336, 219: 18.3842929253919, 220: 17.8697369122291, 221: 17.6906866003977,
         222: 17.0232487952386, 223: 16.9332832798941, 224: 16.3809922187009, 225: 16.0838963033393,
         226: 15.7629668282939, 227: 15.300086688271, 228: 15.1682584249221, 229: 14.5959873005787,
         230: 14.5722779355783, 231: 14.0453069370585, 232: 13.8937061622543, 233: 13.5154027537666,
         234: 13.2531600891849, 235: 13.0054909027696, 236: 12.6446831147078, 237: 12.5148171093078,
         238: 12.063188130299, 239: 12.042655556052, 240: 11.5883078094565, 241: 11.504824430612, 242: 11.1511017866174,
         243: 10.9650922862446, 244: 10.730390761111, 245: 10.4409316500084, 246: 10.3255524063388,
         247: 9.93598787496622, 248: 9.93003221339241, 249: 9.56112091309227, 250: 9.42897347850143,
         251: 9.20039700783966, 252: 8.93796259634457, 253: 8.85328256710522, 254: 8.51926413025667,
         255: 8.45474045082694, 256: 8.1978476086084, 257: 7.97830971561523, 258: 7.88855755455274,
         259: 7.59093645826561, 260: 7.5084019291346, 261: 7.30454407094621, 262: 7.04560910203536,
         263: 7.02895675358957, 264: 6.7637668503289, 265: 6.58508524827696, 266: 6.50858208542044,
         267: 6.26302498297912, 268: 6.12926537677368, 269: 6.02673230860646, 270: 5.79935453208492,
         271: 5.67551833427807, 272: 5.58055531034372, 273: 5.37001098993157, 274: 5.22068394207746,
         275: 5.1674101282601, 276: 4.97245303290997, 277: 4.78485131831808, 278: 4.7589847331981,
         279: 4.60432747919025, 280: 4.43061448000821, 281: 4.28204896201784, 282: 4.26345536002377,
         283: 4.10260285315587, 284: 3.94781902222822, 285: 3.79887490700647, 286: 3.79531775882988,
         287: 3.65555018551434, 288: 3.51763284812767, 289: 3.38491888396434, 290: 3.35631575827001,
         291: 3.25721197910604, 292: 3.13432322620576, 293: 3.03659142956812, 294: 3.01607084505109,
         295: 2.90227991367027, 296: 2.81584948956708, 297: 2.79278210958312, 298: 2.68741546081404,
         299: 2.65523938451712, 300: 2.58602410629894, 301: 2.53186405785293, 302: 2.48845806533149,
         303: 2.43389401598499, 304: 2.3945730157078, 305: 2.35484810110175, 306: 2.30423008024133,
         307: 2.29030759798835, 308: 2.23870782831747, 309: 2.21729562133212, 310: 2.19774474136202,
         311: 2.16649320382364, 312: 2.1437561985855, 313: 2.13364104328665, 314: 2.12914825109195,
         315: 2.12134420283737, 316: 2.1189135610607, 317: 2.12025358916659, 318: 2.12359854608264,
         319: 2.12729706119124, 320: 2.13002308767844, 321: 2.13087189430741, 322: 2.12934793670898,
         323: 2.12528497935857, 324: 2.11874296389018, 325: 2.10991260261216, 326: 2.09904193335945,
         327: 2.08638697432102, 328: 2.07218254319028, 329: 2.05662756564359, 330: 2.05314260209575,
         331: 2.03843485164631, 332: 2.01886281467893, 333: 1.9984248461136, 334: 1.97718776251278,
         335: 1.97568122238929, 336: 1.95323712893129, 337: 1.92860072843894, 338: 1.90340426890818,
         339: 1.90114232129678, 340: 1.87561272153218, 341: 1.84725454349349, 342: 1.82941563895348,
         343: 1.81756271063185, 344: 1.78614952761549, 345: 1.76039507540116, 346: 1.75397738243658,
         347: 1.71974251217124, 348: 1.69397853364227, 349: 1.68475926460872, 350: 1.64809245209816,
         351: 1.63006776861547, 352: 1.61035712752567, 353: 1.57181017837342, 354: 1.56856824186895,
         355: 1.53187458132623, 356: 1.50938898171679, 357: 1.49157103909461, 358: 1.45244244867121,
         359: 1.45104798836669, 360: 1.41029563088115, 361: 1.39764440595198, 362: 1.37009624699134,
         363: 1.34491379488115, 364: 1.33085875116139, 365: 1.29417261497898, 366: 1.29297257670911,
         367: 1.25697500410846, 368: 1.24534580858362, 369: 1.22321452875048, 370: 1.19836114982388,
         371: 1.19189723538816, 372: 1.16355226269127, 373: 1.15314913778086, 374: 1.13825599031275,
         375: 1.11604471477092, 376: 1.1096428936804, 377: 1.09747678812954, 378: 1.08253136160649,
         379: 1.07128971588567, 380: 1.06777806196427, 381: 1.06481695549574, 382: 1.06384668349663,
         383: 1.06777806196427, 384: 1.06972719462398, 385: 1.08642491955387, 386: 1.1096428936804,
         387: 1.1197800735703, 388: 1.15314913778086, 389: 1.19836114982388, 390: 1.24534580858362,
         391: 1.29417261497898, 392: 1.34491379488115, 393: 1.39764440595198, 394: 1.45244244867121,
         395: 1.50938898171679, 396: 1.56856824186895, 397: 1.63006776861547, 398: 1.69397853364227,
         399: 1.69468120120231, 400: 1.76039507540116, 401: 1.82941563895348, 402: 1.90114232129678,
         403: 1.97568122238929, 404: 2.05314260209575, 405: 2.13364104328665, 406: 2.21729562133212,
         407: 2.30423008024133, 408: 2.3945730157078, 409: 2.48845806533149, 410: 2.58602410629894,
         411: 2.68741546081404, 412: 2.79278210958312, 413: 2.79700267389009, 414: 2.90227991367027,
         415: 3.01607084505109, 416: 3.13432322620576, 417: 3.16326930910683, 418: 3.25721197910604,
         419: 3.38491888396434, 420: 3.40636871772578, 421: 3.51763284812767, 422: 3.59143704707615,
         423: 3.65555018551434, 424: 3.74031142922826, 425: 3.79887490700647, 426: 3.86295747771352,
         427: 3.94781902222822, 428: 3.9651475479156, 429: 4.05188099244722, 430: 4.10260285315587,
         431: 4.12526211812152, 432: 4.18932138702242, 433: 4.24410157927993, 434: 4.26345536002377,
         435: 4.29438748786301, 436: 4.34167211953111, 437: 4.38678782938543, 438: 4.43061448000821,
         439: 4.43244482907446, 440: 4.48775027126116, 441: 4.55110125144084, 442: 4.60432747919025,
         443: 4.63164681913314, 444: 4.74717884114848, 445: 4.78485131831808, 446: 4.9356464396023,
         447: 4.97245303290997},
        {2: 14.3148354564015, 3: 14.1363544920168, 4: 14.0576012527695, 5: 14.0573166419503, 6: 14.1201026342765,
         7: 14.2349000673298, 8: 14.3702985599214, 9: 14.3959284436396, 10: 14.6094812296599, 11: 14.7597978520139,
         12: 14.8666611031904, 13: 15.1598543150593, 14: 15.1703873510958, 15: 15.5286204043223, 16: 15.5707540955559,
         17: 15.9406714192196, 18: 15.9927910958504, 19: 16.4104245413974, 20: 16.4262671843564, 21: 16.8714924114699,
         22: 16.9457592714372, 23: 17.3287852313379, 24: 17.5485694829105, 25: 17.7984727296376, 26: 18.2192795455027,
         27: 18.2808908575294, 28: 18.7763846719507, 29: 18.9624314297942, 30: 19.2853085824239, 31: 19.7720469876053,
         32: 19.8080266045525, 33: 20.3449126203895, 34: 20.6440262369104, 35: 20.8963506458615, 36: 21.4627351054426,
         37: 21.5701512599262, 38: 22.0444711142723, 39: 22.5432575652336, 40: 22.6419747679202, 41: 23.2556734400047,
         42: 23.5561704975515, 43: 23.8860060878789, 44: 24.5334235666009, 45: 24.6092258074788, 46: 25.1983889514154,
         47: 25.696719844539, 48: 25.881377868975, 49: 26.5828788375395, 50: 26.8226555183314, 51: 27.3033936163959,
         52: 27.9916511106211, 53: 28.04343756475, 54: 28.8035400103439, 55: 29.1997622355464, 56: 29.5842446280669,
         57: 30.3861098288264, 58: 30.4611052894268, 59: 31.2097091589602, 60: 31.7705063584478, 61: 32.0556317104743,
         62: 32.9244825424001, 63: 33.1399039125126, 64: 33.8168831135716, 65: 34.5715070763614, 66: 34.7334717271337,
         67: 35.6749039870984, 68: 36.0672697059874, 69: 36.6418532672754, 70: 37.6350111929129, 71: 37.6404852962827,
         72: 38.6550881353933, 73: 39.2803115172554, 74: 39.7028137203371, 75: 40.7789373494788, 76: 41.0061191891363,
         77: 41.8842287366882, 78: 42.8152088369864, 79: 43.0194784585194, 80: 44.1854985196834, 81: 44.7103887546963,
         82: 45.3831229338464, 83: 46.6132083201711, 84: 46.7056078861277, 85: 47.8766345160265, 86: 48.7924333570485,
         87: 49.1743052063054, 88: 50.507148569798, 89: 50.9868595816596, 90: 51.8761179430868, 91: 53.2821925024349,
         92: 53.2983501570834, 93: 54.7263779641565, 94: 55.7192114149703, 95: 56.2097073039712, 96: 57.7332414958554,
         97: 58.2726305306391, 98: 59.2980702709207, 99: 60.9053128968599, 100: 60.9668919124385, 101: 62.5561189785208,
         102: 63.8025146600295, 103: 64.2516692801789, 104: 65.9931765700963, 105: 66.8001816926791,
         106: 67.7818864879738, 107: 69.6190784359125, 108: 69.9717146871008, 109: 71.5060664935268,
         110: 73.3279293881948, 111: 73.4442003578592, 112: 75.4348663087722, 113: 76.8843060599498,
         114: 77.4794882005057, 115: 79.5795284801111, 116: 80.6587875612592, 117: 81.7364892334882,
         118: 83.9519132597756, 119: 84.6678743329721, 120: 86.2273851748613, 121: 88.5645325448031,
         122: 88.9313154793443, 123: 90.9650270499707, 124: 93.4305856807397, 125: 93.4739193138633,
         126: 95.9629719655964, 127: 98.3356628703795, 128: 98.5639972325273, 129: 101.2355219046, 130: 103.55653489966,
         131: 103.979456830659, 132: 106.797764652089, 133: 109.196268181886, 134: 109.692461206625,
         135: 112.66561697021, 136: 115.342683671587, 137: 115.719358537936, 138: 118.855870145122,
         139: 122.077395229624, 140: 122.128504561835, 141: 125.386238036485, 142: 128.784765266084,
         143: 129.811579427479, 144: 132.275407766953, 145: 135.860662274481, 146: 138.712955881728,
         147: 139.54309319674, 148: 143.325334448715, 149: 147.210091336258, 150: 149.628431940928,
         151: 151.200142491093, 152: 155.298341858281, 153: 159.507620737542, 154: 163.830989879914,
         155: 164.397351918478, 156: 168.271541641241, 157: 172.832452194024, 158: 177.516983799229,
         159: 182.328487139671, 160: 187.270403716635, 161: 192.34626831147, 162: 194.229528074908,
         163: 197.55971151389, 164: 202.914462318809, 165: 208.414350793565, 166: 214.063310817431,
         167: 219.865382895385, 168: 225.824717048139, 169: 229.027947931403, 170: 231.945575780508,
         171: 238.232337130232, 172: 244.689497799431, 173: 251.321676370945, 174: 258.133616611839,
         175: 265.130190866463, 176: 267.572201491137, 177: 272.316403541463, 178: 279.697394685266,
         179: 287.278443664574, 180: 287.653157910798, 181: 295.064972940512, 182: 301.474287540237,
         183: 303.062551947129, 184: 311.276901075016, 185: 311.726767301611, 186: 319.486608671169,
         187: 319.713895762908, 188: 325.384796229925, 189: 328.379570700178, 190: 329.847804695068,
         191: 333.109262905028, 192: 335.36376483364, 193: 336.748204156848, 194: 337.280124143243,
         195: 337.37750366744, 196: 337.340370122858, 197: 337.280124143243, 198: 336.712955068772,
         199: 335.556953664776, 200: 333.916847289379, 201: 331.826410712167, 202: 329.308582745559,
         203: 328.379570700178, 204: 326.458502024632, 205: 323.275939149856, 206: 319.727236318699,
         207: 319.713895762908, 208: 315.989522973104, 209: 311.917200811669, 210: 311.276901075016,
         211: 307.679821508572, 212: 303.152980996755, 213: 303.062551947129, 214: 298.531580387598,
         215: 295.064972940512, 216: 293.67572723094, 217: 288.697252977278, 218: 287.278443664574,
         219: 283.611954347579, 220: 279.697394685266, 221: 278.382735917523, 222: 273.084067112606,
         223: 272.316403541463, 224: 267.764427408077, 225: 265.130190866463, 226: 262.381592393031,
         227: 258.133616611839, 228: 256.965600413574, 229: 251.558702616817, 230: 251.321676370945,
         231: 246.23987459069, 232: 244.689497799431, 233: 240.963088675989, 234: 238.232337130232,
         235: 235.752935755468, 236: 231.945575780508, 237: 230.631036344469, 238: 225.824717048139,
         239: 225.615628325951, 240: 220.791217991178, 241: 219.865382895385, 242: 216.119674300392,
         243: 214.063310817431, 244: 211.591909943206, 245: 208.414350793565, 246: 207.21076867865,
         247: 202.980855083411, 248: 202.914462318809, 249: 199.010877686368, 250: 197.55971151389,
         251: 195.180878543758, 252: 192.34626831147, 253: 191.48042226072, 254: 187.965108022189,
         255: 187.270403716635, 256: 184.64957070715, 257: 182.328487139671, 258: 181.42920410546,
         259: 178.378240377475, 260: 177.516983799229, 261: 175.495467036106, 262: 172.832452194024,
         263: 172.669460734201, 264: 170.076180326513, 265: 168.271541641241, 266: 167.532841196104,
         267: 165.149661609424, 268: 163.830989879914, 269: 162.859180246012, 270: 160.693922469727,
         271: 159.507620737542, 272: 158.627170224138, 273: 156.686157126048, 274: 155.298341858281,
         275: 154.815394683351, 276: 153.100729753032, 277: 151.4193101191, 278: 151.200142491093,
         279: 149.905378396784, 280: 148.449698806737, 281: 147.210091336258, 282: 147.055152187333,
         283: 145.791804105383, 284: 144.559074971434, 285: 143.353191281504, 286: 143.325334448715,
         287: 142.209698450557, 288: 141.040153872989, 289: 139.822644005111, 290: 139.54309319674,
         291: 138.539717416254, 292: 137.134893639837, 293: 135.860662274481, 294: 135.579853068878,
         295: 133.817736092913, 296: 132.275407766953, 297: 131.837881890788, 298: 129.568397255127,
         299: 128.784765266084, 300: 126.972844475245, 301: 125.386238036485, 302: 124.000783373479,
         303: 122.077395229624, 304: 120.544317116516, 305: 118.855870145122, 306: 116.435737869139,
         307: 115.719358537936, 308: 112.66561697021, 309: 111.151530172012, 310: 109.692461206625,
         311: 106.797764652089, 312: 103.979456830659, 313: 102.094007506998, 314: 101.2355219046,
         315: 98.5639972325273, 316: 95.9629719655964, 317: 93.4305856807397, 318: 90.9650270499707,
         319: 88.5645325448031, 320: 86.2273851748613, 321: 83.9519132597756, 322: 81.7364892334882,
         323: 79.5795284801111, 324: 77.4794882005057, 325: 75.4348663087722, 326: 73.4442003578592,
         327: 71.5060664935268, 328: 69.6190784359125, 329: 67.7818864879738, 330: 67.4282330867875,
         331: 65.9931765700963, 332: 64.2516692801789, 333: 62.5561189785208, 334: 60.9053128968599,
         335: 60.8000307970896, 336: 59.2980702709207, 337: 57.7332414958554, 338: 56.2097073039712,
         339: 56.0838763873419, 340: 54.7263779641565, 341: 53.2821925024349, 342: 52.4219865728153,
         343: 51.8761179430868, 344: 50.507148569798, 345: 49.4306913602679, 346: 49.1743052063054,
         347: 47.8766345160265, 348: 46.9357766987701, 349: 46.6132083201711, 350: 45.3831229338464,
         351: 44.7994367720999, 352: 44.1854985196834, 353: 43.0194784585194, 354: 42.9244288030061,
         355: 41.8842287366882, 356: 41.2599184029772, 357: 40.7789373494788, 358: 39.7390829716876,
         359: 39.7028137203371, 360: 38.6550881353933, 361: 38.3311560035606, 362: 37.6350111929129,
         363: 36.996457559246, 364: 36.6418532672754, 365: 35.7056302289254, 366: 35.6749039870984,
         367: 34.7334717271337, 368: 34.4201125240914, 369: 33.8168831135716, 370: 33.1114591535483,
         371: 32.9244825424001, 372: 32.0556317104743, 373: 31.7128534061872, 374: 31.2097091589602,
         375: 30.3861098288264, 376: 30.1149967338088, 377: 29.5842446280669, 378: 28.8035400103439,
         379: 28.04343756475, 380: 27.6479574883558, 381: 27.3033936163959, 382: 26.5828788375395,
         383: 26.0824160749505, 384: 25.881377868975, 385: 25.1983889514154, 386: 24.6927763329344,
         387: 24.5334235666009, 388: 24.1847941424571, 389: 23.8860060878789, 390: 23.7322442091208,
         391: 23.6464561044356, 392: 23.6108550138513, 393: 23.612146691934, 394: 23.6402098846786,
         395: 23.6871932551771, 396: 23.7468868888884, 397: 23.8142779394974, 398: 23.8852314855781,
         399: 23.8860060878789, 400: 23.960179840932, 401: 24.0308795850435, 402: 24.0946562760842,
         403: 24.149188830144, 404: 24.1923608774864, 405: 24.2221822331668, 406: 24.2367247295265,
         407: 24.2340692177526, 408: 24.2122623626282, 409: 24.1692833580361, 410: 24.1030220049169,
         411: 24.0112707938882, 412: 23.8917347520146, 413: 23.8860060878789, 414: 23.7371351391167,
         415: 23.5468479842151, 416: 23.3182126507659, 417: 23.2556734400047, 418: 23.0364038320562,
         419: 22.7026530852223, 420: 22.6419747679202, 421: 22.2933714087399, 422: 22.0444711142723,
         423: 21.8008934914022, 424: 21.4627351054426, 425: 21.1956026601895, 426: 20.8963506458615,
         427: 20.4382245727669, 428: 20.3449126203895, 429: 19.8080266045525, 430: 19.4425130705122,
         431: 19.2853085824239, 432: 18.7763846719507, 433: 18.2808908575294, 434: 18.085174462555,
         435: 17.7984727296376, 436: 17.3287852313379, 437: 16.8714924114699, 438: 16.4417300603878,
         439: 16.4262671843564, 440: 15.9927910958504, 441: 15.5707540955559, 442: 15.2779831648731,
         443: 15.1598543150593, 444: 14.7597978520139, 445: 14.6562465529643, 446: 14.3702985599214,
         447: 14.3148354564015}
    ],
    'Chalk': [
        {2: 0.557766366227906, 3: 0.573972190391989, 4: 0.590648872522309, 5: 0.60781009333156, 6: 0.62546993102364,
         7: 0.643642872842704, 8: 0.662343826957769, 9: 0.678412707579542, 10: 0.681588134692627, 11: 0.701391583111101,
         12: 0.721770417967956, 13: 0.742741357036101, 14: 0.743866757267231, 15: 0.764321603821008,
         16: 0.786528861673613, 17: 0.794763814786589, 18: 0.809381348313245, 19: 0.832897810772535,
         20: 0.840363599770431, 21: 0.857097540776539, 22: 0.882000390568699, 23: 0.883112572464717,
         24: 0.907626789196631, 25: 0.92392499367233, 26: 0.933997759271083, 27: 0.961134934211836,
         28: 0.963893618888141, 29: 0.989060575994672, 30: 1.0031806600377, 31: 1.01779759341398, 32: 1.04222494760224,
         33: 1.04736956087599, 34: 1.07780073773801, 35: 1.08119654716514, 36: 1.10911608820962, 37: 1.12027504315172,
         38: 1.14134130183201, 39: 1.15954533157832, 40: 1.17450281455245, 41: 1.19909201923964, 42: 1.20862783041093,
         43: 1.23898637830342, 44: 1.24374434385709, 45: 1.27928650055285, 46: 1.27988116271538, 47: 1.31706793181757,
         48: 1.32015335313671, 49: 1.35533515732193, 50: 1.36151212088754, 51: 1.39471423173887, 52: 1.40334955849047,
         53: 1.43523745968387, 54: 1.44565904738269, 55: 1.47693808437847, 56: 1.4884175487619, 57: 1.51985031492142,
         58: 1.53158455538981, 59: 1.56400935435206, 60: 1.57510117610308, 61: 1.60945142852915, 62: 1.61888948584115,
         63: 1.65621381584871, 64: 1.66285228011782, 65: 1.70433487782541, 66: 1.7068733637218, 67: 1.75092966106795,
         68: 1.75385409056235, 69: 1.7948904676319, 70: 1.80481207713535, 71: 1.83848271418953, 72: 1.85725064091802,
         73: 1.88151740752482, 74: 1.91121279987518, 75: 1.92379609015125, 76: 1.9651518324481, 77: 1.96674282185264,
         78: 2.00563496698453, 79: 2.0238862608923, 80: 2.04471456920078, 81: 2.08219488493346, 82: 2.08268999460242,
         83: 2.11815115727198, 84: 2.14320226261363, 85: 2.1520713450679, 86: 2.18397346005315, 87: 2.20547270615233,
         88: 2.21358962535078, 89: 2.24093158636666, 90: 2.26585335698938, 91: 2.26955240876384, 92: 2.28851497622859,
         93: 2.30900122177911, 94: 2.32752203823307, 95: 2.33549393821879, 96: 2.34446824385515, 97: 2.36025373417588,
         98: 2.37525160717422, 99: 2.38989503431503, 100: 2.40335138963706, 101: 2.4046043744893, 102: 2.41978132374074,
         103: 2.43566994269566, 104: 2.45255515748032, 105: 2.47068786505591, 106: 2.47318042986472,
         107: 2.49020309226026, 108: 2.51145520762766, 109: 2.53470402423274, 110: 2.5450383431403,
         111: 2.56012181608625, 112: 2.58821851164601, 113: 2.61898407808792, 114: 2.65320763698134,
         115: 2.69038069177009, 116: 2.69507829607575, 117: 2.73145986159513, 118: 2.77338342097959,
         119: 2.7752070190204, 120: 2.82334276870298, 121: 2.85396369039228, 122: 2.8738807543993,
         123: 2.92745981101238, 124: 2.93688520832095, 125: 2.98447312784881, 126: 3.02221599941547,
         127: 3.04321701500032, 128: 3.10417897632024, 129: 3.11002606477247, 130: 3.16841762823169,
         131: 3.20038743936067, 132: 3.23378735343355, 133: 3.2933742511148, 134: 3.300194342703, 135: 3.36958830389215,
         136: 3.38906278174642, 137: 3.44030268767374, 138: 3.4875315293216, 139: 3.51154820521899,
         140: 3.58381312102165, 141: 3.5888612726568, 142: 3.65885663115701, 143: 3.69313513758576,
         144: 3.73392915632585, 145: 3.80043866515173, 146: 3.80890922031528, 147: 3.8862958307022,
         148: 3.91085988178111, 149: 3.96395053042374, 150: 4.02448937149584, 151: 4.04077812676729,
         152: 4.11893746687117, 153: 4.14142035022401, 154: 4.19720309950069, 155: 4.26174874226954,
         156: 4.27352191299816, 157: 4.35102066417636, 158: 4.38557325900367, 159: 4.42658728159492,
         160: 4.4998473494421, 161: 4.51299547984278, 162: 4.57275269724828, 163: 4.6405149656784,
         164: 4.64411993557906, 165: 4.70802047135483, 166: 4.76870453789519, 167: 4.77905419413232,
         168: 4.82697792191713, 169: 4.878547794276, 170: 4.91790894879332, 171: 4.92232484337626,
         172: 4.96220028873973, 173: 4.99332016307401, 174: 5.01576788134325, 175: 5.02983526142233,
         176: 5.03584452256202, 177: 5.03395376194142, 178: 5.02395975678743, 179: 5.00508908093896,
         180: 4.97574294194631, 181: 4.93312920217845, 182: 4.91790894879332, 183: 4.87366119882552,
         184: 4.78568707317673, 185: 4.77905419413232, 186: 4.64411993557906, 187: 4.63437677621512,
         188: 4.51299547984278, 189: 4.38557325900367, 190: 4.26174874226954, 191: 4.14142035022401,
         192: 4.02448937149584, 193: 3.91085988178111, 194: 3.89043071379395, 195: 3.80043866515173,
         196: 3.69313513758576, 197: 3.62341258154709, 198: 3.5888612726568, 199: 3.4875315293216,
         200: 3.42229969386106, 201: 3.38906278174642, 202: 3.2933742511148, 203: 3.25338143902869,
         204: 3.20038743936067, 205: 3.11002606477247, 206: 3.10424560351895, 207: 3.02221599941547,
         208: 2.97116257271091, 209: 2.93688520832095, 210: 2.85396369039228, 211: 2.84860628312151,
         212: 2.77338342097959, 213: 2.73591939482966, 214: 2.69507829607575, 215: 2.63072452530262,
         216: 2.61898407808792, 217: 2.5450383431403, 218: 2.53218189155805, 219: 2.47318042986472,
         220: 2.43943461717481, 221: 2.40335138963706, 222: 2.35186427241919, 223: 2.33549393821879,
         224: 2.26955240876384, 225: 2.26894240433372, 226: 2.20547270615233, 227: 2.18971234379017,
         228: 2.14320226261363, 229: 2.11428658458463, 230: 2.08268999460242, 231: 2.04232690940775,
         232: 2.0238862608923, 233: 1.97353173883469, 234: 1.96674282185264, 235: 1.91121279987518,
         236: 1.90739498356119, 237: 1.85725064091802, 238: 1.84351184906883, 239: 1.80481207713535,
         240: 1.78210676094937, 241: 1.75385409056235, 242: 1.72299403361761, 243: 1.70433487782541,
         244: 1.66601064086694, 245: 1.65621381584871, 246: 1.61101527231998, 247: 1.60945142852915,
         248: 1.56400935435206, 249: 1.55741278046004, 250: 1.51985031492142, 251: 1.5055291085349,
         252: 1.47693808437847, 253: 1.45541794049004, 254: 1.43523745968387, 255: 1.40702881967289,
         256: 1.39471423173887, 257: 1.36032987638653, 258: 1.35533515732193, 259: 1.31706793181757,
         260: 1.31520746102741, 261: 1.27988116271538, 262: 1.27156288692894, 263: 1.24374434385709,
         264: 1.22970506484133, 265: 1.20862783041093, 266: 1.18963383951529, 267: 1.17450281455245,
         268: 1.15134380571654, 269: 1.14134130183201, 270: 1.11482038246838, 271: 1.10911608820962,
         272: 1.08003698864091, 273: 1.07780073773801, 274: 1.04736956087599, 275: 1.04694792575846,
         276: 1.01779759341398, 277: 1.0154920772351, 278: 0.989060575994672, 279: 0.985630423389403,
         280: 0.961134934211836, 281: 0.957279472108171, 282: 0.933997759271083, 283: 0.930352628568482,
         284: 0.907626789196631, 285: 0.904762881691423, 286: 0.882000390568699, 287: 0.880425171534461,
         288: 0.857256499059094, 289: 0.857097540776539, 290: 0.835154430500349, 291: 0.832897810772535,
         292: 0.814057918179213, 293: 0.809381348313245, 294: 0.793898109721428, 295: 0.786528861673613,
         296: 0.774613487776893, 297: 0.764321603821009, 298: 0.756150020083419, 299: 0.742741357036101,
         300: 0.738461009129646, 301: 0.721770417967956, 302: 0.721506736984217, 303: 0.705130138074714,
         304: 0.701391583111101, 305: 0.689372997346783, 306: 0.681588134692627, 307: 0.674217157287707,
         308: 0.662343826957769, 309: 0.659642792030726, 310: 0.645553832334775, 311: 0.643642872842704,
         312: 0.63187079271498, 313: 0.62546993102364, 314: 0.618679283922582, 315: 0.60781009333156,
         316: 0.605973805461115, 317: 0.593596826564904, 318: 0.590648872522309, 319: 0.581564243105475,
         320: 0.573972190391989, 321: 0.569958301343183, 322: 0.558728168518062, 323: 0.557766366227906,
         324: 0.547685253592942, 325: 0.542018105585599, 326: 0.537024688272131, 327: 0.526750795688131,
         328: 0.526714489382746, 329: 0.516568365584517, 330: 0.511842963300999, 331: 0.506734001508984,
         332: 0.497391327487051, 333: 0.49725565117534, 334: 0.487840318227508, 335: 0.483347726544486,
         336: 0.478736967620062, 337: 0.469946255987676, 338: 0.469700639808211, 339: 0.46120024820419,
         340: 0.456438871893478, 341: 0.452748701324357, 342: 0.444538727089369, 343: 0.443551543511755,
         344: 0.436400352068736, 345: 0.431028082545902, 346: 0.428532326831863, 347: 0.420825423532207,
         348: 0.418858215377337, 349: 0.413234712977635, 350: 0.407031958458076, 351: 0.405890511135157,
         352: 0.398629552247594, 353: 0.39553961012073, 354: 0.39153517671904, 355: 0.384651508389709,
         356: 0.384371742619747, 357: 0.377812643533702, 358: 0.373519194397361, 359: 0.371173097550431,
         360: 0.364673409998825, 361: 0.362973062567908, 362: 0.358279667393135, 363: 0.35272469561435,
         364: 0.35206611110918, 365: 0.345952947968337, 366: 0.342765686291003, 367: 0.339989439848568,
         368: 0.334179230497671, 369: 0.333087864726652, 370: 0.328498806669792, 371: 0.323683291722403,
         372: 0.322971640685018, 373: 0.317615126608608, 374: 0.314544252238761, 375: 0.312410776941405,
         376: 0.307397436826355, 377: 0.305663249066599, 378: 0.30258577645658, 379: 0.297966389211718,
         380: 0.297032996676822, 381: 0.293647756076103, 382: 0.289550645948839, 383: 0.288646415243691,
         384: 0.285876192347875, 385: 0.282585173675145, 386: 0.280496624836881, 387: 0.279797188743655,
         388: 0.277941443194935, 389: 0.277284480003538, 390: 0.279017875714465, 391: 0.280496624836881,
         392: 0.288646415243691, 393: 0.296830309092443, 394: 0.297032996676822, 395: 0.297305287792396,
         396: 0.305663249066599, 397: 0.314544252238761, 398: 0.323683291722403, 399: 0.333087864726652,
         400: 0.342765686291003, 401: 0.347166960485682, 402: 0.35272469561435, 403: 0.362973062567908,
         404: 0.373519194397361, 405: 0.384371742619747, 406: 0.392735425541454, 407: 0.39553961012073,
         408: 0.407031958458076, 409: 0.418858215377337, 410: 0.431028082545902, 411: 0.443551543511755,
         412: 0.456438871893478, 413: 0.457410784947705, 414: 0.469700639808211, 415: 0.483347726544486,
         416: 0.487815412368947, 417: 0.497391327487051, 418: 0.511765607920245, 419: 0.511842963300999,
         420: 0.526714489382746, 421: 0.542018105585599, 422: 0.545294066710861, 423: 0.557766366227906},
        {2: 2.87411936740612, 3: 2.85844726390802, 4: 2.85046949763523, 5: 2.84914009656409, 6: 2.85360423714201,
         7: 2.86322190417374, 8: 2.87754216738413, 9: 2.89324973673344, 10: 2.89635439304031, 11: 2.91989108133194,
         12: 2.9474606839913, 13: 2.97897571551261, 14: 2.98085886381913, 15: 3.01518645413057, 16: 3.05518540178484,
         17: 3.07112084145251, 18: 3.09957685265034, 19: 3.14793969442632, 20: 3.16411599934652, 21: 3.20070689945743,
         22: 3.25729962174237, 23: 3.25992709964012, 24: 3.31856664943715, 25: 3.35863941055349, 26: 3.38379739292289,
         27: 3.45315635246759, 28: 3.46034078227344, 29: 3.52714654885836, 30: 3.56512172513676, 31: 3.60531979092174,
         32: 3.67307549018094, 33: 3.68771417564562, 34: 3.77461087902127, 35: 3.78429815213404, 36: 3.86626688391552,
         37: 3.89888869491752, 38: 3.96246664431934, 39: 4.01694909973816, 40: 4.06330786143627, 41: 4.13858443584746,
         42: 4.16890963976742, 43: 4.2639029540492, 44: 4.27941637278111, 45: 4.39301618303858, 46: 4.39500281943986,
         47: 4.51623635385809, 48: 4.52603902865849, 49: 4.64311531528703, 50: 4.66308987616127, 51: 4.77586879992385,
         52: 4.80429069556715, 53: 4.91484799758957, 54: 4.94976715021283, 55: 5.06047639909924, 56: 5.0996487085871,
         57: 5.21326450565422, 58: 5.25406875955284, 59: 5.37382718720065, 60: 5.41316473105798, 61: 5.54290397947951,
         62: 5.57707821244119, 63: 5.72138258631011, 64: 5.74595508044091, 65: 5.91032580013438, 66: 5.91994562902016,
         67: 6.09920470312233, 68: 6.11205525635914, 69: 6.28389183647735, 70: 6.32885197661925, 71: 6.47417139358058,
         72: 6.56203717710106, 73: 6.67021271597092, 74: 6.81412460399394, 75: 6.87219027293835, 76: 7.0802838167949,
         77: 7.08913357972395, 78: 7.29467854284736, 79: 7.40062005886478, 80: 7.51556525421404, 81: 7.74314053163223,
         82: 7.74653649854685, 83: 7.97760690840758, 84: 8.15831072271297, 85: 8.21917305066097, 86: 8.46805394303344,
         87: 8.65666035559418, 88: 8.72447108001425, 89: 8.98865266306257, 90: 9.26083380369803, 91: 9.30838562325928,
         92: 9.54125673274101, 93: 9.83017101588881, 94: 10.1278337758196, 95: 10.275133766585, 96: 10.4345099210217,
         97: 10.7504723815523, 98: 11.0760023519343, 99: 11.4113895414092, 100: 11.7283324364005, 101: 11.7569324317669,
         102: 12.1129385429834, 103: 12.4797247069014, 104: 12.8576173491991, 105: 13.2469527798961,
         106: 13.2994097947794, 107: 13.6480774926568, 108: 14.0613484731562, 109: 14.4871335167839,
         110: 14.6680104068297, 111: 14.9258115559677, 112: 15.377772997409, 113: 15.84342006953, 114: 16.3231671804416,
         115: 16.8174412867504, 116: 16.8765805861205, 117: 17.3266822735345, 118: 17.8297331842462,
         119: 17.8513433458239, 120: 18.3918914319356, 121: 18.7309097780231, 122: 18.9488075990225,
         123: 19.5225874812041, 124: 19.621441930977, 125: 20.1137417206626, 126: 20.5066827547869,
         127: 20.7227964220946, 128: 21.350293620924, 129: 21.4100380281863, 130: 21.9967917656932,
         131: 22.3251896802076, 132: 22.662866215061, 133: 23.2795982126277, 134: 23.3491097498493,
         135: 24.0561331005959, 136: 24.260147208607, 137: 24.7845654910815, 138: 25.285978252342, 139: 25.535055198314,
         140: 26.3082701294713, 141: 26.3635066625717, 142: 27.1048984163124, 143: 27.4863551375034,
         144: 27.9256490275888, 145: 28.6784945543385, 146: 28.7712523999996, 147: 29.642461088252,
         148: 29.9347645749427, 149: 30.5400504348063, 150: 31.2753095619752, 151: 31.4648192599016,
         152: 32.4175905724746, 153: 32.7102989040455, 154: 33.3992123026065, 155: 34.2613711508485,
         156: 34.4105580561481, 157: 35.4525278921963, 158: 35.9600668232715, 159: 36.5260491241115,
         160: 37.6320771447915, 161: 37.8500133425002, 162: 38.7715962769349, 163: 39.9456206490501,
         164: 40.0153934253321, 165: 41.1551950979915, 166: 42.4013960988242, 167: 42.6469914918577,
         168: 43.6853327228457, 169: 45.0081476246168, 170: 46.2454182052432, 171: 46.371018058881,
         172: 47.7751569282756, 173: 49.2218138627695, 174: 50.7122763317854, 175: 52.2478707899991,
         176: 53.8299638578327, 177: 55.4599635376956, 178: 57.1393204670519, 179: 58.869529209433,
         180: 60.6521295845416, 181: 62.4887080386328, 182: 62.9879815821706, 183: 64.3808990563906,
         184: 66.3303866155566, 185: 66.444448618626, 186: 68.2508634017136, 187: 68.3389056856062,
         188: 69.2013655865656, 189: 69.6349934169257, 190: 69.6974509561751, 191: 69.4867637581384,
         192: 69.0678293893981, 193: 68.4804198737085, 194: 68.3389056856062, 195: 67.7704004016716,
         196: 66.9546748126425, 197: 66.3303866155566, 198: 66.0470350649361, 199: 65.0836966660266,
         200: 64.3808990563906, 201: 64.0514152532243, 202: 62.9852136922356, 203: 62.4887080386328,
         204: 61.8804747248579, 205: 60.7324755813421, 206: 60.6521295845416, 207: 59.5929924121391,
         208: 58.869529209433, 209: 58.4170446091804, 210: 57.2222795001076, 211: 57.1393204670519,
         212: 56.0490556564995, 213: 55.4599635376956, 214: 54.8571360711496, 215: 53.8299638578327,
         216: 53.6535415793629, 217: 52.4673780232114, 218: 52.2478707899991, 219: 51.2951489591587,
         220: 50.7122763317854, 221: 50.1211183501255, 222: 49.2218138627695, 223: 48.9498036032451,
         224: 47.7863529239145, 225: 47.7751569282756, 226: 46.662562398503, 227: 46.371018058881,
         228: 45.5469951937166, 229: 45.0081476246168, 230: 44.4426586309054, 231: 43.6853327228457,
         232: 43.3521353500774, 233: 42.4013960988242, 234: 42.2776315251995, 235: 41.2293149611603,
         236: 41.1551950979915, 237: 40.2131438149727, 238: 39.9456206490501, 239: 39.2148052527821,
         240: 38.7715962769349, 241: 38.2356531363473, 242: 37.6320771447915, 243: 37.27675113838,
         244: 36.5260491241115, 245: 36.3388852630036, 246: 35.4525278921963, 247: 35.4225724096466,
         248: 34.5414436875579, 249: 34.4105580561481, 250: 33.6834907810617, 251: 33.3992123026065,
         252: 32.8451041398558, 253: 32.4175905724746, 254: 32.0259421688742, 255: 31.4648192599016,
         256: 31.2254202505616, 257: 30.5400504348063, 258: 30.4427358246479, 259: 29.6803465876643,
         260: 29.642461088252, 261: 28.9417767841461, 262: 28.7712523999996, 263: 28.2158427479517,
         264: 27.9256490275888, 265: 27.5014226609116, 266: 27.1048984163124, 267: 26.7973923153287,
         268: 26.3082701294713, 269: 26.1026721115639, 270: 25.535055198314, 271: 25.4162688437821,
         272: 24.7845654910815, 273: 24.7373098056506, 274: 24.0658503531437, 275: 24.0561331005959,
         276: 23.4032975451121, 277: 23.3491097498493, 278: 22.7451519963962, 279: 22.662866215061,
         280: 22.0912469841905, 281: 21.9967917656932, 282: 21.4415305429349, 283: 21.350293620924,
         284: 20.7960464791552, 285: 20.7227964220946, 286: 20.1549120700199, 287: 20.1137417206626,
         288: 19.5225874812041, 289: 19.5186456078531, 290: 18.9488075990225, 291: 18.8915735000545,
         292: 18.3918914319356, 293: 18.270587900883, 294: 17.8513433458239, 295: 17.6558973286087,
         296: 17.3266822735345, 297: 17.0476797223271, 298: 16.8174412867504, 299: 16.4460663496397,
         300: 16.3231671804416, 301: 15.8511294364975, 302: 15.84342006953, 303: 15.377772997409, 304: 15.2731904585705,
         305: 14.9258115559677, 306: 14.7037313849678, 307: 14.4871335167839, 308: 14.1419719970221,
         309: 14.0613484731562, 310: 13.6480774926568, 311: 13.5932853655494, 312: 13.2469527798961,
         313: 13.0602083108264, 314: 12.8576173491991, 315: 12.5352275936968, 316: 12.4797247069014,
         317: 12.1129385429834, 318: 12.026895628856, 319: 11.7569324317669, 320: 11.5320225082467,
         321: 11.4113895414092, 322: 11.0760023519343, 323: 11.0479946992446, 324: 10.7504723815523,
         325: 10.5832781515324, 326: 10.4345099210217, 327: 10.1278337758196, 328: 10.1267816434472,
         329: 9.83017101588881, 330: 9.69172206063136, 331: 9.54125673274101, 332: 9.2648545622734,
         333: 9.26083380369803, 334: 8.98865266306257, 335: 8.85832189680433, 336: 8.72447108001425,
         337: 8.46805394303344, 338: 8.46106236112419, 339: 8.21917305066097, 340: 8.08286862547899,
         341: 7.97760690840758, 342: 7.74314053163223, 343: 7.71542636761869, 344: 7.51556525421404,
         345: 7.364386015089, 346: 7.29467854284736, 347: 7.0802838167949, 348: 7.02602161251542, 349: 6.87219027293835,
         350: 6.7013138746784, 351: 6.67021271597092, 352: 6.47417139358058, 353: 6.39074790071552,
         354: 6.28389183647735, 355: 6.09920470312233, 356: 6.09178341910788, 357: 5.91994562902016,
         358: 5.80685505122123, 359: 5.74595508044091, 360: 5.57707821244119, 361: 5.53299503093098,
         362: 5.41316473105798, 363: 5.27067628980748, 364: 5.25406875955284, 365: 5.0996487085871,
         366: 5.01888203718147, 367: 4.94976715021283, 368: 4.80429069556715, 369: 4.77675186243576,
         370: 4.66308987616127, 371: 4.5433852576712, 372: 4.52603902865849, 373: 4.39301618303858,
         374: 4.31619080108083, 375: 4.2639029540492, 376: 4.13858443584746, 377: 4.09413319434803,
         378: 4.01694909973816, 379: 3.89888869491752, 380: 3.87366614735785, 381: 3.78429815213404,
         382: 3.67307549018094, 383: 3.64599888652993, 384: 3.56512172513676, 385: 3.46034078227344,
         386: 3.38362344789885, 387: 3.35863941055349, 388: 3.25992709964012, 389: 3.16411599934652,
         390: 3.07112084145251, 391: 3.04728918407376, 392: 2.99209837380295, 393: 2.98085886381913,
         394: 2.98068510612145, 395: 2.98085886381913, 396: 2.98622659899859, 397: 2.99991047934445,
         398: 3.01796054127489, 399: 3.03857585356309, 400: 3.0607749533867, 401: 3.07112084145251,
         402: 3.08423083406737, 403: 3.10756554596412, 404: 3.12987009134023, 405: 3.15057567484597,
         406: 3.16411599934652, 407: 3.1686835768977, 408: 3.18254128003656, 409: 3.19108990830601,
         410: 3.19260890495562, 411: 3.18503370161347, 412: 3.16626505548067, 413: 3.16411599934652,
         414: 3.13314872836334, 415: 3.08783865340408, 416: 3.07112084145251, 417: 3.0343315229598,
         418: 2.98085886381913, 419: 2.98058642370647, 420: 2.93495015866349, 421: 2.8989145717055,
         422: 2.89324973673344, 423: 2.87411936740612}
    ]
}

# Dictionary to hold the MR cluster points
_rock_deere_miller_points = {
    'Diabase': [
        {2: 271.821582581245, 3: 282.635038475416, 4: 296.643037864525, 5: 308.443927167721, 6: 324.742962668905,
         7: 337.135223841864, 8: 362.789918668744, 9: 377.222226608094, 10: 391.006496432445, 11: 400.266470341287,
         12: 399.642372885415, 13: 397.775913026143, 14: 390.396837173591, 15: 379.584093038784, 16: 356.615899541294,
         17: 346.198142551782, 18: 327.797656097657, 19: 312.318481533429, 20: 300.369353982884, 21: 290.232875180484,
         22: 282.635038475416, 23: 272.246069997119, 24: 265.533119896834, 25: 253.389270659971, 26: 245.603510631852,
         27: 240.671517874311, 28: 235.103697081784, 29: 229.664685168063, 30: 226.815515614605, 31: 225.756213388222,
         32: 227.524477050192, 33: 231.825025145358, 34: 243.314771173075, 35: 253.389270659971, 36: 263.058659627285},
        {2: 67.4504720331896, 3: 70.039469540634, 4: 73.2764607253508, 5: 76.3214384102432, 6: 80.3343009511996,
         7: 83.9295854189984, 8: 90.0881866085383, 9: 94.1183087490418, 10: 97.7344218790017, 11: 102.280729300323,
         12: 105.288654271196, 13: 108.388925898903, 14: 110.077719225425, 15: 111.294667999883, 16: 112.226767689556,
         17: 111.073313762881, 18: 109.294729504779, 19: 106.883123742006, 20: 103.878077857477, 21: 100.338334730343,
         22: 97.354770356567, 23: 93.8974279085959, 24: 91.8008648136066, 25: 87.0776757327645, 26: 83.5960619071789,
         27: 81.600613404238, 28: 78.3309631617244, 29: 75.0777772258669, 30: 72.5012238954097, 31: 70.2205989817274,
         32: 68.1057075844856, 33: 66.6531355769078, 34: 65.5082460514199, 35: 65.6776572715807, 36: 66.1517327507762}],
    'Granite': [
        {2: 147.866048175126, 3: 158.604457304407, 4: 166.043925116895, 5: 173.364255361506, 6: 182.970159982315,
         7: 192.069721277248, 8: 198.921793935208, 9: 207.132334105971, 10: 219.791391890822, 11: 225.190465408836,
         12: 233.224118087667, 13: 238.309712773558, 14: 244.163680248136, 15: 248.145997833644, 16: 245.483967274703,
         17: 237.667997918189, 18: 227.019469709005, 19: 214.521764327814, 20: 199.99744066353, 21: 189.497606485075,
         22: 176.667558313411, 23: 166.492251582068, 24: 159.032696853995, 25: 153.141158166455, 26: 146.674751066081,
         27: 139.725837521201, 28: 136.00859893395, 29: 126.800055837018, 30: 119.175128570404, 31: 115.380709067958,
         32: 108.150455386021, 33: 105.842494981107, 34: 104.143904503174, 35: 101.921444993887, 36: 103.583787084762,
         37: 106.702151175296, 38: 109.618417917255, 39: 113.529046616171, 40: 120.467464838397, 41: 127.829930023594,
         42: 136.744049794174, 43: 143.544671616551},
        {2: 40.8432215019754, 3: 43.2454636226555, 4: 45.3216597829005, 5: 47.2493986142909, 6: 49.6438287388922,
         7: 52.3004333891443, 8: 54.6739261978598, 9: 56.5525061879823, 10: 59.4147014330428, 11: 60.9837222192559,
         12: 63.4162668795035, 13: 65.0929782363318, 14: 67.8764066141393, 15: 71.1593796774245, 16: 75.6137264349046,
         17: 78.2772681013819, 18: 81.4753453319294, 19: 81.3138938584966, 20: 79.2635596273259, 21: 77.4543367963335,
         22: 75.5013215052135, 23: 73.3948202016404, 24: 72.0917267915537, 25: 69.6947996961156, 26: 67.0276526634721,
         27: 64.1277993795974, 28: 61.9879740024956, 29: 59.0091311036215, 30: 55.7260514407461, 31: 53.5868300601434,
         32: 50.7404943397893, 33: 48.9153047886946, 34: 47.0287892877436, 35: 44.7438440625028, 36: 42.6636943914038,
         37: 40.7812413237819, 38: 39.708610297279, 39: 38.5588825676014, 40: 37.8285339031265, 41: 37.7032919445759,
         42: 38.3752813223497, 43: 39.7948526117201}],
    'Basalt': [
        {2: 284.727938547538, 3: 304.583217712399, 4: 318.869935014715, 5: 342.027082064184, 6: 355.185306869937,
         7: 378.930744312618, 8: 397.775913026142, 9: 423.225958195962, 10: 422.086305173048, 11: 403.175059373383,
         12: 374.865697002209, 13: 338.357925388723, 14: 318.869935014715, 15: 300.504370747266, 16: 286.267572136708,
         17: 269.053309872199, 18: 254.928053421666, 19: 235.753202721274, 20: 223.979322973399, 21: 205.46355243597,
         22: 187.970900702628, 23: 177.144569091574, 24: 162.939261231681, 25: 149.469509057896, 26: 137.854689423796,
         27: 126.118086784016, 28: 116.004616985563, 29: 107.859230353569, 30: 99.2099469995219, 31: 95.0207929315598,
         32: 90.275307497597, 33: 85.5358680528269, 34: 79.744611224423, 35: 74.5461911353382, 36: 68.9390715338768,
         37: 63.9258390621412, 38: 59.4372187945479, 39: 54.8185338185788, 40: 50.0163747041779, 41: 46.1297547868304,
         42: 42.0887415206277, 43: 37.8874657866828, 44: 34.3825656192297, 45: 31.8822738312963, 46: 29.1678969698735,
         47: 26.3983513669483, 48: 23.9562881619971, 49: 21.9758860041213, 50: 20.9912736705869, 51: 21.3336420285492,
         52: 22.3946171258094, 53: 23.8274439982982, 54: 26.044836041428, 55: 28.3919199991939, 56: 30.6184890573883,
         57: 34.3825656192297, 58: 39.0280585002303, 59: 42.0887415206277, 60: 44.7816154171182, 61: 46.755889474478,
         62: 50.8321434063262, 63: 52.0808114136034, 64: 55.7126258924516, 65: 59.2771676333159, 66: 64.793525991299,
         67: 68.5682963554397, 68: 73.7464835414727, 69: 77.8326873874859, 70: 82.812489695349, 71: 87.165678562747,
         72: 92.492878521866, 73: 96.8313303178777, 74: 102.472573488582, 75: 108.442466739859, 76: 113.835580421175,
         77: 121.118878802947, 78: 126.800055837018, 79: 131.678218203624, 80: 139.725837521201, 81: 148.665616828732,
         82: 156.480494880635, 83: 164.262659222436, 84: 175.717386748865, 85: 183.464188083609, 86: 192.588318625187,
         87: 204.910284957694, 88: 215.681766102322, 89: 226.408156957734, 90: 241.544370713111, 91: 255.616371244696,
         92: 270.508184709104},
        {2: 50.844392862985, 3: 54.5503660549622, 4: 57.320112388391, 5: 60.8515599670486, 6: 63.2768716997222,
         7: 67.7125156207629, 8: 71.1483532457354, 9: 75.1418158420968, 10: 81.3239751959906, 11: 85.7688771286291,
         12: 88.3646202483594, 13: 88.2359949245838, 14: 88.0638758932285, 15: 87.8920926087639, 16: 87.2488562580731,
         17: 86.6237501164977, 18: 86.449417182626, 19: 84.9461321877762, 20: 84.5495153087399, 21: 83.0869930983463,
         22: 81.6522999596212, 23: 80.4266270594904, 24: 78.6176549189681, 25: 76.0461644577121, 26: 73.3607070216299,
         27: 69.1182997960297, 28: 64.9458715942479, 29: 60.0608564901365, 30: 55.8436200535749, 31: 53.1435717064313,
         32: 50.0485886761696, 33: 47.2596505983008, 34: 44.7521653668757, 35: 41.9322030922241, 36: 39.0883121494472,
         37: 36.2446962645972, 38: 33.4303036324073, 39: 30.9186606883689, 40: 28.5992646109678, 41: 26.1044557201843,
         42: 23.8930930783083, 43: 21.8724487808236, 44: 20.0736420700142, 45: 18.5643440181154, 46: 17.1260112631746,
         47: 15.3902449632315, 48: 14.0133495421825, 49: 12.7917113812673, 50: 11.5792678691974, 51: 10.3644796986761,
         52: 9.47120655965133, 53: 9.04994140705524, 54: 8.6904017690272, 55: 8.43381097520518, 56: 8.29434866163918,
         57: 8.08921658905077, 58: 8.09874920973805, 59: 8.11306920786669, 60: 8.50099319566085, 61: 8.93290042150216,
         62: 9.58222435727902, 63: 9.99196801813492, 64: 10.5799852742582, 65: 11.3219823088954, 66: 12.30523662771,
         67: 12.9284212042124, 68: 13.7607096270052, 69: 14.6497559441779, 70: 15.3502296613953, 71: 16.1286241374391,
         72: 17.1695913955696, 73: 17.9938961143144, 74: 18.9550461972553, 75: 20.1790606703162, 76: 21.2029773754048,
         77: 22.2167914235583, 78: 23.4064104749964, 79: 24.4678794021635, 80: 25.7062303224357, 81: 27.2207033525322,
         82: 28.7521295494504, 83: 30.0522982453824, 84: 31.6536275480608, 85: 33.1743327931344, 86: 34.6744731195016,
         87: 36.5243578143832, 88: 38.8853137944401, 89: 41.0742594469823, 90: 43.3783586358497, 91: 46.0580024729414,
         92: 48.5182063451726}],
    'Quartzite': [
        {2: 161.446093320161, 3: 180.587034901485, 4: 206.698278000787, 5: 234.988880251431, 6: 268.054099204161,
         7: 291.986488511514, 8: 328.656266117287, 9: 359.139530519422, 10: 394.953973354156, 11: 402.610175249287,
         12: 381.718032557738, 13: 358.465340024327, 14: 329.004810066299, 15: 310.11898911679, 16: 283.78284730521,
         17: 257.95617839105, 18: 230.642436706925, 19: 205.536396067237, 20: 183.149977899813, 21: 164.28657272129,
         22: 147.358891043442, 23: 133.496982430447, 24: 126.679404479048, 25: 121.822103631036, 26: 123.093534224409,
         27: 128.95168194596, 28: 137.786963616363, 29: 149.648394199518},
        {2: 60.12334314127, 3: 61.6773814310029, 4: 64.1561604545453, 5: 68.32109142864, 6: 72.0280361441945,
         7: 75.1125537204873, 8: 80.7885452380785, 9: 85.6857481357871, 10: 94.0076293128177, 11: 102.312045828999,
         12: 109.352809362664, 13: 111.469038456687, 14: 110.55800181172, 15: 106.06559161882, 16: 100.680436451685,
         17: 96.5296877506363, 18: 92.5240545170997, 19: 88.9792389404491, 20: 86.44040274832, 21: 83.7006848696205,
         22: 81.5963284330762, 23: 79.0234673710651, 24: 74.8049764577145, 25: 69.643262137004, 26: 65.1116319374142,
         27: 62.5783467452138, 28: 60.367160308301, 29: 59.8434977972896}],
    'Gneiss': [
        {2: 96.6836684207007, 3: 102.213911894108, 4: 110.956880383604, 5: 120.459294158415, 6: 134.296915846616,
         7: 148.767771365585, 8: 164.278657658367, 9: 180.813392314206, 10: 197.741186545926, 11: 213.453708512662,
         12: 227.34916823847, 13: 232.018890522856, 14: 229.865889461203, 15: 222.537427364765, 16: 213.320057017558,
         17: 197.865077405487, 18: 184.114333031705, 19: 172.437137206879, 20: 159.371043345648, 21: 139.729010915154,
         22: 127.835127388023, 23: 115.787483865822, 24: 104.857570267638, 25: 96.8515082672078, 26: 88.2388981138488,
         27: 87.8952130107521, 28: 88.1156961944374, 29: 89.7913715575615, 30: 90.6236548417041, 31: 93.2906007636653},
        {2: 70.311935784065, 3: 75.2900887732106, 4: 80.1147495535646, 5: 84.106274770399, 6: 86.2753623269796,
         7: 86.1348415878903, 8: 84.2671658365283, 9: 82.1578028233926, 10: 77.960195274182, 11: 72.2348139605941,
         12: 68.7448323016094, 13: 63.8503658839968, 14: 58.8759115942904, 15: 54.0849372933765, 16: 49.6754468138095,
         17: 44.9887956428284, 18: 41.4395283308422, 19: 38.693036656563, 20: 36.4877634793264, 21: 34.0311813972837,
         22: 33.298892433879, 23: 33.1308636056181, 24: 33.7511473049014, 25: 34.7444032580358, 26: 38.3832703658498,
         27: 41.7575262681252, 28: 46.6760264810622, 29: 53.4352524211542, 30: 58.7370813944682, 31: 64.8049257466367}
    ],
    'Marble': [
        {2: 69.8804959802203, 3: 73.1550563221064, 4: 75.3315099102936, 5: 76.7936647970027, 6: 75.9876498475892,
         7: 74.7044269308078, 8: 71.0603117287, 9: 68.0530691057269, 10: 65.8342550630175, 11: 63.7123359401747,
         12: 60.8575176776079, 13: 58.9116137055435, 14: 58.3635420340575, 15: 58.0089147445836, 16: 59.0138824378261,
         17: 60.0232456297014, 18: 61.6558382617659, 19: 65.4405398769998, 20: 67.6281615292231},
        {2: 52.3177615315133, 3: 55.4486031613367, 4: 58.5524835600082, 5: 63.5103200013519, 6: 69.553284249263,
         7: 74.8891187186643, 8: 80.3176504289359, 9: 84.1393742704755, 10: 85.8110648163043, 11: 82.9186641252705,
         12: 78.766258532236, 13: 73.3394509771476, 14: 67.8541784655693, 15: 63.2076037712562, 16: 57.5281118890993,
         17: 53.9725709949616, 18: 50.8164139850058, 19: 49.6810315896116, 20: 50.5543067843775}],
    'Schist_Flat': [
        {2: 35.9767301922737, 3: 43.2351252724574, 4: 146.304825872888, 5: 166.778804045694, 6: 179.810007473394,
         7: 198.299307001592, 8: 205.467089193545, 9: 199.95423466185, 10: 185.213111209249, 11: 161.726358725526,
         12: 142.204527739017, 13: 125.066270353157, 14: 106.800153658113, 15: 98.3870890820801, 16: 32.6026423929527,
         17: 29.8475962711872, 18: 26.5378042196558, 19: 24.7889062282646, 20: 23.6172121140306, 21: 23.4855877305039,
         22: 24.2076280906868, 23: 25.7004062295025, 24: 28.0084793997373, 25: 31.5396601980052},
        {2: 5.54621822719689, 3: 6.43199323149537, 4: 22.116393808456, 5: 25.6255004679836, 6: 28.1997386203507,
         7: 33.0992201611974, 8: 37.0186852948327, 9: 41.3580831726655, 10: 45.3952280080074, 11: 47.1612803926695,
         12: 46.5842895208956, 13: 44.6386624944354, 14: 41.3348425422466, 15: 38.7147919242601, 16: 12.9543254007343,
         17: 11.5333720311708, 18: 9.62607023045498, 19: 8.20532996765087, 20: 7.04399306301732, 21: 6.11298319374313,
         22: 5.64053623691598, 23: 5.31368024105231, 24: 5.17979546250946, 25: 5.24306796646124}],
    'Schist_Perp': [
        {2: 28.40119412051, 3: 112.85466758753, 4: 124.88563182176, 5: 131.543281050001, 6: 139.44319018948,
         7: 142.108641173414, 8: 142.918856334917, 9: 132.334695476981, 10: 122.593417969403, 11: 110.999655449582,
         12: 99.8339186110346, 13: 88.3388604930395, 14: 75.8980070160373, 15: 66.5181478610611, 16: 56.7825505318548,
         17: 50.2687182805094, 18: 44.0711168912362, 19: 39.676104603726, 20: 35.7228289806148, 21: 32.0613400822604,
         22: 29.15893303234, 23: 26.7870114851735, 24: 24.0495280985881, 25: 22.1673317255124, 26: 20.4299814088372,
         27: 18.9534871904022, 28: 17.4146598434447, 29: 15.9465124285828, 30: 14.4127216945563, 31: 13.5968493236688,
         32: 13.3001041146349, 33: 13.0991471455592, 34: 13.777534019508, 35: 14.8744471574613, 36: 16.2184773887305,
         37: 17.7963462607264, 38: 20.1096662119325, 39: 23.4771028252449, 40: 25.9086495770692},
        {2: 7.43286562188679, 3: 29.8285496805358, 4: 34.4275238634098, 5: 38.9067664938878, 6: 45.3289337684771,
         7: 51.1977339838848, 8: 58.2046531292834, 9: 67.2013232128203, 10: 72.5277465684748, 11: 75.9062386962835,
         12: 80.2409386613948, 13: 82.5419962518863, 14: 82.0516563659658, 15: 80.7703829520472, 16: 78.6733377686679,
         17: 75.6506708943027, 18: 71.0349275210738, 19: 65.6149725345021, 20: 59.7964235168669, 21: 53.5796183346826,
         22: 47.6971348662317, 23: 41.6169333552396, 24: 35.570408262312, 25: 30.8291583421281, 26: 27.174272534195,
         27: 23.955376887353, 28: 20.413993638603, 29: 17.6314196645274, 30: 14.9197249392791, 31: 12.7198232164488,
         32: 10.9983772545847, 33: 9.19555809317972, 34: 8.01478833638716, 35: 7.27742217884065, 36: 6.60900859862182,
         37: 6.22953247882859, 38: 6.15885425314676, 39: 6.43018579057854, 40: 6.8672828715387}],
    'Limestone': [
        {2: 50.5671045189487, 3: 46.2126901357206, 4: 45.6907448228467, 5: 45.6849626080336, 6: 48.8575447648388,
         7: 52.2504461901094, 8: 59.7708151810881, 9: 97.8652815681611, 10: 111.95450303737, 11: 160.315028163548,
         12: 191.864901123736, 13: 234.862756217632, 14: 259.895666497283, 15: 268.836447844793, 16: 268.930029319713,
         17: 240.464619054415, 18: 212.577021366626, 19: 187.929600550784, 20: 153.601843251831, 21: 134.26290166924,
         22: 108.488331470877, 23: 80.1307821096305, 24: 61.8974794930318, 25: 54.0941274888302},
        {2: 25.7790913598706, 3: 27.8657298561777, 4: 29.3498329553712, 5: 30.9129780183103, 6: 34.2934570489521,
         7: 38.0436073053763, 8: 43.3131448989186, 9: 69.0934088168044, 10: 77.6498900417476, 11: 90.7290740990469,
         12: 93.1138072508387, 13: 91.9137069087398, 14: 85.0310348895984, 15: 80.7313571844757, 16: 69.9955487298443,
         17: 58.3710066504153, 18: 51.9389251340501, 19: 45.6199630914466, 20: 37.5532810316491, 21: 34.2934570489521,
         22: 30.9129780183103, 23: 27.506581487954, 24: 25.7790913598706, 25: 25.4468366999721}],
    'Mudstone': [
        {2: 0.608758737705124, 3: 0.508768361430144, 4: 0.429963718688375, 5: 0.384307450852984, 6: 0.321072080401022,
         7: 0.280523836547239, 8: 0.265077832758436, 9: 0.273997423415898, 10: 0.433625080704438, 11: 0.586876731721373,
         12: 0.72614558837992, 13: 0.908640949262942, 14: 1.11177921447671, 15: 1.47127870860932, 16: 1.82042068766356,
         17: 2.15318534530021, 18: 3.18643237731427, 19: 3.85427745717083, 20: 4.21451408354336, 21: 4.30753472676973,
         22: 4.50348384037542, 23: 5.57235994517929, 24: 7.54221904382582, 25: 11.0438170358847, 26: 19.1367760099569,
         27: 21.1704451348038, 28: 25.9132047608928, 29: 27.107426308142, 30: 27.118578351061, 31: 23.7162694457417,
         32: 22.1804553094519, 33: 18.1329256343993, 34: 14.8239965084277, 35: 7.65376206527207, 36: 5.9153730273083,
         37: 4.42047471772305, 38: 3.45493911585529, 39: 1.47477417456712, 40: 1.05395913386365, 41: 0.861521721044674,
         42: 0.680972397751559},
        {2: 0.023694518476248, 3: 0.021083546298862, 4: 0.019504770520408, 5: 0.019005234799, 6: 0.019504770520408,
         7: 0.02135883027964, 8: 0.025946841987321, 9: 0.033199134404454, 10: 0.060295054234955, 11: 0.078155176189894,
         12: 0.09494340188767, 13: 0.113851308976154, 14: 0.134765108344448, 15: 0.174684158104702,
         16: 0.212207419071606, 17: 0.271520620151895, 18: 0.438786766542876, 19: 0.576186900271553,
         20: 0.709094677175693, 21: 0.919137069087398, 22: 1.10218252520501, 23: 1.32168134625825, 24: 1.6693031437153,
         25: 2.08118103246495, 26: 2.69765194408046, 27: 2.80470587324548, 28: 2.84132640125129, 29: 2.69765194408046,
         30: 2.27901130172823, 31: 1.69109892740432, 32: 1.41024891624201, 33: 1.06011288392613, 34: 0.796908484539692,
         35: 0.405929584496538, 36: 0.305145550927486, 37: 0.226427711650378, 38: 0.172432735634821,
         39: 0.066026505093133, 40: 0.043594993748135, 41: 0.034516612662045, 42: 0.025946841987321}],
    'Sandstone': [
        {2: 13.3348451438855, 3: 18.6626011467829, 4: 22.579100156588, 5: 26.7115278122353, 6: 33.049264592356,
         7: 36.5556332233009, 8: 48.9209654150874, 9: 61.2100025795425, 10: 93.6989661534889, 11: 109.633943560224,
         12: 135.676394514437, 13: 153.509532355045, 14: 198.760678510038, 15: 227.476093239757, 16: 246.184516587503,
         17: 238.117591208974, 18: 208.203723400663, 19: 176.004541809036, 20: 137.556659753067, 21: 99.3943576488237,
         22: 75.112603156954, 23: 50.7434036694055, 24: 37.0810048371256, 25: 30.9952460022868, 26: 23.6862733279013,
         27: 20.2480258388943},
        {2: 5.65083564583243, 3: 7.9175633930494, 4: 9.49434018876694, 5: 11.2383932666617, 6: 13.8307289555544,
         7: 15.3431839893286, 8: 20.1476942724605, 9: 25.1188643150958, 10: 38.5403356789495, 11: 41.6599083188712,
         12: 46.8190433140544, 13: 48.0496402956164, 14: 48.0496402956164, 15: 45.031988709032, 16: 38.0436073053763,
         17: 32.5593747471619, 18: 26.1156842076675, 19: 21.4978172257271, 20: 16.5851082263439, 21: 11.9914924799993,
         22: 9.01424956200351, 23: 6.18798561978428, 24: 4.41642055520165, 25: 3.68296153507817, 26: 2.84132640125129,
         27: 2.40038934398475}],
    'Shale': [
        {2: 39.7238992930836, 3: 49.1490291235183, 4: 58.7973305355051, 5: 80.4661442308283, 6: 98.4491463319799,
         7: 127.385065866272, 8: 142.4915385949, 9: 164.804897462028, 10: 184.284802911126, 11: 192.637413728385,
         12: 188.191409012179, 13: 175.848685990147, 14: 160.706073913943, 15: 135.779460156375, 16: 126.934455949246,
         17: 110.960041223422, 18: 63.3658161050932, 19: 48.9705216549177, 20: 36.1862397165092, 21: 27.3460458708516,
         22: 22.603402751018},
        {2: 2.43173078553652, 3: 2.99265282764246, 4: 3.63549356519614, 5: 4.96334710303244, 6: 6.02950542349548,
         7: 7.9175633930494, 8: 8.78338605847256, 9: 10.9505673277686, 10: 14.011314236132, 11: 17.9275576093498,
         12: 25.7790913598706, 13: 30.9129780183103, 14: 33.4151690020047, 15: 34.2934570489521, 16: 33.8514647091337,
         17: 30.1212672540594, 18: 17.2432735634821, 19: 13.302818384955, 20: 9.87111467380279, 21: 7.42031830259869,
         22: 6.10823156527332}]
}


def ucs_strength_criteria(type):
    """
    ## Insert all UCS Strength Criterion Here.     ## ALL VALUES ARE IN MPa
    # Name Format {Reference Name: [Name of Category]}
    # Value Format {Reference Name: [Boundaries Location]}  <=> in MPa
    # converted_psi [Reference name that are converted from psi to MPa]

    :param type: rock classification system to load
    :type type: str

    :return:
    :rtype:
    """

    category_names = {
        'ISRM\n1977': ['Extremely\nweak', 'Very weak', 'Weak', 'Moderately\nweak', 'Medium\nstrong', 'Strong',
                       'Very strong', 'Extremely strong'],
        'ISRMCAT\n1979': ['R0', 'R1', 'R2', 'R3', 'R4', 'R5', 'R6'],
        'Bieniawski\n1974': ['Very Low', 'Low', 'Medium', 'High', 'Very high'],
        'Jennings\n1973': ['Very soft', 'Soft', 'Hard', 'Very hard', 'Extremely hard'],
        'Broch & Franklin\n1972': ['Very low', 'Low', 'Medium', 'High', 'Very high', 'Extremely high'],
        'Geological Society\n1970': ['Very weak', 'Weak', 'Moderately weak', 'Moderately\nstrong', 'Strong',
                                     'Very strong', 'Extremely strong'],
        'Deere & Miller\n1966': ['Very low (E)', 'Low (D)', 'Medium (C)', 'High (B)', 'Very high (A)'],
        'Coates\n1964': ['Weak', 'Strong', 'Very strong'],
        'Coates & Parsons\n1966': ['Weak', 'Strong', 'Very strong'],
        'ISO 14689\n2017': ['Extremely\nweak', 'Very weak', 'Weak', 'Moderately\nweak', 'Medium\nstrong', 'Strong',
                            'Very strong', 'Extremely strong'],
        'Anon\n1977': ['Very weak', 'Weak', 'Moderately Weak', 'Moderately Strong', 'Strong', 'Very Strong'],
        'Anon\n1979': ['Weak', 'Moderately Strong', 'Strong', 'Very Strong', 'Extremely Strong'],
        'Ramamurthy\n2004': ['Very Low (F)', 'Low (E)', 'Medium (D)', 'Moderate (C)', 'High (B)', 'Very High (A)']}

    category_values = {'ISRM\n1977': [0.25, 1, 5, 25, 50, 100, 250, 1000],
                       'ISRMCAT\n1979': [0.25, 1, 5, 25, 50, 100, 250, 1000],
                       'Bieniawski\n1974': [1, 25, 50, 100, 200, 1000],
                       'Jennings\n1973': [0.7, 3, 10, 20, 70, 1000],
                       'Broch & Franklin\n1972': [0.8, 2.5, 7, 25, 70, 250, 1000],
                       'Geological Society\n1970': [1.25, 5, 12.5, 50, 100, 200, 1000],
                       'Deere & Miller\n1966': [0.6, 27.5, 55.1, 110.3, 220.6, 1000],
                       'Coates\n1964': [0.6, 34.4, 172, 1000],
                       'Coates & Parsons\n1966': [0.6, 68.9, 172, 1000],
                       'ISO 14689\n2017': [0.6, 1, 5, 12.5, 25, 50, 100, 250, 1000],
                       'Anon\n1977': [0.6, 1.25, 5, 12.5, 50, 100, 1000],
                       'Anon\n1979': [1.5, 15, 50, 120, 230, 1000],
                       'Ramamurthy\n2004': [0.8, 5, 25, 50, 100, 250, 1000]}

    converted_psi = ['Coates\n1964', 'Coates & Parsons\n1966', 'Deere & Miller\n1966']

    # If called on separately will plot all the values in a bar chart type
    # If called on from the Deere-Miller plots will create the UCS Strength Criterion based on the type called
    if type == '':
        return category_names, category_values, converted_psi
    else:
        return category_names[type], category_values[type]
